package github.com/ciuak/jvozba

import "testing"

func TestNoralujv(t *testing.T) {
	for i, n := range Noralujv {
		res, err := Jvozba(n.tanru)
		if err != nil {
			t.Errorf("on example #%d (%s): got error: %v", i, n.lujvo, err)
		} else if res != n.lujvo {
			t.Errorf("on example #%d: expected %s, got %s (input: %s)", i, n.lujvo, res, n.tanru)
		}
	}
}

type nora struct {
	lujvo string
	tanru string
}

var Noralujv = []nora{
	nora{"ba'armo'a", "barna morna"},
	nora{"ba'orzu'e", "banro zukte"},
	nora{"ba'ostu", "banro stuzi"},
	nora{"ba'urdu'u", "bacru dunku"},
	nora{"ba'urnoi", "bacru notci"},
	nora{"ba'urtadji", "bacru tadji"},
	nora{"ba'usku", "bacru cusku"},
	nora{"bacycta", "bancu catlu"},
	nora{"bajyjvi", "bajra jivna"},
	nora{"bajykla", "bajra klama"},
	nora{"bajli'a", "bajra cliva"},
	nora{"bajystu", "bajra stuzi"},
	nora{"bakcange", "bakni cange"},
	nora{"bakcatra", "bakni catra"},
	nora{"bakplixa", "bakni plixa"},
	nora{"bakre'u", "bakni rectu"},
	nora{"bakryta'o", "bakri tanbo"},
	nora{"bakyjanbe", "bakni janbe"},
	nora{"bakykakpa", "bakni kakpa"},
	nora{"balcu'e", "banli ckule"},
	nora{"baldakyxa'i", "banli dakfu xarci"},
	nora{"baljamna", "banli jamna"},
	nora{"balku'a", "banli kumfa"},
	nora{"balnunjamna", "banli nu jamna"},
	nora{"balrai", "banli traji"},
	nora{"balsoi", "banli sonci"},
	nora{"baltutra", "banli tutra"},
	nora{"bacybau", "bancu bangu"},
	nora{"bacycripu", "bancu cripu"},
	nora{"bacycu'e", "bancu ckule"},
	nora{"backemselrerkru", "bancu ke se renro kruvi"},
	nora{"backla", "bancu klama"},
	nora{"banjikske", "bangu jikca saske"},
	nora{"baupli", "bangu pilno"},
	nora{"banpliske", "bangu pilno saske"},
	nora{"banta'a", "bangu tavla"},
	nora{"bantadni", "bangu tadni"},
	nora{"banvelsku", "bangu ve cusku"},
	nora{"baple'i", "bapli pleji"},
	nora{"barca'e", "bartu catke"},
	nora{"brablo", "barda bloti"},
	nora{"barfle", "bartu flecu"},
	nora{"bagyce'a", "bargu cecla"},
	nora{"bagyxai", "bargu xrani"},
	nora{"barjyja'a", "barja jatna"},
	nora{"barkalri", "bartu kalri"},
	nora{"barkla", "bartu klama"},
	nora{"barli'a", "bartu cliva"},
	nora{"bartca", "bartu tcadu"},
	nora{"barterzga", "bartu te zgana"},
	nora{"basme'e", "basti cmene"},
	nora{"basygau", "basti gasnu"},
	nora{"basyvla", "basti valsi"},
	nora{"batfendi", "batci fendi"},
	nora{"batkyci'a", "batke ciska"},
	nora{"batkyke'a", "batke kevna"},
	nora{"baucmu", "bangu jicmu"},
	nora{"baucre", "bangu certu"},
	nora{"bauske", "bangu saske"},
	nora{"bavla'i", "balvi lamji"},
	nora{"bavlamdei", "balvi lamji djedi"},
	nora{"bavlamjeftu", "balvi lamji jeftu"},
	nora{"bavna'arefma'i", "balvi nanca krefu masti"},
	nora{"bavna'ake'udei", "balvi nanca krefu djedi"},
	nora{"bavyspe", "balvi speni"},
	nora{"bavyteike'u", "balvi temci krefu"},
	nora{"bavyteirefma'i", "balvi temci krefu masti"},
	nora{"bavyteireftei", "balvi temci krefu temci"},
	nora{"be'aspe", "bersa speni"},
	nora{"befcro", "betfu cortu"},
	nora{"bebgei", "bebna gleki"},
	nora{"befke'a", "betfu kevna"},
	nora{"befsfeke'a", "betfu sefta kevna"},
	nora{"befsri", "betfu dasri"},
	nora{"be'udzu", "betfu cadzu"},
	nora{"beipre", "bevri prenu"},
	nora{"bejmu'o", "benji mulno"},
	nora{"bemjoitco", "bemro joi ketco"},
	nora{"benmro", "besna morsi"},
	nora{"bermau", "berti zmadu"},
	nora{"berpau", "berti pagbu"},
	nora{"berstici", "berti stici"},
	nora{"berstuna", "berti stuna"},
	nora{"besmamta", "bersa mamta"},
	nora{"bevma'e", "bevri marce"},
	nora{"beircarce", "bevri carce"},
	nora{"bifcau", "brife claxu"},
	nora{"bifkluza", "brife kluza"},
	nora{"bifmlo", "brife molki"},
	nora{"bifyvilcarvi", "brife vlile carvi"},
	nora{"bigygau", "bilga gasnu"},
	nora{"bijyjbu", "briju jubme"},
	nora{"bijyku'a", "briju kumfa"},
	nora{"bijyta'e", "briju tanxe"},
	nora{"bikydamri", "bikla damri"},
	nora{"bikykla", "bikla klama"},
	nora{"bi'arbi'o", "bilma binxo"},
	nora{"bi'amlu", "bilma simlu"},
	nora{"bimxra", "bitmu pixra"},
	nora{"binkemgaste'i", "jbini ke ganse steci"},
	nora{"binrydi'a", "binra jdima"},
	nora{"binryve'u", "binra vecnu"},
	nora{"velbinryve'u", "ve binra vecnu"},
	nora{"binynalvokselba'u", "jbini na'e voksa se bacru"},
	nora{"bircidni", "birka cidni"},
	nora{"birdadykla", "birka dandu klama"},
	nora{"birjai", "birka jgari"},
	nora{"birtafpau", "birka taxfu pagbu"},
	nora{"birtu'u", "birka tubnu"},
	nora{"birtu'ucau", "birka tubnu claxu"},
	nora{"birvrajvi", "birka vraga jivna"},
	nora{"bisycmaplini", "bisli cmalu plini"},
	nora{"bivjetka'u", "bi jetnu kantu"},
	nora{"blari'o", "blanu crino"},
	nora{"blita'o", "bliku tanbo"},
	nora{"blogre", "bloti pagre"},
	nora{"blokla", "bloti klama"},
	nora{"bloli'u", "bloti litru"},
	nora{"blomuvga'a", "bloti muvdu grana"},
	nora{"blosazri", "bloti sazri"},
	nora{"blufle", "ciblu flecu"},
	nora{"bluselpi'a", "ciblu se pilka"},
	nora{"bofsnipa", "boxfo snipa"},
	nora{"bogygreku", "bongu greku"},
	nora{"bogykamju", "bongu kamju"},
	nora{"boldi'u", "bolci dinju"},
	nora{"bolga'axa'i", "bolci grana xarci"},
	nora{"bolgrijvi", "bolci girzu jivna"},
	nora{"bolgu'o", "bolci gunro"},
	nora{"boijme", "bolci jemna"},
	nora{"bolkei", "bolci kelci"},
	nora{"bolkeijvi", "bolci kelci jivna"},
	nora{"boltikpa", "bolci tikpa"},
	nora{"boltipkei", "bolci tikpa kelci"},
	nora{"boltipyboi", "bolci tikpa bolci"},
	nora{"boltipyjvi", "bolci tikpa jivna"},
	nora{"brabi'o", "barda binxo"},
	nora{"brabra", "barda barda"},
	nora{"brabracrida", "barda barda crida"},
	nora{"bracutci", "barda cutci"},
	nora{"bradzu", "barda cadzu"},
	nora{"brafe'a", "barda fenra"},
	nora{"braje'a", "barda jecta"},
	nora{"brajmadegji", "barda jamfu degji"},
	nora{"brajmadegycalku", "barda jamfu degji calku"},
	nora{"brakruca", "barda kruca"},
	nora{"bramau", "barda zmadu"},
	nora{"brapatxu", "barda patxu"},
	nora{"braplu", "barda daplu"},
	nora{"braro'i", "barda rokci"},
	nora{"brasa'o", "barda salpo"},
	nora{"bravau", "barda vasru"},
	nora{"brivla", "bridi valsi"},
	nora{"bromalsi", "xebro malsi"},
	nora{"brulu'i", "burcu lumci"},
	nora{"bukydi'u", "bukpu dinju"},
	nora{"bukcilta", "bukpu cilta"},
	nora{"bukfa'u", "bukpu farlu"},
	nora{"bukfe'a", "bukpu fenra"},
	nora{"bu'udru", "bukpu drudi"},
	nora{"bukmra", "bukpu marbi"},
	nora{"buktaiterjo'e", "bukpu tarmi te jorne"},
	nora{"bukterjo'e", "bukpu te jorne"},
	nora{"bukyjabre", "bukpu jabre"},
	nora{"bukykoi", "bukpu korbi"},
	nora{"bunspe", "bruna speni"},
	nora{"burnanba", "bunre nanba"},
	nora{"ca'arcau", "cabra claxu"},
	nora{"ca'erbi'e", "catke brife"},
	nora{"ca'erslanu", "catke slanu"},
	nora{"ca'icru", "catni curmi"},
	nora{"ca'irci'a", "catni ciska"},
	nora{"cabdei", "cabna djedi"},
	nora{"cabma'i", "cabna masti"},
	nora{"cabmamta", "cabna mamta"},
	nora{"cabmi'u", "cabna mintu"},
	nora{"cabmo'a", "cabna morna"},
	nora{"cabnalza'i", "cabna na'e zasti"},
	nora{"cabna'a", "cabna nanca"},
	nora{"cabycedra", "cabna cedra"},
	nora{"cabysna", "cabna sance"},
	nora{"cabysni", "cabna sinxa"},
	nora{"cacyju'o", "tcaci djuno"},
	nora{"cacyjva", "tcaci javni"},
	nora{"cadgau", "cando gasnu"},
	nora{"cadykei", "cando kelci"},
	nora{"cadysti", "cando sisti"},
	nora{"cagyce'u", "cange cecmu"},
	nora{"cagyselxa'u", "cange se xabju"},
	nora{"cagzaita'u", "cange zarci taxfu"},
	nora{"cagzai", "cange zarci"},
	nora{"caicni", "carmi cinmo"},
	nora{"caicpe", "carmi cpedu"},
	nora{"caicta", "carmi catlu"},
	nora{"caidji", "carmi djica"},
	nora{"camcinla", "carmi cinla"},
	nora{"cinlyrai", "cinla traji"},
	nora{"caizma", "carmi zmadu"},
	nora{"caivru", "carmi savru"},
	nora{"cakcinki", "calku cinki"},
	nora{"cakcurnu", "calku curnu"},
	nora{"cakybe'ujma", "calku betfu jamfu"},
	nora{"cakyda'u", "calku danlu"},
	nora{"cakyrespa", "calku respa"},
	nora{"calze'a", "canlu zenba"},
	nora{"caibra", "carmi barda"},
	nora{"camcarvi", "carmi carvi"},
	nora{"camcikna", "carmi cikna"},
	nora{"camcilce", "carmi cilce"},
	nora{"camcintungau", "carmi cinse tunta gasnu"},
	nora{"camcniri'a", "carmi cinmo rinka"},
	nora{"camganra", "carmi ganra"},
	nora{"camgei", "carmi gleki"},
	nora{"campei", "carmi pensi"},
	nora{"camselci'i", "carmi se cinri"},
	nora{"camselci'igri", "carmi se cinri girzu"},
	nora{"caitcu", "carmi nitcu"},
	nora{"camte'a", "carmi terpa"},
	nora{"camtoi", "carmi troci"},
	nora{"camvrici", "carmi vrici"},
	nora{"cagypre", "cange prenu"},
	nora{"capli'u", "ckape litru"},
	nora{"capti'i", "ckape stidi"},
	nora{"capyjde", "ckape kajde"},
	nora{"carcpu", "carna lacpu"},
	nora{"cargau", "carna gasnu"},
	nora{"carna'ivinji", "carna nalci vinji"},
	nora{"ca'irvei", "catni vreji"},
	nora{"cavlu'i", "carvi lumci"},
	nora{"cavyfle", "carvi flecu"},
	nora{"cavykosta", "carvi kosta"},
	nora{"cavysezlu'i", "carvi sevzi lumci"},
	nora{"cazyfusra", "ca'a fusra"},
	nora{"cazytcini", "ca'a tcini"},
	nora{"cedrymi'u", "cedra mintu"},
	nora{"celtci", "cecla tutci"},
	nora{"cemlanzu", "cecmu lanzu"},
	nora{"cempre", "cecmu prenu"},
	nora{"cnecme", "cenba cmene"},
	nora{"centre", "centi mitre"},
	nora{"cermurse", "cerni murse"},
	nora{"cespre", "censa prenu"},
	nora{"cesri'a", "censa rinka"},
	nora{"cesri'isi'a", "censa ritli sinma"},
	nora{"cestoldapma", "censa to'e dapma"},
	nora{"cesycku", "censa cukta"},
	nora{"cesystu", "censa stuzi"},
	nora{"cevrirni", "cevni rirni"},
	nora{"ceirselcpe", "cevni se cpedu"},
	nora{"ceirselxa'u", "cevni se xabju"},
	nora{"ceizda", "cevni zdani"},
	nora{"cfagau", "cfari gasnu"},
	nora{"cfatse", "cfari zutse"},
	nora{"fi'unri'abau", "cfipu rinka bangu"},
	nora{"ci'ajbu", "ciska jubme"},
	nora{"ci'arfi'i", "ciska finti"},
	nora{"ci'arse'u", "ciska selfu"},
	nora{"ci'asku", "ciska cusku"},
	nora{"ci'izma", "cinri zmadu"},
	nora{"cibdei", "ci djedi"},
	nora{"reldei", "re djedi"},
	nora{"pavdei", "pa djedi"},
	nora{"vondei", "vo djedi"},
	nora{"mumdei", "mu djedi"},
	nora{"xavdei", "xa djedi"},
	nora{"nondei", "no djedi"},
	nora{"zeldei", "ze djedi"},
	nora{"cibjantradamri", "ci janco tarti damri"},
	nora{"cibjgatai", "ci jganu tarmi"},
	nora{"cibmeilei", "ci mei klesi"},
	nora{"cibylajyterkruca", "ci klaji te kruca"},
	nora{"cibyselxi'u", "ci se xislu"},
	nora{"cibyskosa'e", "ci skori satre"},
	nora{"cibyslakyvla", "ci slaka valsi"},
	nora{"cibyteryrau", "ci te gradu"},
	nora{"cicfe'u", "cilce fengu"},
	nora{"cicfoi", "cilce foldi"},
	nora{"cicpre", "cilce prenu"},
	nora{"cicre'a", "cilce remna"},
	nora{"cicti'a", "cilce tcima"},
	nora{"cicyractu", "cilce ractu"},
	nora{"cicyspa", "cilce spati"},
	nora{"cicyspafoi", "cilce spati foldi"},
	nora{"cidbajgre", "cidni bajra pagre"},
	nora{"cidbajykla", "cidni bajra klama"},
	nora{"cidydzu", "cidni cadzu"},
	nora{"cidydzukla", "cidni cadzu klama"},
	nora{"cidykla", "cidni klama"},
	nora{"cifylisri", "cifnu lisri"},
	nora{"cifydatka", "cifnu datka"},
	nora{"ciksne", "cikna senva"},
	nora{"cikybi'o", "cikna binxo"},
	nora{"cikygau", "cikna gasnu"},
	nora{"cimde'u", "cilmo dertu"},
	nora{"cimdilnu", "cilmo dilnu"},
	nora{"cimnytei", "cimni temci"},
	nora{"cimri'a", "cilmo rinka"},
	nora{"cimxra", "cilmo pixra"},
	nora{"cincigla", "cinse cigla"},
	nora{"cingafpre", "cinse galfi prenu"},
	nora{"cintungau", "cinse tunta gasnu"},
	nora{"cintyfaigau", "cinta fatri gasnu"},
	nora{"cinvi'i", "cinse vikmi"},
	nora{"circre", "citri certu"},
	nora{"circtu", "citri ctuca"},
	nora{"cirmi'o", "citri misno"},
	nora{"citkanba", "citno kanba"},
	nora{"citmau", "citno zmadu"},
	nora{"citnanla", "citno nanla"},
	nora{"citnau", "citno nanmu"},
	nora{"citni'u", "citno ninmu"},
	nora{"citpe'o", "citno pendo"},
	nora{"citrai", "citno traji"},
	nora{"civysfani", "civla sfani"},
	nora{"cizda'u", "cizra danlu"},
	nora{"ckabu'u", "ckana bukpu"},
	nora{"ckali'a", "ckana cliva"},
	nora{"kafpanci", "ckafi panci"},
	nora{"kafpatxu", "ckafi patxu"},
	nora{"kafyzai", "ckafi zarci"},
	nora{"ckagai", "ckana gacri"},
	nora{"ckakla", "ckana klama"},
	nora{"ckazbe", "ckana zbepi"},
	nora{"ckudi'u", "cukta dinju"},
	nora{"ckuku'a", "cukta kumfa"},
	nora{"kulpikta", "ckule pikta"},
	nora{"kultadni", "ckule tadni"},
	nora{"ckupau", "cukta pagbu"},
	nora{"ckupaupau", "cukta pagbu pagbu"},
	nora{"ckupra", "cukta cupra"},
	nora{"ckusro", "cukta sorcu"},
	nora{"ckuzda", "cukta zdani"},
	nora{"ckuzdacre", "cukta zdani certu"},
	nora{"ckuzdaske", "cukta zdani saske"},
	nora{"clacku", "clani cukta"},
	nora{"cladakyxa'i", "clani dakfu xarci"},
	nora{"cladjine", "clani djine"},
	nora{"claga'u", "clani galtu"},
	nora{"clakurfa", "clani kurfa"},
	nora{"clamau", "clani zmadu"},
	nora{"clapi'e", "clani plipe"},
	nora{"clapi'ejvi", "clani plipe jivna"},
	nora{"clapre", "clani prenu"},
	nora{"clara'i", "clani ranji"},
	nora{"clare'i", "clani renvi"},
	nora{"claselxadni", "clani se xadni"},
	nora{"clatei", "clani temci"},
	nora{"claxa'i", "clani xarci"},
	nora{"caurgau", "claxu gasnu"},
	nora{"clinoi", "cilre notci"},
	nora{"lirgli", "clira glico"},
	nora{"cupypijne", "clupa pijne"},
	nora{"cmabanfi", "cmalu banfi"},
	nora{"cmabu'u", "cmalu bukpu"},
	nora{"cmacai", "cmalu carmi"},
	nora{"cmaca'e", "cmalu catke"},
	nora{"cmacifnu", "cmalu cifnu"},
	nora{"cmacinfo", "cmalu cinfo"},
	nora{"cinfypanzi", "cinfo panzi"},
	nora{"cmacpi", "cmalu cipni"},
	nora{"cmacma", "cmalu cmalu"},
	nora{"cmami'a", "cmalu cmila"},
	nora{"cmacrida", "cmalu crida"},
	nora{"cmactatci", "cmalu catlu tutci"},
	nora{"cmaplu", "cmalu daplu"},
	nora{"cmafle", "cmalu flecu"},
	nora{"cmagu'e", "cmalu gugde"},
	nora{"cmagu'etru", "cmalu gugde turni"},
	nora{"cmalauca'a", "cmalu cladu cabra"},
	nora{"cmala'u", "cmalu lalxu"},
	nora{"cmama'a", "cmalu cmana"},
	nora{"cmamudyspi", "cmalu mudri spisa"},
	nora{"cmapinflani", "cmalu pinta flani"},
	nora{"cmaplini", "cmalu plini"},
	nora{"cmari'e", "cmalu rirxe"},
	nora{"cmaro'i", "cmalu rokci"},
	nora{"cmaste", "cmalu liste"},
	nora{"cmataisni", "cmalu tarmi sinxa"},
	nora{"cmatca", "cmalu tcadu"},
	nora{"cmatricu", "cmalu tricu"},
	nora{"cmatru", "cmalu turni"},
	nora{"cmave'a", "cmalu verba"},
	nora{"cmaxli", "cmalu nixli"},
	nora{"cmazda", "cmalu zdani"},
	nora{"cmebasti", "cmene basti"},
	nora{"cmeju'o", "cmene djuno"},
	nora{"selcmeju'o", "se cmene djuno"},
	nora{"cmekancu", "cmene kancu"},
	nora{"cmemo'i", "cmene morji"},
	nora{"cmesanji", "cmene sanji"},
	nora{"cmetcita", "cmene tcita"},
	nora{"cmeterge'a", "cmene te gerna"},
	nora{"cmevla", "cmene valsi"},
	nora{"cmibi'o", "cmima binxo"},
	nora{"cmoba'u", "cmoni bacru"},
	nora{"cmodji", "cmoni djica"},
	nora{"cmosku", "cmoni cusku"},
	nora{"cnadakfu", "canpa dakfu"},
	nora{"nebykoi", "cnebo korbi"},
	nora{"cnedatni", "cenba datni"},
	nora{"cnelai", "cenba klani"},
	nora{"cnicro", "cinmo cortu"},
	nora{"nicygau", "cnici gasnu"},
	nora{"cnidu'e", "cinmo dukse"},
	nora{"cnija'o", "cinmo jarco"},
	nora{"cnijbi", "cinmo jibni"},
	nora{"cnikansa", "cinmo kansa"},
	nora{"cnima'o", "cinmo cmavo"},
	nora{"ninja'o", "cnino jarco"},
	nora{"cniri'a", "cinmo rinka"},
	nora{"cnisei", "cinmo sepli"},
	nora{"cnisni", "cinmo sinxa"},
	nora{"cnita'u", "cinmo taxfu"},
	nora{"crodri", "cortu badri"},
	nora{"crotsapi", "cortu tsapi"},
	nora{"crovu'i", "cortu vrusi"},
	nora{"cpadji", "cpacu djica"},
	nora{"selkemcpadji", "se ke cpacu djica"},
	nora{"cpatu'i", "cpacu tugni"},
	nora{"cpesku", "cpedu cusku"},
	nora{"cpinytsapi", "cpina tsapi"},
	nora{"cpizda", "cipni zdani"},
	nora{"cpumuvgau", "lacpu muvdu gasnu"},
	nora{"cradyvelcradi", "cradi ve cradi"},
	nora{"craku'a", "crane kumfa"},
	nora{"crale'u", "crane lerfu"},
	nora{"crapau", "crane pagbu"},
	nora{"crasfe", "crane sefta"},
	nora{"crastu", "crane stuzi"},
	nora{"cravro", "crane vorme"},
	nora{"crelei", "certu klesi"},
	nora{"cistcika", "crisa tcika"},
	nora{"crogla", "cortu glare"},
	nora{"crogle", "cortu gletu"},
	nora{"crori'a", "cortu rinka"},
	nora{"cruvei", "curmi vreji"},
	nora{"ctacarna", "catlu carna"},
	nora{"ctebixtei", "nicte binxo temci"},
	nora{"ctejau", "nicte djacu"},
	nora{"ctemanku", "nicte manku"},
	nora{"ctemurse", "nicte murse"},
	nora{"ctesai", "nicte sanmi"},
	nora{"cticinza", "citka cinza"},
	nora{"cticpe", "citka cpedu"},
	nora{"ctidakfu", "citka dakfu"},
	nora{"ctidji", "citka djica"},
	nora{"kamctidji", "ka citka djica"},
	nora{"ctigau", "citka gasnu"},
	nora{"ctiku'a", "citka kumfa"},
	nora{"ctilyvau", "ctile vasru"},
	nora{"ctinei", "citka nelci"},
	nora{"ctipla", "citka platu"},
	nora{"ctiru'e", "citka pruce"},
	nora{"ctiru'egau", "citka pruce gasnu"},
	nora{"ctisla", "citka salci"},
	nora{"ctitci", "citka tutci"},
	nora{"ctitcilu'i", "citka tutci lumci"},
	nora{"ctona'a", "xecto nanca"},
	nora{"ctucku", "ctuca cukta"},
	nora{"ctufau", "ctuca fasnu"},
	nora{"ctunoi", "ctuca notci"},
	nora{"ctutertcidu", "ctuca te tcidu"},
	nora{"cuxselgre", "cuxna se pagre"},
	nora{"cunyna'u", "cunso namcu"},
	nora{"cu'urzu'e", "cuntu zukte"},
	nora{"cucma'e", "cutci marce"},
	nora{"cucti'e", "cutci trixe"},
	nora{"cucycau", "cutci claxu"},
	nora{"cucyxelkla", "cutci xe klama"},
	nora{"cucyza'u", "cutci zargu"},
	nora{"cucyzbi", "cutci nazbi"},
	nora{"cukmakyvelvei", "cukla maksi ve vreji"},
	nora{"cukmu'o", "cukla mulno"},
	nora{"cukselba'a", "cukla se barna"},
	nora{"cuktai", "cukla tarmi"},
	nora{"cukygu'ivelvei", "cukla gusni ve vreji"},
	nora{"culcpe", "cumla cpedu"},
	nora{"cumselpei", "cumki se pensi"},
	nora{"cumymu'efi'a", "cumki munje cfika"},
	nora{"cundinkei", "cunso jdini kelci"},
	nora{"cunfaigau", "cunso fatri gasnu"},
	nora{"cunpe'i", "cunso penmi"},
	nora{"cupli'u", "clupa litru"},
	nora{"cuxtinbe", "cuxna tinbe"},
	nora{"da'acre", "damba certu"},
	nora{"da'erca'u", "danre canlu"},
	nora{"dabja'a", "damba jatna"},
	nora{"dabycalku", "damba calku"},
	nora{"dabysmifau", "damba simsa fasnu"},
	nora{"da'asnu", "damba casnu"},
	nora{"dadgau", "dandu gasnu"},
	nora{"dadgreku", "dandu greku"},
	nora{"dadne'ota'u", "dandu cnebo taxfu"},
	nora{"dadysli", "dandu slilu"},
	nora{"dafcpe", "danfu cpedu"},
	nora{"dafsku", "danfu cusku"},
	nora{"dagysfe", "dargu sefta"},
	nora{"dagytcityta'o", "dargu tcita tanbo"},
	nora{"dakyxa'i", "dakfu xarci"},
	nora{"daklycka", "dakli ckana"},
	nora{"dalcange", "danlu cange"},
	nora{"damfri", "danmo lifri"},
	nora{"damselzdi", "danmo se zdile"},
	nora{"damva'u", "danmo vasxu"},
	nora{"danlu'a", "danti pluta"},
	nora{"danvau", "danti vasru"},
	nora{"dapsku", "dapma cusku"},
	nora{"daptutra", "dapma tutra"},
	nora{"dapyda'i", "dapma darxi"},
	nora{"darctatci", "darno catlu tutci"},
	nora{"dagysni", "dargu sinxa"},
	nora{"darkla", "darno klama"},
	nora{"darbajra", "darno bajra"},
	nora{"darstuna", "darno stuna"},
	nora{"darsyli'u", "darsi litru"},
	nora{"darxa'u", "darno xabju"},
	nora{"daryra'i", "darno ranji"},
	nora{"daryri'a", "darno rinka"},
	nora{"daskybu'u", "daski bukpu"},
	nora{"spopli", "daspo pilno"},
	nora{"datcinglepre", "drata cinse gletu prenu"},
	nora{"datcinpampre", "drata cinse prami prenu"},
	nora{"datcinselta'u", "drata cinse se taxfu"},
	nora{"datklu", "drata kulnu"},
	nora{"datkypi'u", "datka pimlu"},
	nora{"datnyvau", "datni vasru"},
	nora{"datnyvaugunma", "datni vasru gunma"},
	nora{"datnyvei", "datni vreji"},
	nora{"datnyveiste", "datni vreji liste"},
	nora{"datpavycinglepre", "drata pa cinse gletu prenu"},
	nora{"datpavycinpampre", "drata pa cinse prami prenu"},
	nora{"datpre", "drata prenu"},
	nora{"datygu'e", "drata gugde"},
	nora{"datygugvi'e", "drata gugde vitke"},
	nora{"daupro", "darlu fapro"},
	nora{"daxfle", "darxi flecu"},
	nora{"dazmoipru", "da'a moi purci"},
	nora{"densrumikce", "denci sruri mikce"},
	nora{"densru", "denci sruri"},
	nora{"degja'i", "degji jadni"},
	nora{"degja'o", "degji jarco"},
	nora{"degycpu", "degji lacpu"},
	nora{"degyke'a", "degji kevna"},
	nora{"demcarvi", "denmi carvi"},
	nora{"demlanzu", "denmi lanzu"},
	nora{"demri'a", "denmi rinka"},
	nora{"demspa", "denmi spati"},
	nora{"demtse", "denmi zutse"},
	nora{"demxa'e", "denmi xance"},
	nora{"denmikce", "denci mikce"},
	nora{"densai", "denci sanmi"},
	nora{"denterjo'e", "denci te jorne"},
	nora{"denvanbi", "denci vanbi"},
	nora{"depcni", "denpa cinmo"},
	nora{"depri'a", "denpa rinka"},
	nora{"depstu", "denpa stuzi"},
	nora{"derba'o", "dertu banro"},
	nora{"derjbe", "dertu jbena"},
	nora{"derni'a", "dertu cnita"},
	nora{"derni'agau", "dertu cnita gasnu"},
	nora{"dersfe", "dertu sefta"},
	nora{"desygau", "desku gasnu"},
	nora{"detcartu", "detri cartu"},
	nora{"detcku", "detri cukta"},
	nora{"detke'u", "detri krefu"},
	nora{"detyselylacri", "detri se lacri"},
	nora{"di'esna", "dirce sance"},
	nora{"dijypanka", "dinju panka"},
	nora{"dibdji", "dirba djica"},
	nora{"dibrai", "dirba traji"},
	nora{"dibzda", "dirba zdani"},
	nora{"dicfatka'u", "dikca fatne kantu"},
	nora{"dicfle", "dikca flecu"},
	nora{"dicka'u", "dikca kantu"},
	nora{"dicka'udenmi", "dikca kantu denmi"},
	nora{"dicka'ujdika", "dikca kantu jdika"},
	nora{"dicka'uze'a", "dikca kantu zenba"},
	nora{"dirtadji", "dicra tadji"},
	nora{"dicycau", "dikca claxu"},
	nora{"dicydenmi", "dikca denmi"},
	nora{"dicyjdika", "dikca jdika"},
	nora{"dicysro", "dikca sorcu"},
	nora{"digyligykamju", "dirgo sligu kamju"},
	nora{"dijbartu", "dinju bartu"},
	nora{"dijlu'a", "dinju pluta"},
	nora{"dijysenta", "dinju senta"},
	nora{"dikle'i", "dikni pleji"},
	nora{"dikcaigu'i", "dikni carmi gusni"},
	nora{"dikydemgu'i", "dikni denmi gusni"},
	nora{"diktau", "dikni tanru"},
	nora{"diktcika", "dikni tcika"},
	nora{"dikyjvo", "dikni lujvo"},
	nora{"dimcei", "dimna cevni"},
	nora{"dimri'a", "dimna rinka"},
	nora{"dincpa", "jdini cpacu"},
	nora{"dinpa'i", "jdini prami"},
	nora{"dinseldu'a", "jdini se dunda"},
	nora{"dinselxaksu", "jdini se xaksu"},
	nora{"dinske", "jdini saske"},
	nora{"dinsro", "jdini sorcu"},
	nora{"dintro", "jdini jitro"},
	nora{"di'idji", "jdini djica"},
	nora{"dirsno", "dicra masno"},
	nora{"dzimuvgau", "dizlo muvdu gasnu"},
	nora{"dzirai", "dizlo traji"},
	nora{"dzitricu", "dizlo tricu"},
	nora{"djabei", "cidja bevri"},
	nora{"djabeipre", "cidja bevri prenu"},
	nora{"djacautsi", "cidja claxu tsiju"},
	nora{"djacpi", "cidja cipni"},
	nora{"jausna", "djacu sance"},
	nora{"djagru", "cidja gurni"},
	nora{"djaruntygau", "cidja runta gasnu"},
	nora{"djaselcrepu", "cidja se crepu"},
	nora{"djaspi", "cidja spisa"},
	nora{"djave'u", "cidja vecnu"},
	nora{"djecitsi", "djedi citsi"},
	nora{"djecitsi", "djedi citsi"},
	nora{"djerolmeicabrefkai", "djedi ro mei cabna krefu ckaji"},
	nora{"djekarni", "djedi karni"},
	nora{"djetei", "djedi temci"},
	nora{"djunoi", "sidju notci"},
	nora{"dotygu'e", "dotco gugde"},
	nora{"donma'o", "do cmavo"},
	nora{"dormidju", "donri midju"},
	nora{"dormijbalvi", "donri midju balvi"},
	nora{"dormijysai", "donri midju sanmi"},
	nora{"drabai", "drani bapli"},
	nora{"dracydi'u", "draci dinju"},
	nora{"dracystu", "draci stuzi"},
	nora{"draga'i", "drani galfi"},
	nora{"draga'igau", "drani galfi gasnu"},
	nora{"drarajytse", "drani sraji zutse"},
	nora{"drari'a", "drani rinka"},
	nora{"draseltai", "drani se tarmi"},
	nora{"datyzu'e", "drata zukte"},
	nora{"driselsa'a", "badri se sanga"},
	nora{"dritrasma", "badri tarti smaji"},
	nora{"drutapla", "drudi tapla"},
	nora{"du'ecla", "dukse clani"},
	nora{"dusyda'o", "dukse darno"},
	nora{"dusyva'u", "dukse vasxu"},
	nora{"dunjbi", "dunli jibni"},
	nora{"dubjavmau", "du ja zmadu"},
	nora{"dubjavme'a", "du ja mleca"},
	nora{"dudnei", "dunda nelci"},
	nora{"dugyste", "dugri liste"},
	nora{"dujyca'a", "dunja cabra"},
	nora{"dujyku'a", "dunja kumfa"},
	nora{"dukri'a", "dunku rinka"},
	nora{"dutsinso", "dukti sinso"},
	nora{"dukyba'u", "dunku bacru"},
	nora{"dusnei", "dukse nelci"},
	nora{"dusta'i", "dukse tatpi"},
	nora{"dusto'u", "dukse tordu"},
	nora{"dusydarsi", "dukse darsi"},
	nora{"dutpi'i", "dukti pilji"},
	nora{"dutydikca", "dukti dikca"},
	nora{"dzeko'o", "dzena skoto"},
	nora{"dzispa", "dizlo spati"},
	nora{"dzugre", "cadzu pagre"},
	nora{"dzukansa", "cadzu kansa"},
	nora{"dzukla", "cadzu klama"},
	nora{"dzuklaji", "cadzu klaji"},
	nora{"dzupoikansa", "cadzu porsi kansa"},
	nora{"fatydu'i", "fatne dunli"},
	nora{"fatpo'a", "fatne spoja"},
	nora{"fatytisygau", "fatne tisna gasnu"},
	nora{"fadme'e", "fadni cmene"},
	nora{"fagdirpre", "fagri dicra prenu"},
	nora{"fagycfatci", "fagri cfari tutci"},
	nora{"fagyfesti", "fagri festi"},
	nora{"fagyfesyska", "fagri festi skari"},
	nora{"fagyfesyvau", "fagri festi vasru"},
	nora{"fagyka'u", "fagri kantu"},
	nora{"fagysti", "fagri sisti"},
	nora{"fagystigau", "fagri sisti gasnu"},
	nora{"fagytergu'i", "fagri te gusni"},
	nora{"fairbei", "fatri bevri"},
	nora{"falbu'u", "farlu bukpu"},
	nora{"falcru", "farlu curmi"},
	nora{"fanbu'u", "falnu bukpu"},
	nora{"famdakfu", "fanmo dakfu"},
	nora{"famfa'o", "fanmo fanmo"},
	nora{"famyma'o", "fanmo cmavo"},
	nora{"fancyju'a", "fancu jufra"},
	nora{"fankla", "falnu klama"},
	nora{"fanvyca'a", "fanva cabra"},
	nora{"fanvyca'ate'i", "fanva cabra steci"},
	nora{"fancyju'a", "fancu jufra"},
	nora{"farcne", "farna cenba"},
	nora{"fargau", "farna gasnu"},
	nora{"farja'o", "farna jarco"},
	nora{"fasygu'e", "fraso gugde"},
	nora{"fatna'u", "fatne namcu"},
	nora{"faurju'a", "fasnu jufra"},
	nora{"faurpai", "fasnu pajni"},
	nora{"favgau", "farvi gasnu"},
	nora{"faxri'a", "fraxu rinka"},
	nora{"fazykei", "fanza kelci"},
	nora{"fazyta'a", "fanza tavla"},
	nora{"febgau", "febvi gasnu"},
	nora{"fegba'u", "fengu bacru"},
	nora{"fegba'ugunta", "fengu bacru gunta"},
	nora{"fegboixa'e", "fengu bolci xance"},
	nora{"fegycau", "fengu claxu"},
	nora{"fekpre", "fenki prenu"},
	nora{"fekri'a", "fenki rinka"},
	nora{"fekygei", "fenki gleki"},
	nora{"fengidmo'a", "fenso gidva morna"},
	nora{"fepsi'i", "fepni sicni"},
	nora{"fesydai", "festi dacti"},
	nora{"fetcinfo", "fetsi cinfo"},
	nora{"fetci'o", "fetsi citno"},
	nora{"fetnalspe", "fetsi na'e speni"},
	nora{"fetno'i", "fetsi nobli"},
	nora{"fetnolraitru", "fetsi nobli traji turni"},
	nora{"fetpe'o", "fetsi pendo"},
	nora{"fetpa'i", "fetsi prami"},
	nora{"fetspe", "fetsi speni"},
	nora{"fetyganti", "fetsi ganti"},
	nora{"ficri'a", "frica rinka"},
	nora{"fikcku", "cfika cukta"},
	nora{"filri'a", "frili rinka"},
	nora{"filseljmi", "frili se jimpe"},
	nora{"filselzga", "frili se zgana"},
	nora{"finfriti", "finti friti"},
	nora{"fipybirka", "finpe birka"},
	nora{"fipfalnu", "finpe falnu"},
	nora{"fipyrebla", "finpe rebla"},
	nora{"finxu'a", "finti xusra"},
	nora{"fipcange", "finpe cange"},
	nora{"fipkalte", "finpe kalte"},
	nora{"firgai", "flira gacri"},
	nora{"firkre", "flira kerfa"},
	nora{"firkrevi'u", "flira kerfa vimcu"},
	nora{"firsku", "flira cusku"},
	nora{"flacau", "flalu claxu"},
	nora{"flanaltinbe", "flalu na'e tinbe"},
	nora{"flecarvi", "flecu carvi"},
	nora{"fleri'u", "flecu rinju"},
	nora{"fletisygau", "flecu tisna gasnu"},
	nora{"flobimvro", "foldi bitmu vorme"},
	nora{"flulimna", "fulta limna"},
	nora{"fomke'acirla", "fonmo kevna cirla"},
	nora{"fomsle", "fonmo selci"},
	nora{"fonsnu", "fonxa casnu"},
	nora{"fonjudri", "fonxa judri"},
	nora{"fonta'a", "fonxa tavla"},
	nora{"velfonynoi", "ve fonxa notci"},
	nora{"fonynoi", "fonxa notci"},
	nora{"fraba'u", "frati bacru"},
	nora{"fragu'i", "frati gusni"},
	nora{"frasku", "frati cusku"},
	nora{"frecande'u", "ferti canre dertu"},
	nora{"fregau", "ferti gasnu"},
	nora{"frerai", "ferti traji"},
	nora{"freri'a", "ferti rinka"},
	nora{"fi'ormerko", "friko merko"},
	nora{"fi'ortutra", "friko tutra"},
	nora{"filmau", "frili zmadu"},
	nora{"frinyna'u", "frinu namcu"},
	nora{"fu'ivla", "fukpi valsi"},
	nora{"fuzyji'i", "fuzme jinvi"},
	nora{"fuzyka'eji'i", "fuzme kakne jinvi"},
	nora{"fu'esku", "fuzme cusku"},
	nora{"ga'acpu", "grana lacpu"},
	nora{"ga'arxa'i", "grana xarci"},
	nora{"ga'avro", "grana vorme"},
	nora{"ga'orbi'o", "ganlo binxo"},
	nora{"ga'orga'i", "ganlo galfi"},
	nora{"ga'orgau", "ganlo gasnu"},
	nora{"galcla", "galtu clani"},
	nora{"gafto'a", "galfi tonga"},
	nora{"gafto'atci", "galfi tonga tutci"},
	nora{"gafygau", "galfi gasnu"},
	nora{"ga'izba", "galfi zbasu"},
	nora{"gairbu'u", "gacri bukpu"},
	nora{"gairgau", "gacri gasnu"},
	nora{"gairja'i", "gacri jadni"},
	nora{"gairki'e", "gacri kicne"},
	nora{"gairkosta", "gacri kosta"},
	nora{"galbirka", "galtu birka"},
	nora{"galmau", "galtu zmadu"},
	nora{"galpau", "galtu pagbu"},
	nora{"galrai", "galtu traji"},
	nora{"galsu'a", "galtu stura"},
	nora{"galtu'e", "galtu tuple"},
	nora{"gancuktai", "ganra cukla tarmi"},
	nora{"ganle'u", "ganra lerfu"},
	nora{"gankurfa", "ganra kurfa"},
	nora{"gapcpare", "gapru cpare"},
	nora{"gapcta", "gapru catlu"},
	nora{"gapkla", "gapru klama"},
	nora{"gapydzu", "gapru cadzu"},
	nora{"garka'afendi", "garna katna fendi"},
	nora{"gasfri", "ganse lifri"},
	nora{"gaurkalsa", "gasnu kalsa"},
	nora{"gaxmolgle", "ganxo moklu gletu"},
	nora{"gaxygle", "ganxo gletu"},
	nora{"gaxykafke", "ganxo kafke"},
	nora{"gendra", "gerna drani"},
	nora{"geipre", "gleki prenu"},
	nora{"geirde'a", "gleki denpa"},
	nora{"geirgau", "gleki gasnu"},
	nora{"geirxe'o", "gleki xendo"},
	nora{"geizma", "gleki zmadu"},
	nora{"gekcisma", "gleki cisma"},
	nora{"gekpanpi", "gleki panpi"},
	nora{"gekrai", "gleki traji"},
	nora{"geirki'a", "gleki krixa"},
	nora{"genlalske", "gerna lanli saske"},
	nora{"gensu'a", "gerna stura"},
	nora{"genturfa'i", "gerna stura facki"},
	nora{"gercmo", "gerku cmoni"},
	nora{"gerpre", "gerku prenu"},
	nora{"gerzda", "gerku zdani"},
	nora{"gimste", "gismu liste"},
	nora{"glinai", "glico natmi"},
	nora{"glige'a", "glico gerna"},
	nora{"glivla", "glico valsi"},
	nora{"gincilta", "jgina cilta"},
	nora{"ginlazmi'u", "jgina lanzu mintu"},
	nora{"ginpoi", "jgina porsi"},
	nora{"grinunpei", "girzu nu pensi"},
	nora{"grisa'a", "girzu sanga"},
	nora{"griselpei", "girzu se pensi"},
	nora{"grivlici'e", "girzu vlipa ciste"},
	nora{"gimlebvla", "gismu lebna valsi"},
	nora{"gitsko", "jgita skori"},
	nora{"glacai", "glare carmi"},
	nora{"glagau", "glare gasnu"},
	nora{"glari'a", "glare rinka"},
	nora{"glaxlafri", "glare xlali lifri"},
	nora{"gledji", "gletu djica"},
	nora{"glefi'a", "gletu cfika"},
	nora{"gletci", "gletu tutci"},
	nora{"gletro", "gletu jitro"},
	nora{"glevi'i", "gletu vikmi"},
	nora{"glibau", "glico bangu"},
	nora{"glibaukragu'e", "glico bangu krasi gugde"},
	nora{"gligu'e", "glico gugde"},
	nora{"glikragu'e", "glico krasi gugde"},
	nora{"glimerko", "glico merko"},
	nora{"ga'ardanti", "grana danti"},
	nora{"ga'ardance'a", "grana danti cecla"},
	nora{"grebe'i", "pagre benji"},
	nora{"greblo", "pagre bloti"},
	nora{"greblopre", "pagre bloti prenu"},
	nora{"grece'i", "pagre cteki"},
	nora{"gregau", "pagre gasnu"},
	nora{"greke'a", "pagre kevna"},
	nora{"grile'u", "girzu lerfu"},
	nora{"grinunjvi", "girzu nu jivna"},
	nora{"gripau", "girzu pagbu"},
	nora{"grusko", "gurni skori"},
	nora{"rutytricu", "grute tricu"},
	nora{"gunstu", "gunka stuzi"},
	nora{"gugypa'i", "gugde prami"},
	nora{"guryre'o", "gunro renro"},
	nora{"gurgau", "gunro gasnu"},
	nora{"gubgau", "gubni gasnu"},
	nora{"gubnoi", "gubni notci"},
	nora{"gubnunsnu", "gubni nu casnu"},
	nora{"gubyternoi", "gubni te notci"},
	nora{"gugbandu", "gugde bandu"},
	nora{"gugyka'i", "gugde krati"},
	nora{"gukcanre", "guska canre"},
	nora{"gumpe'i", "gunma penmi"},
	nora{"gungri", "gunka girzu"},
	nora{"gunku'a", "gunka kumfa"},
	nora{"gurcutci", "gunro cutci"},
	nora{"gructi", "gurni citka"},
	nora{"gusminra", "gusni minra"},
	nora{"gustci", "gusni tutci"},
	nora{"gusyvelvei", "gusni ve vreji"},
	nora{"gustytigni", "gusta tigni"},
	nora{"gusycai", "gusni carmi"},
	nora{"ja'esni", "jalge sinxa"},
	nora{"ja'orca'o", "jarco canko"},
	nora{"ja'urjukni", "jgalu jukni"},
	nora{"jabytu'u", "janbe tubnu"},
	nora{"jacke'o", "djacu kelvo"},
	nora{"jaclu'a", "djacu pluta"},
	nora{"jacnalselgre", "djacu na'e se pagre"},
	nora{"jaurca'ega'a", "djacu catke grana"},
	nora{"jaurde'u", "djacu dertu"},
	nora{"jaurdirgo", "djacu dirgo"},
	nora{"jaurvi'u", "djacu vimcu"},
	nora{"jadnoi", "jadni notci"},
	nora{"jadycau", "jadni claxu"},
	nora{"jadypijne", "jadni pijne"},
	nora{"jmatamji", "jamfu tamji"},
	nora{"jmatajycalku", "jamfu tamji calku"},
	nora{"jmati'e", "jamfu trixe"},
	nora{"jagdimna", "jalge dimna"},
	nora{"jagdimnalpei", "jalge dimna na'e pensi"},
	nora{"jairxa'e", "jgari xance"},
	nora{"jajgau", "jmaji gasnu"},
	nora{"jakcai", "jarki carmi"},
	nora{"jakle'u", "jarki lerfu"},
	nora{"jamkansa", "jamna kansa"},
	nora{"jarcinki", "jdari cinki"},
	nora{"jarkitybli", "jdari kliti bliku"},
	nora{"jarple", "jdari pelji"},
	nora{"jarpu'i", "jdari punji"},
	nora{"jaryri'a", "jdari rinka"},
	nora{"seljaryri'a", "se jdari rinka"},
	nora{"jasysnu", "jansu casnu"},
	nora{"jaurbumru", "djacu bumru"},
	nora{"jaurcarna", "djacu carna"},
	nora{"jaurda'i", "djacu darxi"},
	nora{"jaurde'uro'i", "djacu dertu rokci"},
	nora{"jacfa'u", "djacu farlu"},
	nora{"jaurgairi'a", "djacu gacri rinka"},
	nora{"jaurgapci", "djacu gapci"},
	nora{"jaurmabru", "djacu mabru"},
	nora{"jaurselylu'i", "djacu se lumci"},
	nora{"jaurvacri", "djacu vacri"},
	nora{"jbebe'a", "jbena bersa"},
	nora{"jbedei", "jbena djedi"},
	nora{"jbedetnunsla", "jbena detri nu salci"},
	nora{"jbedetsla", "jbena detri salci"},
	nora{"jbesla", "jbena salci"},
	nora{"jbetcaxa'u", "jbena tcadu xabju"},
	nora{"jbetutra", "jbena tutra"},
	nora{"jbibi'o", "jibni binxo"},
	nora{"jbidra", "jibni drani"},
	nora{"jbigendra", "jibni gerna drani"},
	nora{"jbikla", "jibni klama"},
	nora{"jbimau", "jibni zmadu"},
	nora{"jbirai", "jibni traji"},
	nora{"jbire'a", "jibni remna"},
	nora{"jbixa'u", "jibni xabju"},
	nora{"jbota'a", "lojbo tavla"},
	nora{"jbobauta'a", "lojbo bangu tavla"},
	nora{"jbobau", "lojbo bangu"},
	nora{"jboce'u", "lojbo cecmu"},
	nora{"jbofinpla", "lojbo finti platu"},
	nora{"jbofonta'a", "lojbo fonxa tavla"},
	nora{"jboge'a", "lojbo gerna"},
	nora{"jbogri", "lojbo girzu"},
	nora{"jbogu'a", "lojbo gunka"},
	nora{"jbojikca", "lojbo jikca"},
	nora{"jbomi'u", "lojbo mintu"},
	nora{"jbomidju", "lojbo midju"},
	nora{"jbonunsku", "lojbo nu cusku"},
	nora{"jbopre", "lojbo prenu"},
	nora{"jbosla", "lojbo salci"},
	nora{"seljbosla", "se lojbo salci"},
	nora{"jboselba'u", "lojbo se bacru"},
	nora{"jboselsku", "lojbo se cusku"},
	nora{"jboslanunpe'i", "lojbo salci nu penmi"},
	nora{"jbosni", "lojbo sinxa"},
	nora{"jboste", "lojbo liste"},
	nora{"jbotcidu", "lojbo tcidu"},
	nora{"jbotermri", "lojbo te mrilu"},
	nora{"jbovla", "lojbo valsi"},
	nora{"jboxelmri", "lojbo xe mrilu"},
	nora{"jbozi'u", "lojbo zirpu"},
	nora{"jbuboikei", "jubme bolci kelci"},
	nora{"jbusfe", "jubme sefta"},
	nora{"jbustu", "jubme stuzi"},
	nora{"jdace'u", "lijda cecmu"},
	nora{"jdacuvgau", "lijda curve gasnu"},
	nora{"jdadapma", "lijda dapma"},
	nora{"jdajinru", "lijda jinru"},
	nora{"jdaka'i", "lijda krati"},
	nora{"jdami'u", "lijda mintu"},
	nora{"jdapli", "lijda pilno"},
	nora{"jdaralju", "lijda ralju"},
	nora{"jdaselsa'a", "lijda se sanga"},
	nora{"jdaselsku", "lijda se cusku"},
	nora{"jdasi'a", "lijda sinma"},
	nora{"jdasku", "lijda cusku"},
	nora{"jdaskuzei", "lijda cusku zekri"},
	nora{"jdasoi", "lijda sonci"},
	nora{"jdaxanmuvgau", "lijda xance muvdu gasnu"},
	nora{"jdazei", "lijda zekri"},
	nora{"jdecisma", "kajde cisma"},
	nora{"jdeselsku", "kajde se cusku"},
	nora{"jdigu'a", "jdice gunka"},
	nora{"jdikyri'a", "jdika rinka"},
	nora{"jditadji", "jdice tadji"},
	nora{"jdufi'e", "jduli finpe"},
	nora{"jectrukamni", "jecta turni kamni"},
	nora{"jecydinsro", "jecta jdini sorcu"},
	nora{"jecyga'ibai", "jecta galfi bapli"},
	nora{"jecyga'ibaigau", "jecta galfi bapli gasnu"},
	nora{"jecpau", "jecta pagbu"},
	nora{"jecyselpo'e", "jecta se ponse"},
	nora{"jecyselpo'ega'i", "jecta se ponse galfi"},
	nora{"jecyselxaizei", "jecta se xrani zekri"},
	nora{"jefyfa'o", "jeftu fanmo"},
	nora{"jelgau", "jelca gasnu"},
	nora{"jelgauca'a", "jelca gasnu cabra"},
	nora{"jelspo", "jelca daspo"},
	nora{"jempau", "jenmi pagbu"},
	nora{"jercru", "jbera curmi"},
	nora{"jerle'i", "jbera pleji"},
	nora{"jesycro", "jesni cortu"},
	nora{"jesyspa", "jesni spati"},
	nora{"jetfa'i", "jetnu facki"},
	nora{"jetka'u", "jetnu kantu"},
	nora{"jetka'ubivmei", "jetnu kantu bi mei"},
	nora{"jetpai", "jetnu pajni"},
	nora{"jetycipra", "jetnu cipra"},
	nora{"jgarau", "jganu gradu"},
	nora{"jgene'ota'u", "jgena cnebo taxfu"},
	nora{"jgiski", "jgira skicu"},
	nora{"jgisku", "jgira cusku"},
	nora{"ji'ecla", "jmive clani"},
	nora{"ji'efri", "jmive lifri"},
	nora{"selji'efri", "se jmive lifri"},
	nora{"ji'epru", "jmive purci"},
	nora{"ji'esti", "jmive sisti"},
	nora{"ji'icni", "jinvi cinmo"},
	nora{"ji'isku", "jinvi cusku"},
	nora{"jibgu'a", "jibri gunka"},
	nora{"jibja'a", "jibri jatna"},
	nora{"jibypli", "jibri pilno"},
	nora{"jibysti", "jibri sisti"},
	nora{"jibystigau", "jibri sisti gasnu"},
	nora{"jifselkri", "jitfa se krici"},
	nora{"jifsku", "jitfa cusku"},
	nora{"jifyjovnarje'u", "jitfa jo na jetnu"},
	nora{"jiglanxe", "jinga lanxe"},
	nora{"jikybebna", "jikca bebna"},
	nora{"jikce'u", "jikca cecmu"},
	nora{"jikfanza", "jikca fanza"},
	nora{"jikfazgau", "jikca fanza gasnu"},
	nora{"jiknei", "jikca nelci"},
	nora{"jikri'i", "jikca ritli"},
	nora{"jikri'ipro", "jikca ritli fapro"},
	nora{"jiksre", "jikca srera"},
	nora{"jiktamne", "jikca tamne"},
	nora{"jikydu'i", "jikca dunli"},
	nora{"jikyju'o", "jikca djuno"},
	nora{"jikyzeitra", "jikca zekri tarti"},
	nora{"jimcai", "jinme carmi"},
	nora{"jimda'izbe", "jinme darxi zbepi"},
	nora{"jimdaxsna", "jinme darxi sance"},
	nora{"jimto'a", "jinme tonga"},
	nora{"jincarna", "djine carna"},
	nora{"jincla", "djine clani"},
	nora{"jirgau", "jinru gasnu"},
	nora{"jintitnanba", "djine titla nanba"},
	nora{"jintydi'u", "jinto dinju"},
	nora{"jipmokca", "jipno mokca"},
	nora{"jirlu'i", "jinru lumci"},
	nora{"jirsezlu'i", "jinru sevzi lumci"},
	nora{"jisygau", "jinsa gasnu"},
	nora{"jisysa'e", "jinsa satre"},
	nora{"jivrei", "jinvi preti"},
	nora{"jizvanbi", "jinzi vanbi"},
	nora{"jmadegji", "jamfu degji"},
	nora{"jmadegycalku", "jamfu degji calku"},
	nora{"jmavra", "jamfu vraga"},
	nora{"jmeja'i", "jemna jadni"},
	nora{"jmekunra", "jemna kunra"},
	nora{"cakyjmepi'a", "calku jemna pilka"},
	nora{"jmero'i", "jemna rokci"},
	nora{"jmigau", "jimpe gasnu"},
	nora{"jmimau", "jimpe zmadu"},
	nora{"mivyselna'a", "jmive se nanca"},
	nora{"jomcmi", "jo'e cmima"},
	nora{"jonja'e", "jorne jalge"},
	nora{"jonjmina", "jorne jmina"},
	nora{"jonma'o", "jorne cmavo"},
	nora{"ju'itra", "jundi tarti"},
	nora{"judri'a", "jundi rinka"},
	nora{"judzga", "jundi zgana"},
	nora{"jufsu'a", "jufra stura"},
	nora{"ju'agri", "jufra girzu"},
	nora{"jugyklu", "jungo kulnu"},
	nora{"julra'o", "junla radno"},
	nora{"junbe'i", "djuno benji"},
	nora{"jungau", "djuno gasnu"},
	nora{"junri'a", "djuno rinka"},
	nora{"juryri'a", "junri rinka"},
	nora{"juntytri", "junta trina"},
	nora{"jupfi'i", "jukpa finti"},
	nora{"jupku'a", "jukpa kumfa"},
	nora{"jupyzba", "jukpa zbasu"},
	nora{"jurdri", "junri badri"},
	nora{"jurja'o", "junri jarco"},
	nora{"jvajvo", "javni lujvo"},
	nora{"jvige'u", "jivna gerku"},
	nora{"veljvine'u", "ve jivna cnemu"},
	nora{"jvipai", "jivna pajni"},
	nora{"jvixi'a", "jivna xirma"},
	nora{"jvoste", "lujvo liste"},
	nora{"jvozba", "lujvo zbasu"},
	nora{"ka'amru", "katna mruli"},
	nora{"ka'anri'a", "katna rinka"},
	nora{"ka'arkakpa", "katna kakpa"},
	nora{"ka'arkomcu", "katna komcu"},
	nora{"ka'arvi'u", "katna vimcu"},
	nora{"ka'inruxpre", "krati pruxi prenu"},
	nora{"ka'urbi'o", "kantu binxo"},
	nora{"kabryca'u", "kabri canlu"},
	nora{"kabrylai", "kabri klani"},
	nora{"kabryselmre", "kabri se merli"},
	nora{"kacna'u", "kancu namcu"},
	nora{"kadnymergli", "kadno merko glico"},
	nora{"kadyto'a", "kandi tonga"},
	nora{"kadyto'atci", "kandi tonga tutci"},
	nora{"kafkytrofli", "kafke jitro fliba"},
	nora{"kafybarja", "ckafi barja"},
	nora{"kagycange", "kagni cange"},
	nora{"kagytrocange", "kagni jitro cange"},
	nora{"kairpai", "ckaji pajni"},
	nora{"kakpyca'a", "kakpa cabra"},
	nora{"kakmli", "klaku milxe"},
	nora{"kalgai", "kanla gacri"},
	nora{"kalgaikre", "kanla gacri kerfa"},
	nora{"karsna", "kalri sance"},
	nora{"kalselvi'i", "kanla se vikmi"},
	nora{"kasydzu", "kalsa cadzu"},
	nora{"kasfle", "kalsa flecu"},
	nora{"kasygri", "kalsa girzu"},
	nora{"kaskla", "kalsa klama"},
	nora{"kasri'a", "kalsa rinka"},
	nora{"kasystu", "kalsa stuzi"},
	nora{"kasysu'a", "kalsa stura"},
	nora{"kalvi'i", "kanla vikmi"},
	nora{"kambitki'u", "ka birti krinu"},
	nora{"kamcemtamne", "ka cecmu tamne"},
	nora{"kamgubga'i", "ka gubni galfi"},
	nora{"kamgubgau", "ka gubni gasnu"},
	nora{"kamje'uja'o", "ka jetnu jarco"},
	nora{"kamjybo'u", "kamju bongu"},
	nora{"kamjybo'usle", "kamju bongu selci"},
	nora{"kamna'ujbi", "ka namcu jibni"},
	nora{"kamnynunpe'i", "kamni nu penmi"},
	nora{"kampavyselmanri", "ka pa se manri"},
	nora{"kampeikai", "ka pensi ckaji"},
	nora{"kamsorselmanri", "ka so'i se manri"},
	nora{"kamyzanfu'a", "ka zabna funca"},
	nora{"kankei", "kansa kelci"},
	nora{"kelkansa", "kelci kansa"},
	nora{"kankla", "kansa klama"},
	nora{"ka'ozma", "kanro zmadu"},
	nora{"ka'orze'a", "kanro zenba"},
	nora{"kanydzu", "kansa cadzu"},
	nora{"kanzutla'i", "kansa zutse lamji"},
	nora{"kapsle", "skapi selci"},
	nora{"kapta'u", "skapi taxfu"},
	nora{"kapyplita", "skapi plita"},
	nora{"karbi'o", "kalri binxo"},
	nora{"karcykla", "karce klama"},
	nora{"karcyli'u", "karce litru"},
	nora{"karcylu'a", "karce pluta"},
	nora{"karcymuvgau", "karce muvdu gasnu"},
	nora{"kargau", "kalri gasnu"},
	nora{"karmolcinba", "kalri moklu cinba"},
	nora{"karnyfi'u", "karni cfipu"},
	nora{"karnyke'u", "karni krefu"},
	nora{"karnypra", "karni cupra"},
	nora{"karnysku", "karni cusku"},
	nora{"karpo'i", "kalri porpi"},
	nora{"katcpi", "kalte cipni"},
	nora{"katstu", "kalte stuzi"},
	nora{"kaurpo'esi'opre", "kampu ponse sidbo prenu"},
	nora{"refcfa", "krefu cfari"},
	nora{"refcpa", "krefu cpacu"},
	nora{"kelbe'e", "kelci bende"},
	nora{"keiblo", "kelci bloti"},
	nora{"keicre", "kelci certu"},
	nora{"keldai", "kelci dacti"},
	nora{"keigri", "kelci girzu"},
	nora{"kelgrimi'u", "kelci girzu mintu"},
	nora{"kelkarda", "kelci karda"},
	nora{"kelkubli", "kelci kubli"},
	nora{"kelpi'e", "kelci plipe"},
	nora{"keipro", "kelci fapro"},
	nora{"kelsnada", "kelci snada"},
	nora{"keizdi", "kelci zdile"},
	nora{"selkeizdi", "se kelci zdile"},
	nora{"kercrida", "kerlo crida"},
	nora{"kercrori'a", "kerlo cortu rinka"},
	nora{"krekandi", "kerfa kandi"},
	nora{"kerjbikre", "kerlo jibni kerfa"},
	nora{"kesli'ufi'a", "kensa litru cfika"},
	nora{"kevykakpa", "kevna kakpa"},
	nora{"kevykalri", "kevna kalri"},
	nora{"kevykargau", "kevna kalri gasnu"},
	nora{"kevzda", "kevna zdani"},
	nora{"kixsku", "krixa cusku"},
	nora{"ki'ijdi", "ckini jdice"},
	nora{"ki'orgratretrefrinynidysnidu", "kilto grake mitre mitre frinu snidu snidu"},
	nora{"skebailai", "saske bapli klani"}, // Noralujv was *wrong*!
	nora{"ki'orsamsrorau", "kilto skami sorcu gradu"},
	nora{"ki'otre", "kilto mitre"},
	nora{"kicymatci", "kicne matci"},
	nora{"kijyselspo", "kijno se daspo"},
	nora{"kikla'a", "ckiku lasna"},
	nora{"kilcna", "kinli canpa"},
	nora{"kilga'a", "kinli grana"},
	nora{"kilga'axa'i", "kinli grana xarci"},
	nora{"kilmru", "kinli mruli"},
	nora{"kiltci", "kinli tutci"},
	nora{"kindi'u", "skina dinju"},
	nora{"kinplapre", "skina platu prenu"},
	nora{"kityzba", "kliti zbasu"},
	nora{"selkityzba", "se kliti zbasu"},
	nora{"klacpe", "klama cpedu"},
	nora{"kladji", "klama djica"},
	nora{"selkladji", "se klama djica"},
	nora{"klagau", "klama gasnu"},
	nora{"klakansa", "klama kansa"},
	nora{"kakydirgo", "klaku dirgo"},
	nora{"kakyjau", "klaku djacu"},
	nora{"klamu'o", "klama mulno"},
	nora{"klasti", "klama sisti"},
	nora{"klastigau", "klama sisti gasnu"},
	nora{"leicmi", "klesi cmima"},
	nora{"klecmiri'a", "klesi cmima rinka"},
	nora{"klemi'u", "klesi mintu"},
	nora{"klerafsi", "klesi rafsi"},
	nora{"kligau", "klina gasnu"},
	nora{"tolkligau", "to'e klina gasnu"},
	nora{"kalselklijmi", "kanla se klina jimpe"},
	nora{"klode'a", "diklo denpa"},
	nora{"klunu'i", "kulnu nutli"},
	nora{"klusmu", "kulnu smuni"},
	nora{"kluzei", "kulnu zekri"},
	nora{"kotygu'e", "skoto gugde"},
	nora{"komnicygau", "komcu cnici gasnu"},
	nora{"koncuptai", "konju clupa tarmi"},
	nora{"kosne'ota'u", "kosta cnebo taxfu"},
	nora{"kosycreka", "kosta creka"},
	nora{"krastu", "krasi stuzi"},
	nora{"kreblabi", "kerfa blabi"},
	nora{"krecau", "kerfa claxu"},
	nora{"kreka'apre", "kerfa katna prenu"},
	nora{"krekemburpelxu", "kerfa ke bunre pelxu"},
	nora{"krepelxu", "kerfa pelxu"},
	nora{"kriselsku", "krici se cusku"},
	nora{"kroce'a", "korcu cecla"},
	nora{"krogarna", "korcu garna"},
	nora{"krokurfa", "korcu kurfa"},
	nora{"kroranda", "korcu randa"},
	nora{"krori'a", "korcu rinka"},
	nora{"kroxadjbi", "korcu xadni jibni"},
	nora{"krudakyxa'i", "kruvi dakfu xarci"},
	nora{"kubykurfa", "kubli kurfa"},
	nora{"kuctai", "kruca tarmi"},
	nora{"kucyga'a", "kruca grana"},
	nora{"kukydja", "kukte cidja"},
	nora{"kuncpastu", "kunra cpacu stuzi"},
	nora{"kurkubli", "kurfa kubli"},
	nora{"kurtre", "kurfa mitre"},
	nora{"kusyja'a", "kusru jatna"},
	nora{"kuzycmi", "ku'a cmima"},
	nora{"la'agle", "lasna gletu"},
	nora{"la'arjai", "lasna jgari"},
	nora{"la'enri'a", "lakne rinka"},
	nora{"la'erme'a", "lakne mleca"},
	nora{"la'ornai", "latmo natmi"},
	nora{"labypiltricu", "blabi pilka tricu"},
	nora{"labyxu'e", "blabi xunre"},
	nora{"lactcicygau", "lacri tcica gasnu"},
	nora{"ladycange", "ladru cange"},
	nora{"ladyfaigau", "ladru fatri gasnu"},
	nora{"lafcpa", "lafti cpacu"},
	nora{"lafmuvgau", "lafti muvdu gasnu"},
	nora{"lagnirbakfu", "vlagi nirna bakfu"},
	nora{"lagygasrango", "vlagi ganse rango"},
	nora{"lagypinji", "vlagi pinji"},
	nora{"lagypunli", "vlagi punli"},
	nora{"lagyselkukrango", "vlagi se kukte rango"},
	nora{"lairdu'i", "klani dunli"},
	nora{"lairpai", "klani pajni"},
	nora{"lajre'e", "klaji trene"},
	nora{"laktergu'i", "lakse te gusni"},
	nora{"lambavdei", "lamji balvi djedi"},
	nora{"lamgri", "lamji girzu"},
	nora{"slelamgri", "selci lamji girzu"},
	nora{"lamjeftu", "lamji jeftu"},
	nora{"lampru", "lamji purci"},
	nora{"lamprudo'i", "lamji purci donri"},
	nora{"lamxa'u", "lamji xabju"},
	nora{"lalcta", "lanli catlu"},
	nora{"cpumi'i", "lacpu minji"},
	nora{"larfi'i", "larcu finti"},
	nora{"larja'ostu", "larcu jarco stuzi"},
	nora{"larjdixau", "larcu jdice xamgu"},
	nora{"larjdixla", "larcu jdice xlali"},
	nora{"larku'a", "larcu kumfa"},
	nora{"larmuzga", "larcu muzga"},
	nora{"larsku", "larcu cusku"},
	nora{"larxau", "larcu xamgu"},
	nora{"la'avla", "lasna valsi"},
	nora{"lasysilka", "slasi silka"},
	nora{"laurba'u", "cladu bacru"},
	nora{"laurbi'o", "cladu binxo"},
	nora{"laurckasu", "cladu ckasu"},
	nora{"laurgau", "cladu gasnu"},
	nora{"laurgauca'a", "cladu gasnu cabra"},
	nora{"laurxajmi", "cladu xajmi"},
	nora{"laurxampre", "cladu xajmi prenu"},
	nora{"lausku", "cladu cusku"},
	nora{"lauzma", "cladu zmadu"},
	nora{"laxli'i", "lanxe linji"},
	nora{"lazyki'i", "lanzu ckini"},
	nora{"lazmi'u", "lanzu mintu"},
	nora{"lazycange", "lanzu cange"},
	nora{"lazycmi", "lanzu cmima"},
	nora{"lazyzda", "lanzu zdani"},
	nora{"lebdji", "lebna djica"},
	nora{"lebyka'e", "lebna kakne"},
	nora{"lebvla", "lebna valsi"},
	nora{"lejbai", "pleji bapli"},
	nora{"lejyselmu'i", "pleji se mukti"},
	nora{"le'otci", "lenjo tutci"},
	nora{"lebri'a", "lebna rinka"},
	nora{"lecydo'i", "lerci donri"},
	nora{"lecydu'e", "lerci dukse"},
	nora{"lecysoltei", "lerci solri temci"},
	nora{"ledgrute", "mledi grute"},
	nora{"leivla", "klesi valsi"},
	nora{"lejypi'o", "pleji pipno"},
	nora{"lekta'e", "lenku tanxe"},
	nora{"lerlogji", "lerfu logji"},
	nora{"lerpoi", "lerfu porsi"},
	nora{"lerseltcidu", "lerfu se tcidu"},
	nora{"lervla", "lerfu valsi"},
	nora{"li'erbe'a", "lidne bersa"},
	nora{"li'erbu'a", "lidne bruna"},
	nora{"li'ergenja", "lidne genja"},
	nora{"li'urnei", "litru nelci"},
	nora{"li'urta'e", "litru tanxe"},
	nora{"lidbi'e", "lindi brife"},
	nora{"lidvru", "lindi savru"},
	nora{"friselku'e", "lifri se kuspe"},
	nora{"lijgri", "linji girzu"},
	nora{"lijvelsku", "linji ve cusku"},
	nora{"lijyselni'a", "linji se cnita"},
	nora{"lijysu'a", "linji stura"},
	nora{"likybi'o", "litki binxo"},
	nora{"likygau", "litki gasnu"},
	nora{"limkla", "limna klama"},
	nora{"limvra", "limna vraga"},
	nora{"lidysna", "lindi sance"},
	nora{"linga'axai", "linsi grana xrani"},
	nora{"lirgau", "clira gasnu"},
	nora{"lirmau", "clira zmadu"},
	nora{"liryrai", "clira traji"},
	nora{"lisku'a", "lisri kumfa"},
	nora{"lisnuntoi", "lisri nu troci"},
	nora{"listigni", "lisri tigni"},
	nora{"lisycku", "lisri cukta"},
	nora{"litli'avla", "clite cliva valsi"},
	nora{"livbai", "cliva bapli"},
	nora{"jbopli", "lojbo pilno"},
	nora{"lojbaugri", "logji bangu girzu"},
	nora{"lojbau", "logji bangu"},
	nora{"jbotadni", "lojbo tadni"},
	nora{"lojycipra", "logji cipra"},
	nora{"lojytadji", "logji tadji"},
	nora{"lolbu'u", "loldi bukpu"},
	nora{"lolcau", "loldi claxu"},
	nora{"lolde'u", "loldi dertu"},
	nora{"lolni'a", "loldi cnita"},
	nora{"lolro'iboi", "loldi rokci bolci"},
	nora{"blocra", "bloti crane"},
	nora{"lumcu'i", "lumci cumki"},
	nora{"lujlu'adi'u", "pluja pluta dinju"},
	nora{"lumpu'o", "lumci purmo"},
	nora{"lumvau", "lumci vasru"},
	nora{"lubyseljma", "lunbe se jamfu"},
	nora{"lurboi", "lunra bolci"},
	nora{"lurcukla", "lunra cukla"},
	nora{"luptci", "klupe tutci"},
	nora{"lutfa'o", "pluta fanmo"},
	nora{"lutke'a", "pluta kevna"},
	nora{"lutku'a", "pluta kumfa"},
	nora{"luzbi'o", "kluza binxo"},
	nora{"luzycre", "kluza certu"},
	nora{"ma'arbi'i", "cmana jbini"},
	nora{"ma'arfe'a", "cmana fenra"},
	nora{"ma'ersazri", "marce sazri"},
	nora{"ma'onrafsi", "cmavo rafsi"},
	nora{"ma'oste", "cmavo liste"},
	nora{"ma'ucla", "makcu clani"},
	nora{"macri'a", "manci rinka"},
	nora{"mafcre", "makfa certu"},
	nora{"mafmi'e", "makfa minde"},
	nora{"maixra", "marji pixra"},
	nora{"majmi'u", "marji mintu"},
	nora{"makfartci", "maksi farna tutci"},
	nora{"makyvelvei", "maksi ve vreji"},
	nora{"maldu'ecni", "mabla dukse cinmo"},
	nora{"malgletoi", "mabla gletu troci"},
	nora{"malgli", "mabla glico"},
	nora{"maljgita'a", "mabla jgira tavla"},
	nora{"malkemcombau", "mabla ke co'e bangu"},
	nora{"malmliselgu'i", "mabla milxe se gusni"},
	nora{"malpavyselbau", "mabla pa se bangu"},
	nora{"malrarbau", "mabla rarna bangu"},
	nora{"malticta'axlu", "mabla tcica tavla xlura"},
	nora{"malxlujikca", "mabla xlura jikca"},
	nora{"malxlujikta'a", "mabla xlura jikca tavla"},
	nora{"mamjipci", "mamta jipci"},
	nora{"mampa'u", "mamta patfu"},
	nora{"manbi'o", "manku binxo"},
	nora{"manrai", "manku traji"},
	nora{"manri'a", "manku rinka"},
	nora{"mansykanji", "mansa kanji"},
	nora{"mantyjalra", "manti jalra"},
	nora{"mantymamta", "manti mamta"},
	nora{"mantyzda", "manti zdani"},
	nora{"manze'a", "manku zenba"},
	nora{"matybi'o", "mapti binxo"},
	nora{"matpai", "mapti pajni"},
	nora{"mardikca", "manri dikca"},
	nora{"marnybu'u", "marna bukpu"},
	nora{"masyce'u", "malsi cecmu"},
	nora{"zmana'u", "zmadu namcu"},
	nora{"zmazau", "zmadu zanru"},
	nora{"maxyvru", "marxa savru"},
	nora{"mecna'u", "mleca namcu"},
	nora{"me'ispe", "mensi speni"},
	nora{"mecrai", "mleca traji"},
	nora{"mekpau", "mekso pagbu"},
	nora{"menbe'i", "menli benji"},
	nora{"menca'a", "menli cabra"},
	nora{"menji'u", "menli jvinu"},
	nora{"menmikce", "menli mikce"},
	nora{"merbau", "merko bangu"},
	nora{"merfei", "merko fepni"},
	nora{"mergu'e", "merko gugde"},
	nora{"merja'a", "merko jatna"},
	nora{"merje'a", "merko jecta"},
	nora{"merkadno", "merko kadno"},
	nora{"merklu", "merko kulnu"},
	nora{"mernai", "merko natmi"},
	nora{"mertru", "merko turni"},
	nora{"meryru'u", "merko rupnu"},
	nora{"mextutra", "mexno tutra"},
	nora{"mi'ecpe", "minde cpedu"},
	nora{"midnoi", "minde notci"},
	nora{"mi'esku", "minde cusku"},
	nora{"termi'esku", "te minde cusku"},
	nora{"midvla", "minde valsi"},
	nora{"mi'irlarcu", "minji larcu"},
	nora{"mi'irlarfi'a", "minji larcu cfika"},
	nora{"mi'irselfinfi'a", "minji se finti cfika"},
	nora{"mi'ispi", "minji spisa"},
	nora{"misyselsi'a", "misno se sinma"},
	nora{"misyzau", "misno zanru"},
	nora{"mitmlu", "mintu simlu"},
	nora{"mibma'o", "mi cmavo"},
	nora{"micka'agau", "mikce katna gasnu"},
	nora{"micka'aku'a", "mikce katna kumfa"},
	nora{"mickarli", "mikce karli"},
	nora{"micydi'u", "mikce dinju"},
	nora{"mijdo'i", "midju donri"},
	nora{"mijdorsai", "midju donri sanmi"},
	nora{"mijycisysla", "midju crisa salci"},
	nora{"mijycte", "midju nicte"},
	nora{"miksnidu", "mikri snidu"},
	nora{"mikygra", "mikri grake"},
	nora{"milsnidu", "milti snidu"},
	nora{"cmizu'e", "cmima zukte"},
	nora{"minba'u", "jmina bacru"},
	nora{"minci'a", "jmina ciska"},
	nora{"midyca'a", "minde cabra"},
	nora{"mirlanxe", "minra lanxe"},
	nora{"mirsarxe", "minra sarxe"},
	nora{"mipstu", "mipri stuzi"},
	nora{"mipypro", "mipri fapro"},
	nora{"mipypu'i", "mipri punji"},
	nora{"mirsna", "minra sance"},
	nora{"mitcinglepre", "mintu cinse gletu prenu"},
	nora{"mitcinpampre", "mintu cinse prami prenu"},
	nora{"mitfa'e", "mintu fatne"},
	nora{"mitmo'a", "mintu morna"},
	nora{"mitnarsi'u", "mintu na simxu"},
	nora{"mitpavycinglepre", "mintu pa cinse gletu prenu"},
	nora{"mitpavycinpampre", "mintu pa cinse prami prenu"},
	nora{"mitsi'u", "mintu simxu"},
	nora{"mitsmuvla", "mintu smuni valsi"},
	nora{"mivdalmuzga", "jmive danlu muzga"},
	nora{"mivgau", "jmive gasnu"},
	nora{"mivmu'i", "jmive mukti"},
	nora{"mivmu'e", "jmive munje"},
	nora{"mlabimke'a", "mlana bitmu kevna"},
	nora{"mlakla", "mlana klama"},
	nora{"mlaselfa'a", "mlana se farna"},
	nora{"mleba'i", "melbi banli"},
	nora{"mlejgi", "melbi jgira"},
	nora{"mlerai", "melbi traji"},
	nora{"mliba'u", "milxe bacru"},
	nora{"mlibra", "milxe barda"},
	nora{"mlibi'e", "milxe brife"},
	nora{"mliburna", "milxe burna"},
	nora{"mlicintunta", "milxe cinse tunta"},
	nora{"mlifanza", "milxe fanza"},
	nora{"mlifrili", "milxe frili"},
	nora{"mligapru", "milxe gapru"},
	nora{"mligla", "milxe glare"},
	nora{"mliri'a", "milxe rinka"},
	nora{"mliselmabla", "milxe se mabla"},
	nora{"mlisli", "milxe slilu"},
	nora{"mlisnosli", "milxe masno slilu"},
	nora{"mlisutsli", "milxe sutra slilu"},
	nora{"mlitoinandu", "milxe troci nandu"},
	nora{"mlixai", "milxe xrani"},
	nora{"mluri'a", "simlu rinka"},
	nora{"mo'isro", "morji sorcu"},
	nora{"mo'isti", "morji sisti"},
	nora{"mocpecli'i", "mokca pencu linji"},
	nora{"mojri'a", "morji rinka"},
	nora{"mojypei", "morji pensi"},
	nora{"mojysu'a", "morji stura"},
	nora{"molgapru", "moklu gapru"},
	nora{"molgle", "moklu gletu"},
	nora{"molko'a", "moklu kojna"},
	nora{"molre'u", "moklu rectu"},
	nora{"moltu'u", "moklu tubnu"},
	nora{"monfu'i", "morna fukpi"},
	nora{"monfu'igau", "morna fukpi gasnu"},
	nora{"monmuprai", "morna mupli traji"},
	nora{"mojgau", "morji gasnu"},
	nora{"mojmau", "morji zmadu"},
	nora{"mosyvi'u", "mosra vimcu"},
	nora{"mosycpu", "mosra lacpu"},
	nora{"mrajymledi", "mraji mledi"},
	nora{"mrena'u", "merli namcu"},
	nora{"mriste", "mrilu liste"},
	nora{"mrobi'o", "morsi binxo"},
	nora{"mrocanci", "morsi canci"},
	nora{"mrofanta", "morsi fanta"},
	nora{"mrofoi", "morsi foldi"},
	nora{"mroke'a", "morsi kevna"},
	nora{"mromu'e", "morsi munje"},
	nora{"mrori'a", "morsi rinka"},
	nora{"mrori'i", "morsi ritli"},
	nora{"mroruxpre", "morsi pruxi prenu"},
	nora{"mrospe", "morsi speni"},
	nora{"mrostu", "morsi stuzi"},
	nora{"mrovau", "morsi vasru"},
	nora{"muclai", "smuci klani"},
	nora{"mudbli", "mudri bliku"},
	nora{"mudyctijalra", "mudri citka jalra"},
	nora{"mudyfagri", "mudri fagri"},
	nora{"mudyka'apre", "mudri katna prenu"},
	nora{"mudypexsilka", "mudri pesxu silka"},
	nora{"mudyselcrepu", "mudri se crepu"},
	nora{"mu'ejva", "munje javni"},
	nora{"mu'etru", "munje turni"},
	nora{"mukygei", "mukti gleki"},
	nora{"mulbri", "mulno bridi"},
	nora{"mulgau", "mulno gasnu"},
	nora{"mulgri", "mulno girzu"},
	nora{"mulna'u", "mulno namcu"},
	nora{"smuge'a", "smuni gerna"},
	nora{"mu'ezda", "munje zdani"},
	nora{"musmalsi", "muslo malsi"},
	nora{"tcebra", "mutce barda"},
	nora{"muvra'itra", "muvdu ranji tarti"},
	nora{"na'acto", "nanca xecto"},
	nora{"na'arcartu", "nanca cartu"},
	nora{"na'arke'udei", "nanca krefu djedi"},
	nora{"na'irmabru", "nalci mabru"},
	nora{"nabysmi", "nanba simsa"},
	nora{"nabzba", "nanba zbasu"},
	nora{"nadmau", "nandu zmadu"},
	nora{"nadmo'i", "nandu morji"},
	nora{"nadrai", "nandu traji"},
	nora{"nadva'u", "nandu vasxu"},
	nora{"nafmupli", "natfe mupli"},
	nora{"nafxu'a", "natfe xusra"},
	nora{"nairterfi'a", "natmi te cfika"},
	nora{"naiske", "natmi saske"},
	nora{"naknalspe", "nakni na'e speni"},
	nora{"nakyganti", "nakni ganti"},
	nora{"nakpa'i", "nakni prami"},
	nora{"kamnakseltro", "ka nakni se jitro"},
	nora{"naktro", "nakni jitro"},
	nora{"kamnakseltru", "ka nakni se turni"},
	nora{"naktru", "nakni turni"},
	nora{"kamnakydzeseltru", "ka nakni dzena se turni"},
	nora{"nakydzetru", "nakni dzena turni"},
	nora{"kamfe'idzeseltru", "ka fetsi dzena se turni"},
	nora{"fetydzetru", "fetsi dzena turni"},
	nora{"kamfetseltro", "ka fetsi se jitro"},
	nora{"fe'itro", "fetsi jitro"},
	nora{"kamfetseltru", "ka fetsi se turni"},
	nora{"fe'itru", "fetsi turni"},
	nora{"nakspe", "nakni speni"},
	nora{"nakybakni", "nakni bakni"},
	nora{"nalci'o", "na'e citno"},
	nora{"nalcnedatni", "na'e cenba datni"},
	nora{"nalcumselfanva", "na'e cumki se fanva"},
	nora{"na'irselpezli", "nalci se pezli"},
	nora{"naldasri'a", "na'e dasni rinka"},
	nora{"naldzukla", "na'e cadzu klama"},
	nora{"nalfadysmato'a", "na'e fadni smaji tonga"},
	nora{"nalfrinyna'u", "na'e frinu namcu"},
	nora{"nalgaixai", "na'e gacri xrani"},
	nora{"nalgeiselflira", "na'e gleki se flira"},
	nora{"nalgundei", "na'e gunka djedi"},
	nora{"naljizykai", "na'e jinzi ckaji"},
	nora{"nalkiryri'a", "na'e ckire rinka"},
	nora{"nalkrecau", "na'e kerfa claxu"},
	nora{"nalmatryma'e", "na'e matra marce"},
	nora{"nalmuvzbe", "na'e muvdu zbepi"},
	nora{"nalnerkla", "na'e nenri klama"},
	nora{"nalpruselpli", "na'e purci se pilno"},
	nora{"nalre'ucti", "na'e rectu citka"},
	nora{"nalrolmei", "na'e ro mei"},
	nora{"nalrolmeilei", "na'e ro mei klesi"},
	nora{"nalsajypei", "na'e sanji pensi"},
	nora{"nalseljuncizra", "na'e se djuno cizra"},
	nora{"nalselvau", "na'e se vasru"},
	nora{"nalsimcabna", "na'e simxu cabna"},
	nora{"nalsirkla", "na'e sirji klama"},
	nora{"nalsti", "na'e sisti"},
	nora{"nalspaji", "na'e spaji"},
	nora{"nalsutydzukepkla", "na'e sutra cadzu ke'e klama"},
	nora{"nalsutydzukla", "na'e sutra cadzu klama"},
	nora{"nalterjuncizra", "na'e te djuno cizra"},
	nora{"naltinri'a", "na'e tirna rinka"},
	nora{"nalvo'aba'ubinselba'u", "na'e voksa bacru jbini se bacru"},
	nora{"nalvo'abinselba'u", "na'e voksa jbini se bacru"},
	nora{"nalxaumau", "na'e xamgu zmadu"},
	nora{"nalylecyvu'e", "na'e lerci vrude"},
	nora{"nalyli'u", "na'e litru"},
	nora{"nalylumcu'i", "na'e lumci cumki"},
	nora{"nabysnuji", "nanba snuji"},
	nora{"nanfi'o", "snanu friko"},
	nora{"nanmerko", "snanu merko"},
	nora{"narmitsi'u", "na mintu simxu"},
	nora{"narselfendi", "na se fendi"},
	nora{"natpau", "natmi pagbu"},
	nora{"nairbau", "natmi bangu"},
	nora{"naudre", "nanmu derxi"},
	nora{"zbibu'u", "nazbi bukpu"},
	nora{"nebyka'a", "cnebo katna"},
	nora{"nebyka'aca'a", "cnebo katna cabra"},
	nora{"neizma", "nelci zmadu"},
	nora{"neldu'e", "nelci dukse"},
	nora{"nenxaksu", "nejni xaksu"},
	nora{"nerbi'o", "nenri binxo"},
	nora{"nercreka", "nenri creka"},
	nora{"nerfle", "nenri flecu"},
	nora{"nerkla", "nenri klama"},
	nora{"nermolre'u", "nenri moklu rectu"},
	nora{"nerta'u", "nenri taxfu"},
	nora{"ni'ablo", "cnita bloti"},
	nora{"nitkro", "cnita korcu"},
	nora{"nitcpare", "cnita cpare"},
	nora{"ninrai", "cnino traji"},
	nora{"nibgei", "nibli gleki"},
	nora{"nibypoi", "nibli porsi"},
	nora{"nicygai", "cnici gacri"},
	nora{"nilcitmidju", "ni citno midju"},
	nora{"nilcre", "ni certu"},
	nora{"nilda'ibandu", "ni darxi bandu"},
	nora{"nildicka'ukezyjdika", "ni dikca kantu kei jdika"},
	nora{"nilji'a", "ni jinga"},
	nora{"niljigrau", "ni jinga gradu"},
	nora{"nilre'i", "ni renvi"},
	nora{"nilsau", "ni slabu"},
	nora{"niltermakfa", "ni te makfa"},
	nora{"niltolci'o", "ni to'e citno"},
	nora{"nilxa'u", "ni xabju"},
	nora{"nilyla'e", "ni lakne"},
	nora{"nimci'o", "ninmu citno"},
	nora{"nimcre", "ninmu certu"},
	nora{"nimjizdunkri", "ninmu jinzi dunli krici"},
	nora{"nimnaujizdunkri", "ninmu nanmu jinzi dunli krici"},
	nora{"ninpe'i", "cnino penmi"},
	nora{"ninpengau", "cnino penmi gasnu"},
	nora{"ninselkakpa", "cnino se kakpa"},
	nora{"ninzba", "cnino zbasu"},
	nora{"nipsri", "snipa dasri"},
	nora{"nipsrisro", "snipa dasri sorcu"},
	nora{"nirci'e", "nirna ciste"},
	nora{"nitflevoi", "cnita flecu vofli"},
	nora{"nitkla", "cnita klama"},
	nora{"nitmu'e", "cnita munje"},
	nora{"nitsa'o", "cnita salpo"},
	nora{"nitybu'u", "cnita bukpu"},
	nora{"nityta'u", "cnita taxfu"},
	nora{"nitytu'u", "cnita tubnu"},
	nora{"normro", "no'e morsi"},
	nora{"normromi'e", "no'e morsi minde"},
	nora{"normu'o", "no'e mulno"},
	nora{"norpante", "no'e pante"},
	nora{"norvaismu", "no'e vajni smuni"},
	nora{"nolnei", "nobli nelci"},
	nora{"nolni'u", "nobli ninmu"},
	nora{"nolrai", "nobli traji"},
	nora{"nolrainanla", "nobli traji nanla"},
	nora{"nolraiti'u", "nobli traji tixnu"},
	nora{"nolraitru", "nobli traji turni"},
	nora{"nolraitrube'a", "nobli traji turni bersa"},
	nora{"nolraitruti'u", "nobli traji turni tixnu"},
	nora{"nolraixli", "nobli traji nixli"},
	nora{"nolraizda", "nobli traji zdani"},
	nora{"nolzda", "nobli zdani"},
	nora{"nonmau", "no zmadu"},
	nora{"nonmauna'u", "no zmadu namcu"},
	nora{"nonme'a", "no mleca"},
	nora{"nonmecna'u", "no mleca namcu"},
	nora{"norsi'ata'a", "no'e sinma tavla"},
	nora{"norsnosli", "no'e masno slilu"},
	nora{"norsutsli", "no'e sutra slilu"},
	nora{"noryra'e", "no'e ralte"},
	nora{"notcreka", "notci creka"},
	nora{"notcrida", "notci crida"},
	nora{"nujdja", "snuji cidja"},
	nora{"nunbavyfi'a", "nu balvi cfika"},
	nora{"nunboitipyjvikezboi", "nu bolci tikpa jivna kei bolci"},
	nora{"nunci'ebasti", "nu ciste basti"},
	nora{"nunclapi'e", "nu clani plipe"},
	nora{"nunctikezgau", "nu citka kei gasnu"},
	nora{"nunje'aga'ibai", "nu jecta galfi bapli"},
	nora{"nunjupca'u", "nu jukpa canlu"},
	nora{"nunkeici'e", "nu kelci ciste"},
	nora{"nunlejnei", "nu pleji nelci"},
	nora{"nunmafyjoida'a", "nu makfa joi damba"},
	nora{"nunmroruxpre", "nu morsi pruxi prenu"},
	nora{"nunmrostu", "nu morsi stuzi"},
	nora{"nunpencku", "nu penmi cukta"},
	nora{"nunpeiri'a", "nu pensi rinka"},
	nora{"nunposnei", "nu ponse nelci"},
	nora{"nunseltickri", "nu se tcica krici"},
	nora{"nunsimta'a", "nu simxu tavla"},
	nora{"nunsladansu", "nu salci dansu"},
	nora{"nunsoidji", "nu sonci djica"},
	nora{"nunsolcanci", "nu solri canci"},
	nora{"nunterlejnei", "nu te pleji nelci"},
	nora{"nunxumsne", "nu xukmi senva"},
	nora{"nunzgaju'a", "nu zgana jufra"},
	nora{"nunzvaju'o", "nu zvati djuno"},
	nora{"nurbe'i", "snura benji"},
	nora{"nurcau", "snura claxu"},
	nora{"nurgau", "snura gasnu"},
	nora{"nurprecau", "snura prenu claxu"},
	nora{"nurpu'i", "snura punji"},
	nora{"nutli'a", "snuti cliva"},
	nora{"nuzyki'a", "nuzba krixa"},
	nora{"nuzyxagji", "nuzba xagji"},
	nora{"pa'arcau", "pacna claxu"},
	nora{"pa'arpei", "pacna pensi"},
	nora{"pa'ezma", "prane zmadu"},
	nora{"pafspe", "patfu speni"},
	nora{"pacraistu", "palci traji stuzi"},
	nora{"pacruxpre", "palci pruxi prenu"},
	nora{"pacruxtutra", "palci pruxi tutra"},
	nora{"pacyselzu'e", "palci se zukte"},
	nora{"pacyxlu", "palci xlura"},
	nora{"pacyzu'e", "palci zukte"},
	nora{"pafybu'a", "patfu bruna"},
	nora{"pafybunspeme'i", "patfu bruna speni mensi"},
	nora{"pairvu'e", "pajni vrude"},
	nora{"pakskaci", "palku skaci"},
	nora{"palcau", "prali claxu"},
	nora{"paltydamri", "palta damri"},
	nora{"paltylu'i", "palta lumci"},
	nora{"paltylumca'a", "palta lumci cabra"},
	nora{"pambasti", "prami basti"},
	nora{"pamnabmi", "prami nabmi"},
	nora{"pampemyzba", "prami pemci zbasu"},
	nora{"pamsa'a", "prami sanga"},
	nora{"pamta'a", "prami tavla"},
	nora{"pamyzautra", "prami zanru tarti"},
	nora{"patydzu", "pante cadzu"},
	nora{"patpai", "pante pajni"},
	nora{"papcpi", "panpi cipni"},
	nora{"papkufra", "panpi kufra"},
	nora{"papri'a", "panpi rinka"},
	nora{"paprysfe", "papri sefta"},
	nora{"paprysfelai", "papri sefta klani"},
	nora{"papygei", "panpi gleki"},
	nora{"paspalku", "pastu palku"},
	nora{"pasyskaci", "pastu skaci"},
	nora{"paurpo'e", "pagbu ponse"},
	nora{"pavdeicitsi", "pa djedi citsi"},
	nora{"pavmeijbe", "pa mei jbena"},
	nora{"pavmoijbe", "pa moi jbena"},
	nora{"pavycinglepre", "pa cinse gletu prenu"},
	nora{"pavycinpampre", "pa cinse prami prenu"},
	nora{"pavypruda'i", "pa purci darxi"},
	nora{"pavysei", "pa sepli"},
	nora{"pavyseljirna", "pa se jirna"},
	nora{"pavyskojmavra", "pa skori jamfu vraga"},
	nora{"pavysu'i", "pa sumti"},
	nora{"pavmoisu'i", "pa moi sumti"},
	nora{"pavyterfrinyna'u", "pa te frinu namcu"},
	nora{"pavyvla", "pa valsi"},
	nora{"pazvau", "panzi vasru"},
	nora{"pazyspe", "panzi speni"},
	nora{"pazysperirni", "panzi speni rirni"},
	nora{"pe'ocme", "pendo cmene"},
	nora{"pecke'a", "pencu kevna"},
	nora{"peckevgai", "pencu kevna gacri"},
	nora{"pecta'o", "pencu tanbo"},
	nora{"pecta'osle", "pencu tanbo selci"},
	nora{"pectcu", "pencu nitcu"},
	nora{"pesrei", "pensi preti"},
	nora{"peircauji'i", "pensi claxu jinvi"},
	nora{"pesnunpe'i", "pensi nu penmi"},
	nora{"peirselra'u", "pensi se raktu"},
	nora{"peitse", "pensi zutse"},
	nora{"pejri'a", "preja rinka"},
	nora{"pelselkre", "pelxu se kerfa"},
	nora{"pelnimre", "pelxu nimre"},
	nora{"pempau", "pemci pagbu"},
	nora{"pempra", "pemci cupra"},
	nora{"pemsa'a", "pemci sanga"},
	nora{"pedrai", "pendo traji"},
	nora{"pengri", "penmi girzu"},
	nora{"penydjuxa'a", "penmi sidju xatra"},
	nora{"pespe'i", "pensi penmi"},
	nora{"pesri'a", "pensi rinka"},
	nora{"pesti'i", "pensi stidi"},
	nora{"selpeiti'i", "se pensi stidi"},
	nora{"pevbakykalci", "pe'a bakni kalci"},
	nora{"pevjicla", "pe'a jicla"},
	nora{"pevrisnyjelca", "pe'a risna jelca"},
	nora{"pevycuvgau", "pe'a curve gasnu"},
	nora{"pezyfaltricu", "pezli farlu tricu"},
	nora{"pezysigja", "pezli sigja"},
	nora{"pi'ejvi", "plipe jivna"},
	nora{"pi'orci'a", "pipno ciska"},
	nora{"pibrango", "plibu rango"},
	nora{"pibyta'u", "plibu taxfu"},
	nora{"pidrai", "pindi traji"},
	nora{"pifstidi'a", "pinfu sisti jdima"},
	nora{"pijvri", "prije virnu"},
	nora{"pijvritra", "prije virnu tarti"},
	nora{"pimselpezli", "pimlu se pezli"},
	nora{"pincyvi'i", "pinca vikmi"},
	nora{"pinflani", "pinta flani"},
	nora{"pinjyca'a", "pinji cabra"},
	nora{"pinjydakli", "pinji dakli"},
	nora{"pinjymolgle", "pinji moklu gletu"},
	nora{"pinke'a", "pinta kevna"},
	nora{"piksku", "pinka cusku"},
	nora{"pipcinki", "plipe cinki"},
	nora{"pipybanfi", "plipe banfi"},
	nora{"pipyjalra", "plipe jalra"},
	nora{"xraski", "pixra skicu"},
	nora{"pitytu'a", "plita tumla"},
	nora{"pixri'a", "pinxe rinka"},
	nora{"pixsla", "pinxe salci"},
	nora{"pixydji", "pinxe djica"},
	nora{"pizysostei", "pi so'o temci"},
	nora{"pledi'i", "pelji jdini"},
	nora{"plesigja", "pelji sigja"},
	nora{"plexa'a", "pelji xatra"},
	nora{"plicru", "pilno curmi"},
	nora{"terplicru", "te pilno curmi"},
	nora{"pliri'a", "pilno rinka"},
	nora{"plisytisna", "plise tisna"},
	nora{"plisytricu", "plise tricu"},
	nora{"plitadji", "pilno tadji"},
	nora{"pitna'u", "plita namcu"},
	nora{"plixau", "pilno xamgu"},
	nora{"plokarlycreka", "polje karli creka"},
	nora{"plopijne", "polje pijne"},
	nora{"plopijnyla'a", "polje pijne lasna"},
	nora{"plopijnytci", "polje pijne tutci"},
	nora{"pojyfa'u", "spoja farlu"},
	nora{"po'aspo", "spoja daspo"},
	nora{"porja'este", "porsi jalge liste"},
	nora{"pojma'a", "spoja cmana"},
	nora{"pojri'a", "spoja rinka"},
	nora{"popri'a", "porpi rinka"},
	nora{"popselgu'i", "porpi se gusni"},
	nora{"popygau", "porpi gasnu"},
	nora{"porjmina", "porsi jmina"},
	nora{"porla'i", "porsi lamji"},
	nora{"porselfai", "porsi se fatri"},
	nora{"porveljmina", "porsi ve jmina"},
	nora{"posnei", "ponse nelci"},
	nora{"posri'a", "ponse rinka"},
	nora{"po'edji", "ponse djica"},
	nora{"precau", "prenu claxu"},
	nora{"pregri", "prenu girzu"},
	nora{"pretai", "prenu tarmi"},
	nora{"pretrocange", "prenu jitro cange"},
	nora{"retpei", "preti pensi"},
	nora{"velprevelma'e", "ve prenu ve marce"},
	nora{"prezda", "prenu zdani"},
	nora{"pripre", "prina prenu"},
	nora{"prityxa'e", "pritu xance"},
	nora{"prolanxe", "fapro lanxe"},
	nora{"prucedra", "purci cedra"},
	nora{"prucimri'a", "purci cilmo rinka"},
	nora{"prujeftu", "purci jeftu"},
	nora{"prulamjeftu", "purci lamji jeftu"},
	nora{"prula'i", "purci lamji"},
	nora{"prulamcte", "purci lamji nicte"},
	nora{"prulamvanci", "purci lamji vanci"},
	nora{"bavlamvanci", "balvi lamji vanci"},
	nora{"pruru'a", "purci sruma"},
	nora{"selpruru'a", "se purci sruma"},
	nora{"pruselpli", "purci se pilno"},
	nora{"pruselpo'e", "purci se ponse"},
	nora{"prusoi", "purci sonci"},
	nora{"ruxycrida", "pruxi crida"},
	nora{"prulamdei", "purci lamji djedi"},
	nora{"prulamrai", "purci lamji traji"},
	nora{"prupla", "purci platu"},
	nora{"prusofto", "purci softo"},
	nora{"ra'artei", "srana temci"},
	nora{"ra'etci", "ralte tutci"},
	nora{"ra'irta'a", "ranji tavla"},
	nora{"ra'udri", "raktu badri"},
	nora{"ra'urcau", "raktu claxu"},
	nora{"racmau", "ralci zmadu"},
	nora{"rairgu'e", "traji gugde"},
	nora{"rairnau", "traji nanmu"},
	nora{"rajma'a", "sraji cmana"},
	nora{"rajycla", "sraji clani"},
	nora{"rajyclamau", "sraji clani zmadu"},
	nora{"rajyflani", "sraji flani"},
	nora{"rajyke'a", "sraji kevna"},
	nora{"rajykevloi", "sraji kevna loldi"},
	nora{"rajymudri", "sraji mudri"},
	nora{"rajysirdra", "sraji sirji drani"},
	nora{"rajyto'agri", "sraji tonga girzu"},
	nora{"rajytu'u", "sraji tubnu"},
	nora{"ralgau", "ralju gasnu"},
	nora{"ralselva'i", "ralju se vamji"},
	nora{"raltca", "ralju tcadu"},
	nora{"ranbo'u", "ranti bongu"},
	nora{"rancimde'u", "ranti cilmo dertu"},
	nora{"rancimderke'a", "ranti cilmo dertu kevna"},
	nora{"rancindu", "ranti cindu"},
	nora{"rapcki", "rapli ciksi"},
	nora{"rapteryrei", "rapli te preti"},
	nora{"rapyda'i", "rapli darxi"},
	nora{"rarbau", "rarna bangu"},
	nora{"rarge'a", "rarna gerna"},
	nora{"rarjva", "rarna javni"},
	nora{"rarlalske", "rarna lanli saske"},
	nora{"rarmi'e", "rarna minde"},
	nora{"rarske", "rarna saske"},
	nora{"rartapla", "rarna tapla"},
	nora{"rarvanbi", "rarna vanbi"},
	nora{"rastergu'i", "grasu te gusni"},
	nora{"rasyselpi'a", "grasu se pilka"},
	nora{"ratmidju", "ratni midju"},
	nora{"ratske", "ratni saske"},
	nora{"ratsru", "ratni sruri"},
	nora{"ravycta", "ragve catlu"},
	nora{"ravypi'e", "ragve plipe"},
	nora{"re'azda", "remna zdani"},
	nora{"rerjvi", "renro jivna"},
	nora{"recyjupcarca'a", "rectu jukpa carna cabra"},
	nora{"bregau", "bredi gasnu"},
	nora{"refsipna", "krefu sipna"},
	nora{"refsku", "krefu cusku"},
	nora{"refyfa'i", "krefu facki"},
	nora{"rejgau", "vreji gasnu"},
	nora{"veirse'u", "vreji selfu"},
	nora{"veirseljibri", "vreji se jibri"},
	nora{"rekybo'u", "greku bongu"},
	nora{"relba'eka'a", "re balre katna"},
	nora{"relcimdyna'u", "re cimde namcu"},
	nora{"relcinglepre", "re cinse gletu prenu"},
	nora{"relcinpampre", "re cinse prami prenu"},
	nora{"relcte", "re nicte"},
	nora{"pavycte", "pa nicte"},
	nora{"cibycte", "ci nicte"},
	nora{"voncte", "vo nicte"},
	nora{"mumcte", "mu nicte"},
	nora{"xavycte", "xa nicte"},
	nora{"noncte", "no nicte"},
	nora{"zelcte", "ze nicte"},
	nora{"reldo'i", "re donri"},
	nora{"pavdo'i", "pa donri"},
	nora{"cibdo'i", "ci donri"},
	nora{"vondo'i", "vo donri"},
	nora{"mumdo'i", "mu donri"},
	nora{"xavdo'i", "xa donri"},
	nora{"nondo'i", "no donri"},
	nora{"zeldo'i", "ze donri"},
	nora{"relvanbi", "re vanbi"},
	nora{"pavyvanbi", "pa vanbi"},
	nora{"cibvanbi", "ci vanbi"},
	nora{"vonvanbi", "vo vanbi"},
	nora{"mumvanbi", "mu vanbi"},
	nora{"xavyvanbi", "xa vanbi"},
	nora{"nonvanbi", "no vanbi"},
	nora{"zelvanbi", "ze vanbi"},
	nora{"relpi'i", "re pilji"},
	nora{"velrelprevelma'e", "ve re prenu ve marce"},
	nora{"relpru", "re purci"},
	nora{"relpruda'i", "re purci darxi"},
	nora{"relselba'e", "re se balre"},
	nora{"relselcalku", "re se calku"},
	nora{"relseljimca", "re se jimca"},
	nora{"relselmla", "re se mlana"},
	nora{"relselxi'u", "re se xislu"},
	nora{"relskosa'e", "re skori satre"},
	nora{"relteryrau", "re te gradu"},
	nora{"relxagri", "re xagri"},
	nora{"relxilma'e", "re xislu marce"},
	nora{"rembau", "remna bangu"},
	nora{"rembi'o", "remna binxo"},
	nora{"remdja", "remna cidja"},
	nora{"remgri", "remna girzu"},
	nora{"remska", "remna skari"},
	nora{"remskapi", "remna skapi"},
	nora{"remso'a", "remna sovda"},
	nora{"remtai", "remna tarmi"},
	nora{"remtsi", "remna tsiju"},
	nora{"remyma'utei", "remna makcu temci"},
	nora{"renkla", "trene klama"},
	nora{"rerce'a", "renro cecla"},
	nora{"resycrida", "respa crida"},
	nora{"reisku", "preti cusku"},
	nora{"reispu", "preti spuda"},
	nora{"reirsisku", "preti sisku"},
	nora{"re'icla", "renvi clani"},
	nora{"ri'emla", "rirxe mlana"},
	nora{"ri'erkrajinto", "rirxe krasi jinto"},
	nora{"ri'irdzuzgibe'e", "ritli cadzu zgike bende"},
	nora{"ri'irju'a", "ritli jufra"},
	nora{"ri'irti'i", "ritli stidi"},
	nora{"ri'ixra", "ritli pixra"},
	nora{"ri'ortcati", "crino tcati"},
	nora{"ri'urtulsru", "rinju tunlo sruri"},
	nora{"ricfoi", "tricu foldi"},
	nora{"ricpurdi", "tricu purdi"},
	nora{"ricyci'e", "tricu ciste"},
	nora{"ricycrida", "tricu crida"},
	nora{"ricyratcu", "tricu ratcu"},
	nora{"ricyselsru", "tricu se sruri"},
	nora{"ridrirni", "crida rirni"},
	nora{"rijyska", "rijno skari"},
	nora{"rijysmi", "rijno simsa"},
	nora{"rikygei", "rinka gleki"},
	nora{"rindatni", "krinu datni"},
	nora{"ringei", "krinu gleki"},
	nora{"rirbu'a", "rirni bruna"},
	nora{"rirme'i", "rirni mensi"},
	nora{"riryriryrirni", "rirni rirni rirni"},
	nora{"risnyjelca", "risna jelca"},
	nora{"ritkemna'aterjvi", "brito ke nanca te jivna"},
	nora{"ri'irme'a", "ritli mleca"},
	nora{"ritna'aterjvi", "brito nanca te jivna"},
	nora{"ritnai", "brito natmi"},
	nora{"ritpre", "brito prenu"},
	nora{"ritybartu", "brito bartu"},
	nora{"ritygu'e", "brito gugde"},
	nora{"rityjbo", "brito lojbo"},
	nora{"rivli'a", "rivbi cliva"},
	nora{"rokcmaplini", "rokci cmalu plini"},
	nora{"rokspi", "rokci spisa"},
	nora{"rolbaukai", "ro bangu ckaji"},
	nora{"roldei", "ro djedi"},
	nora{"rolgu'e", "ro gugde"},
	nora{"rolcte", "ro nicte"},
	nora{"rolpre", "ro prenu"},
	nora{"rolre'azda", "ro remna zdani"},
	nora{"rolsliparbi", "ro slilu parbi"},
	nora{"rolstu", "ro stuzi"},
	nora{"roltei", "ro temci"},
	nora{"rolterdi", "ro terdi"},
	nora{"rolterslidi'e", "ro te slilu dirce"},
	nora{"roltru", "ro turni"},
	nora{"rolzda", "ro zdani"},
	nora{"ruxpre", "pruxi prenu"},
	nora{"rulpezli", "xrula pezli"},
	nora{"rulpurdi", "xrula purdi"},
	nora{"rulzda", "xrula zdani"},
	nora{"rumpe'a", "runme preja"},
	nora{"rumro'i", "runme rokci"},
	nora{"runbau", "rutni bangu"},
	nora{"runge'a", "rutni gerna"},
	nora{"rutpesxu", "grute pesxu"},
	nora{"rutpurdi", "grute purdi"},
	nora{"rutyjdu", "grute jduli"},
	nora{"rutyve'u", "grute vecnu"},
	nora{"ruxse'i", "pruxi sevzi"},
	nora{"ruxyzau", "pruxi zanru"},
	nora{"sa'erjgita", "satre jgita"},
	nora{"sa'irlai", "sanli klani"},
	nora{"sa'orkurfa", "salpo kurfa"},
	nora{"sa'unri'a", "sarcu rinka"},
	nora{"sa'urmi'e", "sarcu minde"},
	nora{"sadrai", "snada traji"},
	nora{"sadyda'a", "snada damba"},
	nora{"sagbarja", "sanga barja"},
	nora{"sagdraci", "sanga draci"},
	nora{"sa'asku", "sanga cusku"},
	nora{"saisla", "sanmi salci"},
	nora{"sakcpu", "sakci lacpu"},
	nora{"sakygau", "sakci gasnu"},
	nora{"sakselylu'i", "sakci se lumci"},
	nora{"sakto'a", "sakci tonga"},
	nora{"salsiltci", "sakli siclu tutci"},
	nora{"saltu'u", "sakli tubnu"},
	nora{"sakmuvgau", "sakci muvdu gasnu"},
	nora{"sakyva'u", "sakci vasxu"},
	nora{"slafagri", "salci fagri"},
	nora{"sa'ordziselfa'a", "salpo dizlo se farna"},
	nora{"samci'a", "skami ciska"},
	nora{"samci'eta'a", "skami ciste tavla"},
	nora{"samjudri", "skami judri"},
	nora{"samki'o", "skami kilto"},
	nora{"sampei", "skami pensi"},
	nora{"sampla", "skami platu"},
	nora{"selsampla", "se skami platu"},
	nora{"sample", "skami pelji"},
	nora{"saprai", "sampu traji"},
	nora{"samralsle", "skami ralju selci"},
	nora{"samru'e", "skami pruce"},
	nora{"samse'u", "skami selfu"},
	nora{"samselpla", "skami se platu"},
	nora{"samske", "skami saske"},
	nora{"samsnuci'e", "skami casnu ciste"},
	nora{"samsroka'u", "skami sorcu kantu"},
	nora{"samsrorau", "skami sorcu gradu"},
	nora{"samsrosle", "skami sorcu selci"},
	nora{"samstu", "skami stuzi"},
	nora{"samtadji", "skami tadji"},
	nora{"samtermi'e", "skami te minde"},
	nora{"samvidni", "skami vidni"},
	nora{"samgi'o", "skami gigdo"},
	nora{"samymegdo", "skami megdo"},
	nora{"samymidnoi", "skami minde notci"},
	nora{"samymri", "skami mrilu"},
	nora{"samyzva", "skami zvati"},
	nora{"sange'u", "spano gerku"},
	nora{"sajbi'o", "sanji binxo"},
	nora{"sajri'a", "sanji rinka"},
	nora{"sankrabau", "spano krasi bangu"},
	nora{"sankragu'e", "spano krasi gugde"},
	nora{"santyse'u", "santa selfu"},
	nora{"saptciklu", "sampu tutci kulnu"},
	nora{"sarlyja'i", "sarlu jadni"},
	nora{"sasfoi", "srasu foldi"},
	nora{"saspurdi", "srasu purdi"},
	nora{"sastu'a", "srasu tumla"},
	nora{"satcymau", "satci zmadu"},
	nora{"satcyri'a", "satci rinka"},
	nora{"satcyski", "satci skicu"},
	nora{"saurckusro", "slabu cukta sorcu"},
	nora{"saurdai", "slabu dacti"},
	nora{"saurgu'e", "slabu gugde"},
	nora{"saursutsabdja", "slabu sutra sabji cidja"},
	nora{"vrule'u", "savru lerfu"},
	nora{"vruri'a", "savru rinka"},
	nora{"sazvanbi", "sazri vanbi"},
	nora{"sazycau", "sazri claxu"},
	nora{"sazyci'e", "sazri ciste"},
	nora{"sazysti", "sazri sisti"},
	nora{"sazytcila", "sazri tcila"},
	nora{"se'isku", "sevzi cusku"},
	nora{"se'isni", "sevzi sinxa"},
	nora{"se'ixru", "sevzi xruti"},
	nora{"se'izga", "sevzi zgana"},
	nora{"sedbo'u", "stedu bongu"},
	nora{"sedja'o", "stedu jarco"},
	nora{"sedycro", "stedu cortu"},
	nora{"sedykre", "stedu kerfa"},
	nora{"sedyterjo'e", "stedu te jorne"},
	nora{"seicni", "sepli cinmo"},
	nora{"selbadydji", "se bandu djica"},
	nora{"selbauka'e", "se bangu kakne"},
	nora{"selca'u", "se canlu"},
	nora{"selcmipi'i", "se cmima pilji"},
	nora{"selcmisumji", "se cmima sumji"},
	nora{"seldamgau", "se danmo gasnu"},
	nora{"seldansazri", "se danti sazri"},
	nora{"seldjixau", "se djica xamgu"},
	nora{"selfi'usa'i", "se cfipu sanli"},
	nora{"selfinfi'a", "se finti cfika"},
	nora{"selfityjbu", "se friti jubme"},
	nora{"selga'esmu", "se ganse smuni"},
	nora{"selgaita'u", "se gacri taxfu"},
	nora{"selgapygau", "se gapru gasnu"},
	nora{"selgeimau", "se gleki zmadu"},
	nora{"selgreka'e", "se pagre kakne"},
	nora{"selgrenalka'e", "se pagre na'e kakne"},
	nora{"selgusrai", "se gusni traji"},
	nora{"selja'efau", "se jalge fasnu"},
	nora{"selja'esku", "se jalge cusku"},
	nora{"seljdadji", "se lijda djica"},
	nora{"seljdagei", "se lijda gleki"},
	nora{"seljdami'u", "se lijda mintu"},
	nora{"seljmaji", "se jmaji"},
	nora{"seljmiri'a", "se jimpe rinka"},
	nora{"selju'ixau", "se jundi xamgu"},
	nora{"seljunbe'i", "se djuno benji"},
	nora{"selkecmlu", "se kecti simlu"},
	nora{"selkeiste", "se kelci liste"},
	nora{"selma'e", "se marce"},
	nora{"selma'ecu'e", "se marce ckule"},
	nora{"selmamspemamta", "se mamta speni mamta"},
	nora{"selmi'e", "se minde"},
	nora{"selmonmi'u", "se morna mintu"},
	nora{"selneirai", "se nelci traji"},
	nora{"selneimau", "se nelci zmadu"},
	nora{"selneixau", "se nelci xamgu"},
	nora{"selpeixau", "se pensi xamgu"},
	nora{"selplidu'i", "se pilno dunli"},
	nora{"selplika'e", "se pilno kakne"},
	nora{"selplimi'u", "se pilno mintu"},
	nora{"selplixau", "se pilno xamgu"},
	nora{"selplopijne", "se polje pijne"},
	nora{"selpopselta'u", "se porpi se taxfu"},
	nora{"selrepydja", "se crepu cidja"},
	nora{"selrerkru", "se renro kruvi"},
	nora{"selrigvamtu", "se rigni vamtu"},
	nora{"selsabytutra", "se sabji tutra"},
	nora{"selsajgau", "se sanji gasnu"},
	nora{"selskuvei", "se cusku vreji"},
	nora{"selsmujmi", "se smuni jimpe"},
	nora{"selsnuka'e", "se casnu kakne"},
	nora{"seltavma'o", "se tavla cmavo"},
	nora{"seltepmau", "se terpa zmadu"},
	nora{"selteprai", "se terpa traji"},
	nora{"selti'ifla", "se stidi flalu"},
	nora{"selti'ismu", "se stidi smuni"},
	nora{"selti'u", "se tixnu"},
	nora{"seltilmau", "se tcila zmadu"},
	nora{"seltolnei", "se to'e nelci"},
	nora{"seltutrai", "se tutra traji"},
	nora{"selviska'eri'a", "se viska kakne rinka"},
	nora{"selvrestu", "se vreta stuzi"},
	nora{"selxaumau", "se xamgu zmadu"},
	nora{"selxaumaugau", "se xamgu zmadu gasnu"},
	nora{"selxagryvau", "se xagri vasru"},
	nora{"selxlupai", "se xlura pajni"},
	nora{"selylauca'a", "se cladu cabra"},
	nora{"selylazmi'u", "se lanzu mintu"},
	nora{"selylebvla", "se lebna valsi"},
	nora{"senlanli", "senpi lanli"},
	nora{"senxu'i", "senpi xukmi"},
	nora{"seirgau", "sepli gasnu"},
	nora{"snebaigau", "senva bapli gasnu"},
	nora{"sezdrari'a", "sevzi drani rinka"},
	nora{"sezlacri", "sevzi lacri"},
	nora{"sezlu'i", "sevzi lumci"},
	nora{"sezvelski", "sevzi ve skicu"},
	nora{"sezyci'i", "sevzi cinri"},
	nora{"sezycitri", "sevzi citri"},
	nora{"sezyju'o", "sevzi djuno"},
	nora{"sezykarni", "sevzi karni"},
	nora{"sezykemxaumaupai", "sevzi ke xamgu zmadu pajni"},
	nora{"sezypa'i", "sevzi prami"},
	nora{"sezypevdu'a", "sevzi pe'a dunda"},
	nora{"se'ipli", "sevzi pilno"},
	nora{"sezyse'u", "sevzi selfu"},
	nora{"se'itru", "sevzi turni"},
	nora{"kamse'itru", "ka sevzi turni"},
	nora{"sezyxangle", "sevzi xance gletu"},
	nora{"sezyxaumaupai", "sevzi xamgu zmadu pajni"},
	nora{"sezyxu'a", "sevzi xusra"},
	nora{"sezyzdakla", "sevzi zdani klama"},
	nora{"sfacatra", "sfasa catra"},
	nora{"sfala'a", "sfasa lasna"},
	nora{"sfanalseljde", "sfasa na'e se kajde"},
	nora{"sfaxai", "sfasa xrani"},
	nora{"sfecra", "sefta crane"},
	nora{"sfefli", "sefta fliba"},
	nora{"sfesti", "sefta sisti"},
	nora{"sfestigau", "sefta sisti gasnu"},
	nora{"si'arfriti", "sinma friti"},
	nora{"si'asnu", "sinma casnu"},
	nora{"si'erbi'e", "snime brife"},
	nora{"sibycanja", "sidbo canja"},
	nora{"sibyti'i", "sidbo stidi"},
	nora{"selsi'oti'isni", "se sidbo stidi sinxa"},
	nora{"sibdai", "sidbo dacti"},
	nora{"sicko'o", "stici skoto"},
	nora{"siltci", "siclu tutci"},
	nora{"silto'a", "siclu tonga"},
	nora{"sigdamva'u", "sigja danmo vasxu"},
	nora{"sigdanmo", "sigja danmo"},
	nora{"sigva'u", "sigja vasxu"},
	nora{"sigycko", "sigja cokcu"},
	nora{"sigyfesyvau", "sigja festi vasru"},
	nora{"sigyfespalta", "sigja festi palta"},
	nora{"sigyfri", "sigja lifri"},
	nora{"sigypli", "sigja pilno"},
	nora{"sijycutci", "skiji cutci"},
	nora{"sijykla", "skiji klama"},
	nora{"tersijykla", "te skiji klama"},
	nora{"sikcurnu", "silka curnu"},
	nora{"silgei", "siclu gleki"},
	nora{"simcabna", "simxu cabna"},
	nora{"simcatra", "simxu catra"},
	nora{"simda'a", "simxu damba"},
	nora{"simda'e", "simxu danre"},
	nora{"simda'i", "simxu darxi"},
	nora{"simju'o", "simxu djuno"},
	nora{"simpro", "simxu fapro"},
	nora{"simfra", "simxu frati"},
	nora{"simfrica", "simxu frica"},
	nora{"simgle", "simxu gletu"},
	nora{"simjikca", "simxu jikca"},
	nora{"simjvi", "simxu jivna"},
	nora{"simkansa", "simxu kansa"},
	nora{"simkruca", "simxu kruca"},
	nora{"simla'i", "simxu lamji"},
	nora{"simlivbaigau", "simxu cliva bapli gasnu"},
	nora{"simpanpi", "simxu panpi"},
	nora{"simpe'o", "simxu pendo"},
	nora{"simpe'u", "simxu pencu"},
	nora{"simpe'i", "simxu penmi"},
	nora{"simsarxe", "simxu sarxe"},
	nora{"nalsimsarxe", "na'e simxu sarxe"},
	nora{"simselyli'e", "simxu se lidne"},
	nora{"simta'a", "simxu tavla"},
	nora{"simtipyda'a", "simxu tikpa damba"},
	nora{"simxanja'i", "simxu xance jadni"},
	nora{"si'umri", "simxu mrilu"},
	nora{"si'uzva", "simxu zvati"},
	nora{"sincycrida", "since crida"},
	nora{"sincysna", "since sance"},
	nora{"si'arseldu'a", "sinma se dunda"},
	nora{"sipku'a", "sipna kumfa"},
	nora{"sipsavgau", "sipna savru gasnu"},
	nora{"sipyvru", "sipna savru"},
	nora{"sipstu", "sipna stuzi"},
	nora{"sipta'u", "sipna taxfu"},
	nora{"sipydakli", "sipna dakli"},
	nora{"sivdju", "sivni sidju"},
	nora{"sivycni", "sivni cinmo"},
	nora{"sivyta'u", "sivni taxfu"},
	nora{"kapkandi", "skapi kandi"},
	nora{"skavrici", "skari vrici"},
	nora{"skefa'i", "saske facki"},
	nora{"skefi'a", "saske cfika"},
	nora{"skegu'a", "saske gunka"},
	nora{"skepre", "saske prenu"},
	nora{"skinoi", "skicu notci"},
	nora{"skola'a", "skori lasna"},
	nora{"skora'e", "skori ralte"},
	nora{"skosra", "skori sarji"},
	nora{"skovrede'a", "skori vreta denpa"},
	nora{"skucre", "cusku certu"},
	nora{"skuci'a", "cusku ciska"},
	nora{"skutadji", "cusku tadji"},
	nora{"skuzau", "cusku zanru"},
	nora{"slacfa", "salci cfari"},
	nora{"slacfagau", "salci cfari gasnu"},
	nora{"slacti", "salci citka"},
	nora{"sladei", "salci djedi"},
	nora{"slagei", "salci gleki"},
	nora{"slapemci", "salci pemci"},
	nora{"sligau", "slilu gasnu"},
	nora{"slivru", "slilu savru"},
	nora{"slisko", "slilu skori"},
	nora{"sludemcro", "sluji denmi cortu"},
	nora{"slugu'a", "sluji gunka"},
	nora{"slukemcakfi'e", "sluji ke calku finpe"},
	nora{"slunandu", "sluji nandu"},
	nora{"sluseltro", "sluji se jitro"},
	nora{"slutro", "sluji jitro"},
	nora{"smaba'u", "smaji bacru"},
	nora{"smacni", "smaji cinmo"},
	nora{"smagai", "smaji gacri"},
	nora{"smajmavra", "smaji jamfu vraga"},
	nora{"smatci", "smaji tutci"},
	nora{"smigau", "simsa gasnu"},
	nora{"smimlu", "simsa simlu"},
	nora{"smirai", "simsa traji"},
	nora{"smizu'e", "simsa zukte"},
	nora{"smudu'i", "smuni dunli"},
	nora{"smujmi", "smuni jimpe"},
	nora{"smulei", "smuni klesi"},
	nora{"smuske", "smuni saske"},
	nora{"snacau", "sance claxu"},
	nora{"snacko", "sance cokcu"},
	nora{"sadmi'o", "snada misno"},
	nora{"snaga'e", "sance ganse"},
	nora{"snage'a", "sance gerna"},
	nora{"snagenske", "sance gerna saske"},
	nora{"snajalra", "sance jalra"},
	nora{"snakamju", "sance kamju"},
	nora{"snaku'ocukca'a", "sance skuro cukla cabra"},
	nora{"snaku'ocukla", "sance skuro cukla"},
	nora{"snaku'ocukyzmi", "sance skuro cukla zmiku"},
	nora{"nanstici", "snanu stici"},
	nora{"nanstuna", "snanu stuna"},
	nora{"snasrica'a", "sance dasri cabra"},
	nora{"snasrita'e", "sance dasri tanxe"},
	nora{"snaterga'e", "sance te ganse"},
	nora{"snaterga'eca'a", "sance te ganse cabra"},
	nora{"snavei", "sance vreji"},
	nora{"snaveiku'ocukla", "sance vreji skuro cukla"},
	nora{"snaveisrica'a", "sance vreji dasri cabra"},
	nora{"snavelminra", "sance ve minra"},
	nora{"snavelmiryri'a", "sance ve minra rinka"},
	nora{"snaze'a", "sance zenba"},
	nora{"snexu'i", "senva xukmi"},
	nora{"snima'o", "sinxa cmavo"},
	nora{"sniti'i", "sinxa stidi"},
	nora{"snoraisli", "masno traji slilu"},
	nora{"snosli", "masno slilu"},
	nora{"snoslijgita", "masno slilu jgita"},
	nora{"snulalske", "casnu lanli saske"},
	nora{"snununpe'i", "casnu nu penmi"},
	nora{"snusna", "casnu sance"},
	nora{"snuxau", "casnu xamgu"},
	nora{"so'etsi", "sobde tsiju"},
	nora{"sorpra", "so'i cupra"},
	nora{"sorpre", "so'i prenu"},
	nora{"sorna'a", "so'i nanca"},
	nora{"sorprema'e", "so'i prenu marce"},
	nora{"sorpruda'i", "so'i purci darxi"},
	nora{"sorzu'edzukla", "so'i zukte cadzu klama"},
	nora{"soidji", "sonci djica"},
	nora{"soirnei", "sonci nelci"},
	nora{"solboi", "solri bolci"},
	nora{"solgu'i", "solri gusni"},
	nora{"solro'i", "solri rokci"},
	nora{"solseldi'e", "solri se dirce"},
	nora{"solxrula", "solri xrula"},
	nora{"sonralju", "sonci ralju"},
	nora{"sorkoitai", "so'i korbi tarmi"},
	nora{"sorprekarce", "so'i prenu karce"},
	nora{"soryre'a", "so'i remna"},
	nora{"sosma'o", "so'o cmavo"},
	nora{"sosyjetka'u", "so'o jetnu kantu"},
	nora{"sosyselcmipi'i", "so'o se cmima pilji"},
	nora{"sosyselcmisumji", "so'o se cmima sumji"},
	nora{"sosyzda", "so'o zdani"},
	nora{"sotprekarce", "so'u prenu karce"},
	nora{"sovrango", "sovda rango"},
	nora{"sovyseltai", "sovda se tarmi"},
	nora{"spabi'u", "spati bitmu"},
	nora{"spacange", "spati cange"},
	nora{"spacau", "spati claxu"},
	nora{"spatadni", "spati tadni"},
	nora{"spagunma", "spati gunma"},
	nora{"spebi'o", "speni binxo"},
	nora{"spebu'a", "speni bruna"},
	nora{"spebunspe", "speni bruna speni"},
	nora{"specfari'i", "speni cfari ritli"},
	nora{"spegau", "speni gasnu"},
	nora{"spekemlazyki'i", "speni ke lanzu ckini"},
	nora{"spelazmi'u", "speni lanzu mintu"},
	nora{"spemamta", "speni mamta"},
	nora{"speme'i", "speni mensi"},
	nora{"speme'ispe", "speni mensi speni"},
	nora{"sperirni", "speni rirni"},
	nora{"spepa'u", "speni patfu"},
	nora{"spesi'u", "speni simxu"},
	nora{"speti'u", "speni tixnu"},
	nora{"spetubyspe", "speni tunba speni"},
	nora{"spetunba", "speni tunba"},
	nora{"spezau", "speni zanru"},
	nora{"spicku", "spisa cukta"},
	nora{"spixra", "spisa pixra"},
	nora{"spofriti", "daspo friti"},
	nora{"spusku", "spuda cusku"},
	nora{"sraki'e", "sarji kicne"},
	nora{"raksku", "sraku cusku"},
	nora{"srimakyvelvei", "dasri maksi ve vreji"},
	nora{"sropanka", "sorcu panka"},
	nora{"srota'e", "sorcu tanxe"},
	nora{"sacrai", "stace traji"},
	nora{"stagau", "stali gasnu"},
	nora{"stagypurdi", "stagi purdi"},
	nora{"stagyve'u", "stagi vecnu"},
	nora{"sicmla", "stici mlana"},
	nora{"stiri'a", "sisti rinka"},
	nora{"stodatni", "stodi datni"},
	nora{"stufa'i", "stuzi facki"},
	nora{"stula'i", "stuzi lamji"},
	nora{"sunzdo", "stuna xazdo"},
	nora{"sunzdopre", "stuna xazdo prenu"},
	nora{"sucri'a", "sucta rinka"},
	nora{"sudgau", "sudga gasnu"},
	nora{"sudgaubu'u", "sudga gasnu bukpu"},
	nora{"sudyfoi", "sudga foldi"},
	nora{"sudysrasu", "sudga srasu"},
	nora{"sudytu'a", "sudga tumla"},
	nora{"sukli'a", "suksa cliva"},
	nora{"sukybajykla", "suksa bajra klama"},
	nora{"sulkai", "sunla ckaji"},
	nora{"sulmai", "sunla marji"},
	nora{"sumnyjirna", "sumne jirna"},
	nora{"sumtcita", "sumti tcita"},
	nora{"sunko'o", "stuna skoto"},
	nora{"surbi'o", "surla binxo"},
	nora{"surdzu", "surla cadzu"},
	nora{"sutctidja", "sutra citka cidja"},
	nora{"sutfau", "sutra fasnu"},
	nora{"sutfle", "sutra flecu"},
	nora{"sutkemjupsabdja", "sutra ke jukpa sabji cidja"},
	nora{"sutrai", "sutra traji"},
	nora{"sutraisli", "sutra traji slilu"},
	nora{"sutybai", "sutra bapli"},
	nora{"sutfi'i", "sutra finti"},
	nora{"sutygau", "sutra gasnu"},
	nora{"sutyjvi", "sutra jivna"},
	nora{"sutkla", "sutra klama"},
	nora{"sutmau", "sutra zmadu"},
	nora{"sutyterjvi", "sutra te jivna"},
	nora{"sutyzbadja", "sutra zbasu cidja"},
	nora{"sutsabdja", "sutra sabji cidja"},
	nora{"sutspu", "sutra spuda"},
	nora{"sutyjupydja", "sutra jukpa cidja"},
	nora{"tavjmi", "tavla jimpe"},
	nora{"ta'atci", "tavla tutci"},
	nora{"ta'axlu", "tavla xlura"},
	nora{"taxyca'a", "tanxe cabra"},
	nora{"ta'irgau", "tatpi gasnu"},
	nora{"ta'orda'i", "tanbo darxi"},
	nora{"ta'orstizu", "tanbo stizu"},
	nora{"ta'uzba", "taxfu zbasu"},
	nora{"tacpinxe", "tance pinxe"},
	nora{"tacto'acfa", "tance tonga cfari"},
	nora{"tacti'e", "tance trixe"},
	nora{"tactungau", "tance tunta gasnu"},
	nora{"tacycra", "tance crane"},
	nora{"tacydzi", "tance dizlo"},
	nora{"tacyga'u", "tance galtu"},
	nora{"tacymidju", "tance midju"},
	nora{"tadgri", "tadni girzu"},
	nora{"tadju'i", "tadni jundi"},
	nora{"tadnunpe'i", "tadni nu penmi"},
	nora{"tadypre", "tadni prenu"},
	nora{"tadycku", "tadni cukta"},
	nora{"tadysmadyfi'a", "tadni smadi cfika"},
	nora{"tafkoi", "taxfu korbi"},
	nora{"taflumpu'o", "taxfu lumci purmo"},
	nora{"tafygunma", "taxfu gunma"},
	nora{"tagmau", "tagji zmadu"},
	nora{"tagysna", "tagji sance"},
	nora{"tamglefri", "tarmi gletu lifri"},
	nora{"taktapla", "staku tapla"},
	nora{"takybli", "staku bliku"},
	nora{"tamdu'i", "tarmi dunli"},
	nora{"tamju'o", "tarmi djuno"},
	nora{"taismi", "tarmi simsa"},
	nora{"tankycacpli", "tanko tcaci pilno"},
	nora{"tankydanmo", "tanko danmo"},
	nora{"tankyjelfri", "tanko jelca lifri"},
	nora{"tankyjelgau", "tanko jelca gasnu"},
	nora{"tankypli", "tanko pilno"},
	nora{"tankyxu'i", "tanko xukmi"},
	nora{"tauzba", "tanru zbasu"},
	nora{"tapkla", "stapa klama"},
	nora{"taplytai", "tapla tarmi"},
	nora{"tatyji'o", "tatru jipno"},
	nora{"tatyta'u", "tatru taxfu"},
	nora{"taurselpli", "tanru se pilno"},
	nora{"taursu'a", "tanru stura"},
	nora{"tavba'u", "tavla bacru"},
	nora{"tavma'o", "tavla cmavo"},
	nora{"tavnei", "tavla nelci"},
	nora{"taxmi'i", "tanxe minji"},
	nora{"cacysku", "tcaci cusku"},
	nora{"tcakarni", "tcadu karni"},
	nora{"tcanai", "tcadu natmi"},
	nora{"tcare'etcana", "tcadu trene tcana"},
	nora{"tcatru", "tcadu turni"},
	nora{"tcatytei", "tcati temci"},
	nora{"tcavro", "tcadu vorme"},
	nora{"tcavru", "tcadu savru"},
	nora{"tcaxa'u", "tcadu xabju"},
	nora{"tcebi'o", "mutce binxo"},
	nora{"tceci'i", "mutce cinri"},
	nora{"tcecla", "mutce clani"},
	nora{"tcecli", "mutce cilre"},
	nora{"tcecne", "mutce cenba"},
	nora{"tcefri", "mutce lifri"},
	nora{"tcegei", "mutce gleki"},
	nora{"tcesau", "mutce slabu"},
	nora{"tceselpu'a", "mutce se pluka"},
	nora{"tceselspaji", "mutce se spaji"},
	nora{"tceselxai", "mutce se xrani"},
	nora{"tcesnosli", "mutce masno slilu"},
	nora{"tcesutsli", "mutce sutra slilu"},
	nora{"tceta'i", "mutce tatpi"},
	nora{"tcete'a", "mutce terpa"},
	nora{"tceva'uvruto'a", "mutce vasxu savru tonga"},
	nora{"tcexai", "mutce xrani"},
	nora{"tcikyselylacri", "tcika se lacri"},
	nora{"tcikyzga", "tcika zgana"},
	nora{"tcityta'o", "tcita tanbo"},
	nora{"tciveljai", "tutci ve jgari"},
	nora{"tcokumte", "ketco kumte"},
	nora{"tcudu'u", "nitcu dunku"},
	nora{"tebykre", "ctebi kerfa"},
	nora{"tecmau", "steci zmadu"},
	nora{"tedboi", "terdi bolci"},
	nora{"tedyplini", "terdi plini"},
	nora{"teicla", "temci clani"},
	nora{"teirmo'a", "temci morna"},
	nora{"teistu", "temci stuzi"},
	nora{"tembavdei", "temci balvi djedi"},
	nora{"tembavna'a", "temci balvi nanca"},
	nora{"tembavytei", "temci balvi temci"},
	nora{"temcimni", "temci cimni"},
	nora{"temge'a", "temci gerna"},
	nora{"tepcau", "terpa claxu"},
	nora{"teprai", "terpa traji"},
	nora{"tepri'a", "terpa rinka"},
	nora{"tepringau", "terpa krinu gasnu"},
	nora{"tepygau", "terpa gasnu"},
	nora{"tercakyjme", "te calku jemna"},
	nora{"terda'akoi", "te damba korbi"},
	nora{"tergusmi'i", "te gusni minji"},
	nora{"terkemselgeimau", "te ke se gleki zmadu"},
	nora{"terlumpu'o", "te lumci purmo"},
	nora{"termo'ixau", "te morji xamgu"},
	nora{"terpecfoi", "te pencu foldi"},
	nora{"tersa'e", "te satre"},
	nora{"tersa'ecpu", "te satre lacpu"},
	nora{"tersliroldu'i", "te slilu ro dunli"},
	nora{"tersacmau", "te stace zmadu"},
	nora{"terto'asko", "te tonga skori"},
	nora{"tervlimau", "te vlipa zmadu"},
	nora{"rixybakfu", "trixe bakfu"},
	nora{"rixybo'u", "trixe bongu"},
	nora{"rixykansa", "trixe kansa"},
	nora{"rixpau", "trixe pagbu"},
	nora{"rixtu'e", "trixe tuple"},
	nora{"rixsfe", "trixe sefta"},
	nora{"ti'icki", "stidi ciksi"},
	nora{"ti'ifla", "stidi flalu"},
	nora{"ti'ortai", "ctino tarmi"},
	nora{"ti'otci", "ctino tutci"},
	nora{"tixspe", "tixnu speni"},
	nora{"tibmli", "tinbe milxe"},
	nora{"ticyjifsku", "tcica jitfa cusku"},
	nora{"ticysku", "tcica cusku"},
	nora{"tigdi'u", "tigni dinju"},
	nora{"tigygusta", "tigni gusta"},
	nora{"tigypre", "tigni prenu"},
	nora{"tikygau", "stika gasnu"},
	nora{"tilcau", "tcila claxu"},
	nora{"tilmau", "tcila zmadu"},
	nora{"tilsku", "tcila cusku"},
	nora{"tinca'a", "tirna cabra"},
	nora{"tinju'i", "tirna jundi"},
	nora{"tinsybu'u", "tinsa bukpu"},
	nora{"tinsyple", "tinsa pelji"},
	nora{"tipyboi", "tikpa bolci"},
	nora{"tisnanba", "tisna nanba"},
	nora{"tisycanti", "tisna canti"},
	nora{"tisydja", "tisna cidja"},
	nora{"titnanba", "titla nanba"},
	nora{"titselpa'i", "titla se prami"},
	nora{"tixmamta", "tixnu mamta"},
	nora{"to'acfa", "tonga cfari"},
	nora{"to'acru", "tonga curmi"},
	nora{"togykaigri", "tonga ckaji girzu"},
	nora{"to'asti", "tonga sisti"},
	nora{"to'asto", "tonga stodi"},
	nora{"tolcitnau", "to'e citno nanmu"},
	nora{"tolci'o", "to'e citno"},
	nora{"tolcu'i", "to'e cumki"},
	nora{"toldarsi", "to'e darsi"},
	nora{"tolno'i", "to'e nobli"},
	nora{"tolpante", "to'e pante"},
	nora{"tolsi'a", "to'e sinma"},
	nora{"tolte'i", "to'e steci"},
	nora{"tolte'igau", "to'e steci gasnu"},
	nora{"tolvri", "to'e virnu"},
	nora{"tolzba", "to'e zbasu"},
	nora{"tocnunpe'i", "troci nu penmi"},
	nora{"toirca'a", "troci cabra"},
	nora{"togdicra", "tonga dicra"},
	nora{"togle'u", "tonga lerfu"},
	nora{"togra'ijmavra", "tonga ranji jamfu vraga"},
	nora{"togyci'e", "tonga ciste"},
	nora{"togycnesli", "tonga cenba slilu"},
	nora{"to'apra", "tonga cupra"},
	nora{"to'asli", "tonga slilu"},
	nora{"togytikygau", "tonga stika gasnu"},
	nora{"togytikpijne", "tonga stika pijne"},
	nora{"togytikpijnyvau", "tonga stika pijne vasru"},
	nora{"togytikyke'a", "tonga stika kevna"},
	nora{"tolbanzu", "to'e banzu"},
	nora{"tolcanci", "to'e canci"},
	nora{"tolka'eselylacri", "to'e kakne se lacri"},
	nora{"tolnindai", "to'e cnino dacti"},
	nora{"tolpaivu'e", "to'e pajni vrude"},
	nora{"tolpa'e", "to'e prane"},
	nora{"toltiljvo", "to'e tcila lujvo"},
	nora{"tolzau", "to'e zanru"},
	nora{"tolzaupai", "to'e zanru pajni"},
	nora{"torcrida", "tordu crida"},
	nora{"tordakyxa'i", "tordu dakfu xarci"},
	nora{"torga'axa'i", "tordu grana xarci"},
	nora{"tormau", "tordu zmadu"},
	nora{"tornunkruca", "tordu nu kruca"},
	nora{"torselsku", "tordu se cusku"},
	nora{"tortei", "tordu temci"},
	nora{"toryre'a", "tordu remna"},
	nora{"rairnei", "traji nelci"},
	nora{"rairtoi", "traji troci"},
	nora{"tramo'a", "tarti morna"},
	nora{"tranydro", "trano cidro"},
	nora{"tratygarna", "trati garna"},
	nora{"ricyzbe", "tricu zbepi"},
	nora{"truci'e", "turni ciste"},
	nora{"trukamni", "turni kamni"},
	nora{"truspe", "turni speni"},
	nora{"trusragri", "turni sarji girzu"},
	nora{"trustizu", "turni stizu"},
	nora{"tsacinla", "tsali cinla"},
	nora{"tsamau", "tsali zmadu"},
	nora{"tsame'a", "tsali mleca"},
	nora{"tanbargu", "tsani bargu"},
	nora{"tanxa'u", "tsani xabju"},
	nora{"tsarai", "tsali traji"},
	nora{"tsejbi", "zutse jibni"},
	nora{"tsifaigau", "tsiju fatri gasnu"},
	nora{"tsilitki", "tsiju litki"},
	nora{"tsipejgau", "tsiju preja gasnu"},
	nora{"tsise'a", "tsiju setca"},
	nora{"tsiselcigla", "tsiju se cigla"},
	nora{"tsivi'i", "tsiju vikmi"},
	nora{"tsubu'u", "rotsu bukpu"},
	nora{"tsugrusi", "rotsu grusi"},
	nora{"tu'ucra", "tubnu crane"},
	nora{"tubyspe", "tunba speni"},
	nora{"tubyti'u", "tunba tixnu"},
	nora{"tupcutci", "tuple cutci"},
	nora{"tupyga'u", "tuple galtu"},
	nora{"turdu'i", "stura dunli"},
	nora{"tutkoi", "tutra korbi"},
	nora{"tutske", "tutra saske"},
	nora{"tutytu'a", "tutra tumla"},
	nora{"vajba'u", "vajni bacru"},
	nora{"vajrai", "vajni traji"},
	nora{"vairxu'a", "vajni xusra"},
	nora{"selvaixu'a", "se vajni xusra"},
	nora{"vlakei", "valsi kelci"},
	nora{"vlanunkei", "valsi nu kelci"},
	nora{"vlaselkei", "valsi se kelci"},
	nora{"vlaturge'a", "valsi stura gerna"},
	nora{"vlatercu'a", "valsi te cuxna"},
	nora{"vampai", "vamji pajni"},
	nora{"vacysai", "vanci sanmi"},
	nora{"vanjba", "vanju jbari"},
	nora{"varjei", "vacri jenmi"},
	nora{"varmuvmi'i", "vacri muvdu minji"},
	nora{"varselclu", "vacri se culno"},
	nora{"varsoi", "vacri sonci"},
	nora{"vasnanba", "vasru nanba"},
	nora{"vaurgau", "vasru gasnu"},
	nora{"vaxterje'e", "vasxu te jetce"},
	nora{"vaxtu'o", "vasxu tunlo"},
	nora{"vaxtu'upau", "vasxu tubnu pagbu"},
	nora{"vaxyba'u", "vasxu bacru"},
	nora{"vaxyke'a", "vasxu kevna"},
	nora{"vaxyvi'i", "vasxu vikmi"},
	nora{"vazdzu", "va cadzu"},
	nora{"venynoi", "vecnu notci"},
	nora{"vensni", "vecnu sinxa"},
	nora{"vefsfa", "venfu sfasa"},
	nora{"vefydji", "venfu djica"},
	nora{"veirci'a", "vreji ciska"},
	nora{"veljoicradi", "ve joi cradi"},
	nora{"velkemprema'e", "ve ke prenu marce"},
	nora{"velklali'i", "ve klama linji"},
	nora{"velma'ekla", "ve marce klama"},
	nora{"velma'epre", "ve marce prenu"},
	nora{"velmirsna", "ve minra sance"},
	nora{"velskicau", "ve skicu claxu"},
	nora{"venski", "vecnu skicu"},
	nora{"vesyspa", "vensa spati"},
	nora{"venzmi", "vecnu zmiku"},
	nora{"verjipci", "verba jipci"},
	nora{"verku'i", "verba kurji"},
	nora{"vi'ajmi", "viska jimpe"},
	nora{"vi'ecpe", "vitke cpedu"},
	nora{"vibgle", "vibna gletu"},
	nora{"viblitki", "vibna litki"},
	nora{"vibmolgle", "vibna moklu gletu"},
	nora{"vibyselcigla", "vibna se cigla"},
	nora{"vidnyveica'a", "vidni vreji cabra"},
	nora{"vijyja'a", "vinji jatna"},
	nora{"vijysazri", "vinji sazri"},
	nora{"vilkla", "vlile klama"},
	nora{"vilti'a", "vlile tcima"},
	nora{"vilyle'a", "vlile lebna"},
	nora{"vimku'a", "vikmi kumfa"},
	nora{"viptru", "vipsi turni"},
	nora{"vipyja'a", "vipsi jatna"},
	nora{"viska'e", "viska kakne"},
	nora{"viska'eri'a", "viska kakne rinka"},
	nora{"viskli", "viska klina"},
	nora{"visnalka'eri'a", "viska na'e kakne rinka"},
	nora{"vi'adji", "viska djica"},
	nora{"visfa'i", "viska facki"},
	nora{"visyvei", "viska vreji"},
	nora{"vi'orji'e", "vitno jmive"},
	nora{"vizbei", "vi bevri"},
	nora{"vizyklo", "vi diklo"},
	nora{"vizystu", "vi stuzi"},
	nora{"vlaba'i", "valsi banli"},
	nora{"vlacku", "valsi cukta"},
	nora{"vlaja'o", "valsi jarco"},
	nora{"vlali'i", "valsi linji"},
	nora{"vlami'u", "valsi mintu"},
	nora{"vlaste", "valsi liste"},
	nora{"vlastocku", "valsi stodi cukta"},
	nora{"vlaxajmi", "valsi xajmi"},
	nora{"vliki'a", "vlipa krixa"},
	nora{"vlikla", "vlipa klama"},
	nora{"vlimau", "vlipa zmadu"},
	nora{"vlinyselkau", "vlina se kampu"},
	nora{"voikla", "vofli klama"},
	nora{"voirli'u", "vofli litru"},
	nora{"volmabru", "vofli mabru"},
	nora{"voksnaske", "voksa sance saske"},
	nora{"vokle'u", "voksa lerfu"},
	nora{"voksli", "voksa slilu"},
	nora{"volcukla", "vofli cukla"},
	nora{"volfalnu", "vofli falnu"},
	nora{"volgau", "vofli gasnu"},
	nora{"volselkei", "vofli se kelci"},
	nora{"vonpitytai", "vo plita tarmi"},
	nora{"vonselmla", "vo se mlana"},
	nora{"vonmlatai", "vo mlana tarmi"},
	nora{"vonskosa'e", "vo skori satre"},
	nora{"vrostu", "vorme stuzi"},
	nora{"vrede'a", "vreta denpa"},
	nora{"vresraki'e", "vreta sarji kicne"},
	nora{"vriba'i", "virnu banli"},
	nora{"vricyvipsi", "vrici vipsi"},
	nora{"vrikla", "virnu klama"},
	nora{"vrirai", "virnu traji"},
	nora{"vrobi'u", "vorme bitmu"},
	nora{"vroca'o", "vorme canko"},
	nora{"vrogai", "vorme gacri"},
	nora{"vrozu'itci", "vorme zunti tutci"},
	nora{"vruca'a", "savru cabra"},
	nora{"vrucau", "savru claxu"},
	nora{"vu'igla", "vrusi glare"},
	nora{"xa'argai", "xatra gacri"},
	nora{"xa'arvau", "xatra vasru"},
	nora{"xa'urjudri", "xabju judri"},
	nora{"xa'urvanbi", "xabju vanbi"},
	nora{"xabyplu", "xadba daplu"},
	nora{"xabmapti", "xadba mapti"},
	nora{"xabminli", "xadba minli"},
	nora{"xabnilganra", "xadba ni ganra"},
	nora{"xabybumru", "xadba bumru"},
	nora{"xacysanta", "xarci santa"},
	nora{"xacysantyse'u", "xarci santa selfu"},
	nora{"xadbi'o", "xadni binxo"},
	nora{"xadmidju", "xadni midju"},
	nora{"xadmuvgau", "xadni muvdu gasnu"},
	nora{"xadycarna", "xadni carna"},
	nora{"xadycla", "xadni clani"},
	nora{"xadykro", "xadni korcu"},
	nora{"xadypau", "xadni pagbu"},
	nora{"xadyplijvi", "xadni pilno jivna"},
	nora{"xadysku", "xadni cusku"},
	nora{"xadytaixau", "xadni tarmi xamgu"},
	nora{"xadyti'e", "xadni trixe"},
	nora{"xadyxai", "xadni xrani"},
	nora{"xauzma", "xamgu zmadu"},
	nora{"xagmaubi'o", "xamgu zmadu binxo"},
	nora{"xagmaugau", "xamgu zmadu gasnu"},
	nora{"xagmaupai", "xamgu zmadu pajni"},
	nora{"xagrai", "xamgu traji"},
	nora{"xagri'a", "xamgu rinka"},
	nora{"xaursirji", "xamgu sirji"},
	nora{"xagze'a", "xamgu zenba"},
	nora{"xajre'u", "xarju rectu"},
	nora{"xalbarja", "xalka barja"},
	nora{"xalbebna", "xalka bebna"},
	nora{"xalcro", "xalka cortu"},
	nora{"xaldji", "xalka djica"},
	nora{"xalfenki", "xalka fenki"},
	nora{"xalgei", "xalka gleki"},
	nora{"xalkai", "xalka ckaji"},
	nora{"xalnunvindu", "xalka nu vindu"},
	nora{"xalpinxe", "xalka pinxe"},
	nora{"xalpixydji", "xalka pinxe djica"},
	nora{"xalsa'a", "xalka sanga"},
	nora{"xalsedycro", "xalka stedu cortu"},
	nora{"xalsipna", "xalka sipna"},
	nora{"xalsla", "xalka salci"},
	nora{"xalvamtu", "xalka vamtu"},
	nora{"xalxre", "xalka mixre"},
	nora{"xamfi'i", "xajmi finti"},
	nora{"xamgau", "xajmi gasnu"},
	nora{"xamselfi'i", "xajmi se finti"},
	nora{"xamyzu'e", "xajmi zukte"},
	nora{"xanboi", "xance bolci"},
	nora{"xandakyxa'i", "xance dakfu xarci"},
	nora{"xandegji", "xance degji"},
	nora{"xandegycalku", "xance degji calku"},
	nora{"xangle", "xance gletu"},
	nora{"xanjanbe", "xance janbe"},
	nora{"xanjoifirsku", "xance joi flira cusku"},
	nora{"xansku", "xance cusku"},
	nora{"xantamji", "xance tamji"},
	nora{"xanterjo'e", "xance te jorne"},
	nora{"xantydenmai", "xanto denci marji"},
	nora{"xanzunto'a", "xance zunti tonga"},
	nora{"xarpre", "xanri prenu"},
	nora{"xaskla", "xamsi klama"},
	nora{"xaskoi", "xamsi korbi"},
	nora{"xaslycmo", "xasli cmoni"},
	nora{"xasxelkla", "xamsi xe klama"},
	nora{"xasyda'u", "xamsi danlu"},
	nora{"xasymabru", "xamsi mabru"},
	nora{"xasysfe", "xamsi sefta"},
	nora{"xasyspa", "xamsi spati"},
	nora{"xaufri", "xamgu lifri"},
	nora{"xaujdi", "xamgu jdice"},
	nora{"jikykamxaujdi", "jikca ka xamgu jdice"},
	nora{"xaupre", "xamgu prenu"},
	nora{"xaurfu'a", "xamgu funca"},
	nora{"xaurka'e", "xamgu kakne"},
	nora{"xaurpai", "xamgu pajni"},
	nora{"xaurprepro", "xamgu prenu fapro"},
	nora{"xaurtoi", "xamgu troci"},
	nora{"xavyselmla", "xa se mlana"},
	nora{"xavyto'a", "xa tonga"},
	nora{"xekselkre", "xekri se kerfa"},
	nora{"xejyji'o", "xedja jipno"},
	nora{"xejykoi", "xedja korbi"},
	nora{"xe'akre", "xedja kerfa"},
	nora{"xekli'ikai", "xekri linji ckaji"},
	nora{"xekyblabi", "xekri blabi"},
	nora{"xekselskapi", "xekri se skapi"},
	nora{"xelbe'iple", "xe benji pelji"},
	nora{"xernunba'u", "xenru nu bacru"},
	nora{"xerselfriti", "xenru se friti"},
	nora{"xervla", "xenru valsi"},
	nora{"xesxei", "xelso xebni"},
	nora{"xesygu'e", "xelso gugde"},
	nora{"xilcucli'u", "xislu cutci litru"},
	nora{"xilcutci", "xislu cutci"},
	nora{"xingu'e", "xindo gugde"},
	nora{"xirkla", "xirma klama"},
	nora{"xircmo", "xirma cmoni"},
	nora{"xirno'i", "xirma nobli"},
	nora{"xirselma'e", "xirma se marce"},
	nora{"xirselma'ecu'e", "xirma se marce ckule"},
	nora{"xirselma'eno'i", "xirma se marce nobli"},
	nora{"xirno'i", "xirma nobli"},
	nora{"xirza'u", "xirma zargu"},
	nora{"xisli'icutci", "xriso linji cutci"},
	nora{"xismalsi", "xriso malsi"},
	nora{"xi'octu", "xriso ctuca"},
	nora{"xlabu'u", "xlali bukpu"},
	nora{"xlafu'a", "xlali funca"},
	nora{"xlapre", "xlali prenu"},
	nora{"xlari'a", "xlali rinka"},
	nora{"xlati'a", "xlali tcima"},
	nora{"xleserti", "naxle serti"},
	nora{"xluga'i", "xlura galfi"},
	nora{"xrakarni", "pixra karni"},
	nora{"xrare'o", "pixra renro"},
	nora{"xrube'i", "xruti benji"},
	nora{"xrucpa", "xruti cpacu"},
	nora{"xrufle", "xruti flecu"},
	nora{"xrukla", "xruti klama"},
	nora{"xu'acmu", "xusra jicmu"},
	nora{"terxuspli", "te xusra pilno"},
	nora{"xukske", "xruki saske"},
	nora{"xuksle", "xruki selci"},
	nora{"xumcacpli", "xukmi tcaci pilno"},
	nora{"xumsne", "xukmi senva"},
	nora{"xunkrexli", "xunre kerfa nixli"},
	nora{"xusnoi", "xusra notci"},
	nora{"xusycmuma'o", "xusra jicmu cmavo"},
	nora{"xusypapri", "xusra papri"},
	nora{"xusyvei", "xusra vreji"},
	nora{"zaglamtu'e", "zargu lamji tuple"},
	nora{"zajyctu", "zajba ctuca"},
	nora{"zalre'u", "zalvi rectu"},
	nora{"zaltapla", "zalvi tapla"},
	nora{"zancimstu", "zabna cilmo stuzi"},
	nora{"zanfri", "zabna lifri"},
	nora{"zarki'a", "zanru krixa"},
	nora{"zasmo'isro", "zasni morji sorcu"},
	nora{"zasyspo", "zasni daspo"},
	nora{"zasysti", "zasni sisti"},
	nora{"macyva'uzasysti", "manci vasxu zasni sisti"},
	nora{"zatfa'i", "zasti facki"},
	nora{"zatsta", "zasti stali"},
	nora{"zausku", "zanru cusku"},
	nora{"zbaske", "zbasu saske"},
	nora{"zbaveljmina", "zbasu ve jmina"},
	nora{"zbero'i", "zbepi rokci"},
	nora{"zbisakci", "nazbi sakci"},
	nora{"zdabartu", "zdani bartu"},
	nora{"zdacravro", "zdani crane vorme"},
	nora{"zdadi'u", "zdani dinju"},
	nora{"zdaku'i", "zdani kurji"},
	nora{"zdamu'e", "zdani munje"},
	nora{"zdane'i", "zdani nenri"},
	nora{"zdasazri", "zdani sazri"},
	nora{"zdaspe", "zdani speni"},
	nora{"zdasta", "zdani stali"},
	nora{"zdatutra", "zdani tutra"},
	nora{"zdaxru", "zdani xruti"},
	nora{"zdida'asnu", "zdile damba casnu"},
	nora{"zdifanza", "zdile fanza"},
	nora{"zdilisri", "zdile lisri"},
	nora{"zenri'a", "zenba rinka"},
	nora{"zergau", "zekri gasnu"},
	nora{"zerkalte", "zekri kalte"},
	nora{"zerle'a", "zekri lebna"},
	nora{"blozeile'a", "bloti zekri lebna"},
	nora{"nunblozeile'a", "nu bloti zekri lebna"},
	nora{"nunzeile'a", "nu zekri lebna"},
	nora{"zernerkla", "zekri nenri klama"},
	nora{"zerxai", "zekri xrani"},
	nora{"zerxaigau", "zekri xrani gasnu"},
	nora{"zetcla", "zetro clani"},
	nora{"zgama'o", "zgana cmavo"},
	nora{"zgatirna", "zgana tirna"},
	nora{"zgica'a", "zgike cabra"},
	nora{"zgifau", "zgike fasnu"},
	nora{"zgifi'i", "zgike finti"},
	nora{"zgijvexajmi", "zgike je xajmi"},
	nora{"zgikabri", "zgike kabri"},
	nora{"zgikalsa", "zgike kalsa"},
	nora{"zgipi'o", "zgike pipno"},
	nora{"zgiselsku", "zgike se cusku"},
	nora{"zgisku", "zgike cusku"},
	nora{"selzgisku", "se zgike cusku"},
	nora{"zgizu'e", "zgike zukte"},
	nora{"zifri'a", "zifre rinka"},
	nora{"zirjbo", "zirpu lojbo"},
	nora{"maudji", "zmadu djica"},
	nora{"zmanei", "zmadu nelci"},
	nora{"termaupu'a", "te zmadu pluka"},
	nora{"zmari'a", "zmadu rinka"},
	nora{"zmitra", "zmiku tarti"},
	nora{"zmutu'a", "zumri tumla"},
	nora{"zu'edji", "zukte djica"},
	nora{"zugyxu'a", "zungi xusra"},
	nora{"zulxa'e", "zunle xance"},
	nora{"zunsna", "zunti sance"},
	nora{"tsekansa", "zutse kansa"},
	nora{"tsela'i", "zutse lamji"},
	nora{"zvaju'o", "zvati djuno"},
	nora{"zvakansa", "zvati kansa"},
	nora{"zvapre", "zvati prenu"},
	nora{"zvaste", "zvati liste"},
	nora{"zvastejbu", "zvati liste jubme"},
	nora{"selba'u", "se bacru"},
	nora{"selbadna", "se badna"},
	nora{"seldri", "se badri"},
	nora{"selbajra", "se bajra"},
	nora{"terbajra", "te bajra"},
	nora{"velbajra", "ve bajra"},
	nora{"selbakfu", "se bakfu"},
	nora{"terbakfu", "te bakfu"},
	nora{"selbakni", "se bakni"},
	nora{"selbakri", "se bakri"},
	nora{"terbakri", "te bakri"},
	nora{"selbaktu", "se baktu"},
	nora{"terbaktu", "te baktu"},
	nora{"selbalji", "se balji"},
	nora{"selbalni", "se balni"},
	nora{"selba'e", "se balre"},
	nora{"selbalvi", "se balvi"},
	nora{"selbancu", "se bancu"},
	nora{"terbancu", "te bancu"},
	nora{"velbancu", "ve bancu"},
	nora{"selbandu", "se bandu"},
	nora{"terbandu", "te bandu"},
	nora{"selbanfi", "se banfi"},
	nora{"selbau", "se bangu"},
	nora{"terbau", "te bangu"},
	nora{"selba'i", "se banli"},
	nora{"terba'i", "te banli"},
	nora{"selba'o", "se banro"},
	nora{"terba'o", "te banro"},
	nora{"selbanxa", "se banxa"},
	nora{"terbanxa", "te banxa"},
	nora{"selbanzu", "se banzu"},
	nora{"terbanzu", "te banzu"},
	nora{"selbai", "se bapli"},
	nora{"selbra", "se barda"},
	nora{"terbra", "te barda"},
	nora{"selbargu", "se bargu"},
	nora{"terbargu", "te bargu"},
	nora{"selbarja", "se barja"},
	nora{"terbarja", "te barja"},
	nora{"selba'a", "se barna"},
	nora{"terba'a", "te barna"},
	nora{"selbartu", "se bartu"},
	nora{"selbasna", "se basna"},
	nora{"terbasna", "te basna"},
	nora{"selbasti", "se basti"},
	nora{"terbasti", "te basti"},
	nora{"selbatci", "se batci"},
	nora{"terbatci", "te batci"},
	nora{"velbatci", "ve batci"},
	nora{"selbatke", "se batke"},
	nora{"terbatke", "te batke"},
	nora{"velbatke", "ve batke"},
	nora{"selbavmi", "se bavmi"},
	nora{"selbaxso", "se baxso"},
	nora{"selbebna", "se bebna"},
	nora{"selbe'o", "se bemro"},
	nora{"selbe'e", "se bende"},
	nora{"terbe'e", "te bende"},
	nora{"velbe'e", "ve bende"},
	nora{"selbengo", "se bengo"},
	nora{"selbe'i", "se benji"},
	nora{"terbe'i", "te benji"},
	nora{"velbe'i", "ve benji"},
	nora{"xelbe'i", "xe benji"},
	nora{"selbe'a", "se bersa"},
	nora{"selberti", "se berti"},
	nora{"terberti", "te berti"},
	nora{"selbesna", "se besna"},
	nora{"selbe'u", "se betfu"},
	nora{"selbetri", "se betri"},
	nora{"selbei", "se bevri"},
	nora{"terbei", "te bevri"},
	nora{"velbei", "ve bevri"},
	nora{"xelbei", "xe bevri"},
	nora{"selbidju", "se bidju"},
	nora{"selbifce", "se bifce"},
	nora{"selbilga", "se bilga"},
	nora{"terbilga", "te bilga"},
	nora{"selbi'a", "se bilma"},
	nora{"terbi'a", "te bilma"},
	nora{"selbilni", "se bilni"},
	nora{"terbilni", "te bilni"},
	nora{"selbindo", "se bindo"},
	nora{"selbinra", "se binra"},
	nora{"terbinra", "te binra"},
	nora{"velbinra", "ve binra"},
	nora{"selbi'o", "se binxo"},
	nora{"terbi'o", "te binxo"},
	nora{"selbirje", "se birje"},
	nora{"selbirka", "se birka"},
	nora{"selbirti", "se birti"},
	nora{"selbisli", "se bisli"},
	nora{"selbi'u", "se bitmu"},
	nora{"terbi'u", "te bitmu"},
	nora{"velbi'u", "ve bitmu"},
	nora{"selblaci", "se blaci"},
	nora{"selbli", "se bliku"},
	nora{"terbli", "te bliku"},
	nora{"selblo", "se bloti"},
	nora{"terblo", "te bloti"},
	nora{"selboi", "se bolci"},
	nora{"selbo'u", "se bongu"},
	nora{"terbo'u", "te bongu"},
	nora{"selbo'i", "se botpi"},
	nora{"terbo'i", "te botpi"},
	nora{"velbo'i", "ve botpi"},
	nora{"selbo'o", "se boxfo"},
	nora{"selbo'a", "se boxna"},
	nora{"terbo'a", "te boxna"},
	nora{"velbo'a", "ve boxna"},
	nora{"xelbo'a", "xe boxna"},
	nora{"selbradi", "se bradi"},
	nora{"terbradi", "te bradi"},
	nora{"selbratu", "se bratu"},
	nora{"selbrazo", "se brazo"},
	nora{"selbre", "se bredi"},
	nora{"selbri", "se bridi"},
	nora{"terbri", "te bridi"},
	nora{"selbi'e", "se brife"},
	nora{"terbi'e", "te brife"},
	nora{"selbriju", "se briju"},
	nora{"terbriju", "te briju"},
	nora{"selbrito", "se brito"},
	nora{"selbu'a", "se bruna"},
	nora{"terbu'a", "te bruna"},
	nora{"selbu'o", "se budjo"},
	nora{"selbu'u", "se bukpu"},
	nora{"selbumru", "se bumru"},
	nora{"selbunda", "se bunda"},
	nora{"terbunda", "te bunda"},
	nora{"velbunda", "ve bunda"},
	nora{"selbru", "se burcu"},
	nora{"terbru", "te burcu"},
	nora{"selburna", "se burna"},
	nora{"selcabna", "se cabna"},
	nora{"selca'a", "se cabra"},
	nora{"terca'a", "te cabra"},
	nora{"selcacra", "se cacra"},
	nora{"tercacra", "te cacra"},
	nora{"seldzu", "se cadzu"},
	nora{"terdzu", "te cadzu"},
	nora{"selcafne", "se cafne"},
	nora{"selcalku", "se calku"},
	nora{"tercalku", "te calku"},
	nora{"selcanci", "se canci"},
	nora{"tercanci", "te canci"},
	nora{"selcange", "se cange"},
	nora{"tercange", "te cange"},
	nora{"velcange", "ve cange"},
	nora{"selcanja", "se canja"},
	nora{"tercanja", "te canja"},
	nora{"velcanja", "ve canja"},
	nora{"selca'o", "se canko"},
	nora{"selcna", "se canpa"},
	nora{"selcanre", "se canre"},
	nora{"tercanre", "te canre"},
	nora{"selcanti", "se canti"},
	nora{"selcarce", "se carce"},
	nora{"tercarce", "te carce"},
	nora{"selcai", "se carmi"},
	nora{"tercai", "te carmi"},
	nora{"selcarna", "se carna"},
	nora{"tercarna", "te carna"},
	nora{"selcartu", "se cartu"},
	nora{"tercartu", "te cartu"},
	nora{"selcarvi", "se carvi"},
	nora{"tercarvi", "te carvi"},
	nora{"selsnu", "se casnu"},
	nora{"selca'e", "se catke"},
	nora{"terca'e", "te catke"},
	nora{"selcta", "se catlu"},
	nora{"selca'i", "se catni"},
	nora{"terca'i", "te catni"},
	nora{"selcatra", "se catra"},
	nora{"tercatra", "te catra"},
	nora{"selcaxno", "se caxno"},
	nora{"tercaxno", "te caxno"},
	nora{"velcaxno", "ve caxno"},
	nora{"selce'a", "se cecla"},
	nora{"terce'a", "te cecla"},
	nora{"selce'u", "se cecmu"},
	nora{"selcedra", "se cedra"},
	nora{"selcne", "se cenba"},
	nora{"tercne", "te cenba"},
	nora{"velcne", "ve cenba"},
	nora{"selcensa", "se censa"},
	nora{"selcenti", "se centi"},
	nora{"tercenti", "te centi"},
	nora{"selcerda", "se cerda"},
	nora{"tercerda", "te cerda"},
	nora{"velcerda", "ve cerda"},
	nora{"selcerni", "se cerni"},
	nora{"tercerni", "te cerni"},
	nora{"selcre", "se certu"},
	nora{"tercre", "te certu"},
	nora{"selcei", "se cevni"},
	nora{"tercei", "te cevni"},
	nora{"selfi'a", "se cfika"},
	nora{"terfi'a", "te cfika"},
	nora{"selcfi", "se cfila"},
	nora{"tercfi", "te cfila"},
	nora{"selcfine", "se cfine"},
	nora{"selfi'u", "se cfipu"},
	nora{"terfi'u", "te cfipu"},
	nora{"selblu", "se ciblu"},
	nora{"seldja", "se cidja"},
	nora{"selcidni", "se cidni"},
	nora{"tercidni", "te cidni"},
	nora{"selcifnu", "se cifnu"},
	nora{"selcigla", "se cigla"},
	nora{"tercigla", "te cigla"},
	nora{"selcikre", "se cikre"},
	nora{"tercikre", "te cikre"},
	nora{"selcki", "se ciksi"},
	nora{"tercki", "te ciksi"},
	nora{"velcki", "ve ciksi"},
	nora{"selcilmo", "se cilmo"},
	nora{"selcli", "se cilre"},
	nora{"tercli", "te cilre"},
	nora{"velcli", "ve cilre"},
	nora{"xelcli", "xe cilre"},
	nora{"selcilta", "se cilta"},
	nora{"selcimde", "se cimde"},
	nora{"tercimde", "te cimde"},
	nora{"selcimni", "se cimni"},
	nora{"tercimni", "te cimni"},
	nora{"selcinba", "se cinba"},
	nora{"tercinba", "te cinba"},
	nora{"selcindu", "se cindu"},
	nora{"selcinfo", "se cinfo"},
	nora{"selcinje", "se cinje"},
	nora{"selcinki", "se cinki"},
	nora{"selcinla", "se cinla"},
	nora{"tercinla", "te cinla"},
	nora{"selcni", "se cinmo"},
	nora{"tercni", "te cinmo"},
	nora{"selci'i", "se cinri"},
	nora{"selcinse", "se cinse"},
	nora{"tercinse", "te cinse"},
	nora{"velcinse", "ve cinse"},
	nora{"selcinta", "se cinta"},
	nora{"tercinta", "te cinta"},
	nora{"selcinza", "se cinza"},
	nora{"tercinza", "te cinza"},
	nora{"selcpi", "se cipni"},
	nora{"selcipra", "se cipra"},
	nora{"tercipra", "te cipra"},
	nora{"selcri", "se cirko"},
	nora{"tercri", "te cirko"},
	nora{"selcirla", "se cirla"},
	nora{"selci'a", "se ciska"},
	nora{"terci'a", "te ciska"},
	nora{"velci'a", "ve ciska"},
	nora{"selci'e", "se ciste"},
	nora{"terci'e", "te ciste"},
	nora{"velci'e", "ve ciste"},
	nora{"selcti", "se citka"},
	nora{"selci'o", "se citno"},
	nora{"selcitri", "se citri"},
	nora{"tercitri", "te citri"},
	nora{"selcitsi", "se citsi"},
	nora{"tercitsi", "te citsi"},
	nora{"selcivla", "se civla"},
	nora{"tercivla", "te civla"},
	nora{"selcizra", "se cizra"},
	nora{"tercizra", "te cizra"},
	nora{"selckabu", "se ckabu"},
	nora{"terckabu", "te ckabu"},
	nora{"selckafi", "se ckafi"},
	nora{"selkai", "se ckaji"},
	nora{"selcka", "se ckana"},
	nora{"tercka", "te ckana"},
	nora{"selckape", "se ckape"},
	nora{"terckape", "te ckape"},
	nora{"selckasu", "se ckasu"},
	nora{"terckasu", "te ckasu"},
	nora{"velckasu", "ve ckasu"},
	nora{"selcke", "se ckeji"},
	nora{"tercke", "te ckeji"},
	nora{"selckiku", "se ckiku"},
	nora{"terckiku", "te ckiku"},
	nora{"selci'u", "se ckilu"},
	nora{"selki'i", "se ckini"},
	nora{"terki'i", "te ckini"},
	nora{"selckire", "se ckire"},
	nora{"terckire", "te ckire"},
	nora{"selcu'e", "se ckule"},
	nora{"tercu'e", "te ckule"},
	nora{"velcu'e", "ve ckule"},
	nora{"xelcu'e", "xe ckule"},
	nora{"selku'u", "se ckunu"},
	nora{"terku'u", "te ckunu"},
	nora{"selylau", "se cladu"},
	nora{"terlau", "te cladu"},
	nora{"selcla", "se clani"},
	nora{"tercla", "te clani"},
	nora{"selcau", "se claxu"},
	nora{"selclika", "se clika"},
	nora{"terclika", "te clika"},
	nora{"selclira", "se clira"},
	nora{"selclite", "se clite"},
	nora{"terclite", "te clite"},
	nora{"selyli'a", "se cliva"},
	nora{"terli'a", "te cliva"},
	nora{"selclupa", "se clupa"},
	nora{"selcmaci", "se cmaci"},
	nora{"selcma", "se cmalu"},
	nora{"tercma", "te cmalu"},
	nora{"selma'a", "se cmana"},
	nora{"selma'o", "se cmavo"},
	nora{"terma'o", "te cmavo"},
	nora{"velma'o", "ve cmavo"},
	nora{"selcme", "se cmene"},
	nora{"tercme", "te cmene"},
	nora{"selcmi", "se cmima"},
	nora{"selcmo", "se cmoni"},
	nora{"tercmo", "te cmoni"},
	nora{"selna'o", "se cnano"},
	nora{"terna'o", "te cnano"},
	nora{"velna'o", "ve cnano"},
	nora{"selne'o", "se cnebo"},
	nora{"selne'u", "se cnemu"},
	nora{"terne'u", "te cnemu"},
	nora{"velne'u", "ve cnemu"},
	nora{"selcnici", "se cnici"},
	nora{"selni'o", "se cnino"},
	nora{"terni'o", "te cnino"},
	nora{"velni'o", "ve cnino"},
	nora{"selni'a", "se cnita"},
	nora{"terni'a", "te cnita"},
	nora{"selcko", "se cokcu"},
	nora{"tercko", "te cokcu"},
	nora{"velcko", "ve cokcu"},
	nora{"selcoi", "se condi"},
	nora{"tercoi", "te condi"},
	nora{"velcoi", "ve condi"},
	nora{"selcro", "se cortu"},
	nora{"selcpa", "se cpacu"},
	nora{"tercpa", "te cpacu"},
	nora{"selcpana", "se cpana"},
	nora{"tercpana", "te cpana"},
	nora{"selcpare", "se cpare"},
	nora{"tercpare", "te cpare"},
	nora{"velcpare", "ve cpare"},
	nora{"selcpe", "se cpedu"},
	nora{"tercpe", "te cpedu"},
	nora{"velcpe", "ve cpedu"},
	nora{"selcpina", "se cpina"},
	nora{"selcradi", "se cradi"},
	nora{"tercradi", "te cradi"},
	nora{"velcradi", "ve cradi"},
	nora{"selcra", "se crane"},
	nora{"tercra", "te crane"},
	nora{"selcreka", "se creka"},
	nora{"selcrepu", "se crepu"},
	nora{"tercrepu", "te crepu"},
	nora{"selcribe", "se cribe"},
	nora{"selcrida", "se crida"},
	nora{"selcripu", "se cripu"},
	nora{"tercripu", "te cripu"},
	nora{"velcripu", "ve cripu"},
	nora{"selcrisa", "se crisa"},
	nora{"tercrisa", "te crisa"},
	nora{"selcritu", "se critu"},
	nora{"tercritu", "te critu"},
	nora{"selctaru", "se ctaru"},
	nora{"terctaru", "te ctaru"},
	nora{"selctebi", "se ctebi"},
	nora{"terctebi", "te ctebi"},
	nora{"selce'i", "se cteki"},
	nora{"terce'i", "te cteki"},
	nora{"velce'i", "ve cteki"},
	nora{"selctile", "se ctile"},
	nora{"selti'o", "se ctino"},
	nora{"terti'o", "te ctino"},
	nora{"selctu", "se ctuca"},
	nora{"terctu", "te ctuca"},
	nora{"velctu", "ve ctuca"},
	nora{"xelctu", "xe ctuca"},
	nora{"selcku", "se cukta"},
	nora{"tercku", "te cukta"},
	nora{"velcku", "ve cukta"},
	nora{"xelcku", "xe cukta"},
	nora{"selclu", "se culno"},
	nora{"selcu'i", "se cumki"},
	nora{"selcumla", "se cumla"},
	nora{"selcunmi", "se cunmi"},
	nora{"selcu'o", "se cunso"},
	nora{"tercu'o", "te cunso"},
	nora{"selcu'u", "se cuntu"},
	nora{"selpra", "se cupra"},
	nora{"terpra", "te cupra"},
	nora{"selcru", "se curmi"},
	nora{"tercru", "te curmi"},
	nora{"selcurnu", "se curnu"},
	nora{"selcurve", "se curve"},
	nora{"selsku", "se cusku"},
	nora{"tersku", "te cusku"},
	nora{"velsku", "ve cusku"},
	nora{"selcutci", "se cutci"},
	nora{"tercutci", "te cutci"},
	nora{"selcutne", "se cutne"},
	nora{"selcu'a", "se cuxna"},
	nora{"tercu'a", "te cuxna"},
	nora{"seldacru", "se dacru"},
	nora{"terdacru", "te dacru"},
	nora{"seldadjo", "se dadjo"},
	nora{"seldakfu", "se dakfu"},
	nora{"terdakfu", "te dakfu"},
	nora{"seldakli", "se dakli"},
	nora{"terdakli", "te dakli"},
	nora{"selda'a", "se damba"},
	nora{"terda'a", "te damba"},
	nora{"seldamri", "se damri"},
	nora{"seldandu", "se dandu"},
	nora{"terdandu", "te dandu"},
	nora{"seldanfu", "se danfu"},
	nora{"selda'u", "se danlu"},
	nora{"seldanmo", "se danmo"},
	nora{"selda'e", "se danre"},
	nora{"seldansu", "se dansu"},
	nora{"seldanti", "se danti"},
	nora{"selplu", "se daplu"},
	nora{"terplu", "te daplu"},
	nora{"seldapma", "se dapma"},
	nora{"terdapma", "te dapma"},
	nora{"seldargu", "se dargu"},
	nora{"terdargu", "te dargu"},
	nora{"veldargu", "ve dargu"},
	nora{"seldau", "se darlu"},
	nora{"terdau", "te darlu"},
	nora{"selda'o", "se darno"},
	nora{"terda'o", "te darno"},
	nora{"seldarsi", "se darsi"},
	nora{"selda'i", "se darxi"},
	nora{"terda'i", "te darxi"},
	nora{"velda'i", "ve darxi"},
	nora{"seldaski", "se daski"},
	nora{"seldasni", "se dasni"},
	nora{"terdasni", "te dasni"},
	nora{"selspo", "se daspo"},
	nora{"selsri", "se dasri"},
	nora{"seldatka", "se datka"},
	nora{"seldatni", "se datni"},
	nora{"terdatni", "te datni"},
	nora{"seldecti", "se decti"},
	nora{"terdecti", "te decti"},
	nora{"seldegji", "se degji"},
	nora{"terdegji", "te degji"},
	nora{"seldejni", "se dejni"},
	nora{"terdejni", "te dejni"},
	nora{"veldejni", "ve dejni"},
	nora{"seldekpu", "se dekpu"},
	nora{"terdekpu", "te dekpu"},
	nora{"veldekpu", "ve dekpu"},
	nora{"seldekto", "se dekto"},
	nora{"terdekto", "te dekto"},
	nora{"selde'o", "se delno"},
	nora{"terde'o", "te delno"},
	nora{"seldembi", "se dembi"},
	nora{"selde'i", "se denci"},
	nora{"seldenmi", "se denmi"},
	nora{"terdenmi", "te denmi"},
	nora{"selde'a", "se denpa"},
	nora{"terde'a", "te denpa"},
	nora{"velde'a", "ve denpa"},
	nora{"selde'u", "se dertu"},
	nora{"terde'u", "te dertu"},
	nora{"seldre", "se derxi"},
	nora{"terdre", "te derxi"},
	nora{"seldesku", "se desku"},
	nora{"seldetri", "se detri"},
	nora{"terdetri", "te detri"},
	nora{"veldetri", "ve detri"},
	nora{"seldicra", "se dicra"},
	nora{"terdicra", "te dicra"},
	nora{"seldikca", "se dikca"},
	nora{"terdikca", "te dikca"},
	nora{"selklo", "se diklo"},
	nora{"terklo", "te diklo"},
	nora{"seldikni", "se dikni"},
	nora{"terdikni", "te dikni"},
	nora{"seldilcu", "se dilcu"},
	nora{"terdilcu", "te dilcu"},
	nora{"veldilcu", "ve dilcu"},
	nora{"seldilnu", "se dilnu"},
	nora{"terdilnu", "te dilnu"},
	nora{"veldilnu", "ve dilnu"},
	nora{"seldimna", "se dimna"},
	nora{"seldi'u", "se dinju"},
	nora{"seldi'o", "se dinko"},
	nora{"terdi'o", "te dinko"},
	nora{"seldirba", "se dirba"},
	nora{"seldi'e", "se dirce"},
	nora{"terdi'e", "te dirce"},
	nora{"seldirgo", "se dirgo"},
	nora{"terdirgo", "te dirgo"},
	nora{"seldzi", "se dizlo"},
	nora{"terdzi", "te dizlo"},
	nora{"seldei", "se djedi"},
	nora{"terdei", "te djedi"},
	nora{"seldji", "se djica"},
	nora{"terdji", "te djica"},
	nora{"seldjine", "se djine"},
	nora{"terdjine", "te djine"},
	nora{"veldjine", "ve djine"},
	nora{"selju'o", "se djuno"},
	nora{"terju'o", "te djuno"},
	nora{"velju'o", "ve djuno"},
	nora{"seldo'i", "se donri"},
	nora{"terdo'i", "te donri"},
	nora{"seldo'o", "se dotco"},
	nora{"seldraci", "se draci"},
	nora{"terdraci", "te draci"},
	nora{"veldraci", "ve draci"},
	nora{"xeldraci", "xe draci"},
	nora{"seldra", "se drani"},
	nora{"terdra", "te drani"},
	nora{"veldra", "ve drani"},
	nora{"seldrata", "se drata"},
	nora{"terdrata", "te drata"},
	nora{"seldru", "se drudi"},
	nora{"seldu'o", "se du"},
	nora{"terdu'o", "te du"},
	nora{"seldugri", "se dugri"},
	nora{"terdugri", "te dugri"},
	nora{"seldu'e", "se dukse"},
	nora{"terdu'e", "te dukse"},
	nora{"seldukti", "se dukti"},
	nora{"terdukti", "te dukti"},
	nora{"seldu'a", "se dunda"},
	nora{"terdu'a", "te dunda"},
	nora{"seldunja", "se dunja"},
	nora{"terdunja", "te dunja"},
	nora{"seldu'u", "se dunku"},
	nora{"seldu'i", "se dunli"},
	nora{"terdu'i", "te dunli"},
	nora{"seldunra", "se dunra"},
	nora{"terdunra", "te dunra"},
	nora{"seldze", "se dzena"},
	nora{"terdze", "te dzena"},
	nora{"selzi'o", "se dzipo"},
	nora{"selfa'i", "se facki"},
	nora{"terfa'i", "te facki"},
	nora{"selfadni", "se fadni"},
	nora{"terfadni", "te fadni"},
	nora{"selfagri", "se fagri"},
	nora{"terfagri", "te fagri"},
	nora{"selfalnu", "se falnu"},
	nora{"terfalnu", "te falnu"},
	nora{"selfamti", "se famti"},
	nora{"terfamti", "te famti"},
	nora{"selfancu", "se fancu"},
	nora{"terfancu", "te fancu"},
	nora{"velfancu", "ve fancu"},
	nora{"selfange", "se fange"},
	nora{"terfange", "te fange"},
	nora{"selfa'o", "se fanmo"},
	nora{"selfanri", "se fanri"},
	nora{"terfanri", "te fanri"},
	nora{"selfanta", "se fanta"},
	nora{"selfanva", "se fanva"},
	nora{"terfanva", "te fanva"},
	nora{"velfanva", "ve fanva"},
	nora{"xelfanva", "xe fanva"},
	nora{"selfanza", "se fanza"},
	nora{"selpro", "se fapro"},
	nora{"terpro", "te fapro"},
	nora{"selfa'u", "se farlu"},
	nora{"terfa'u", "te farlu"},
	nora{"velfa'u", "ve farlu"},
	nora{"selfa'a", "se farna"},
	nora{"terfa'a", "te farna"},
	nora{"selfarvi", "se farvi"},
	nora{"terfarvi", "te farvi"},
	nora{"velfarvi", "ve farvi"},
	nora{"selfa'e", "se fatne"},
	nora{"selfai", "se fatri"},
	nora{"terfai", "te fatri"},
	nora{"selfebvi", "se febvi"},
	nora{"terfebvi", "te febvi"},
	nora{"selfemti", "se femti"},
	nora{"terfemti", "te femti"},
	nora{"selfendi", "se fendi"},
	nora{"terfendi", "te fendi"},
	nora{"velfendi", "ve fendi"},
	nora{"selfe'u", "se fengu"},
	nora{"terfe'u", "te fengu"},
	nora{"selfenki", "se fenki"},
	nora{"selfe'a", "se fenra"},
	nora{"selfe'o", "se fenso"},
	nora{"terfe'o", "te fenso"},
	nora{"velfe'o", "ve fenso"},
	nora{"selfei", "se fepni"},
	nora{"terfei", "te fepni"},
	nora{"selfepri", "se fepri"},
	nora{"selfre", "se ferti"},
	nora{"selfesti", "se festi"},
	nora{"selfe'i", "se fetsi"},
	nora{"terfe'i", "te fetsi"},
	nora{"selfigre", "se figre"},
	nora{"selfilso", "se filso"},
	nora{"selfi'e", "se finpe"},
	nora{"selfi'i", "se finti"},
	nora{"terfi'i", "te finti"},
	nora{"velfi'i", "ve finti"},
	nora{"selfla", "se flalu"},
	nora{"terfla", "te flalu"},
	nora{"velfla", "ve flalu"},
	nora{"xelfla", "xe flalu"},
	nora{"selfle", "se flecu"},
	nora{"terfle", "te flecu"},
	nora{"velfle", "ve flecu"},
	nora{"selfli", "se fliba"},
	nora{"selflira", "se flira"},
	nora{"selfoi", "se foldi"},
	nora{"selfo'o", "se fonmo"},
	nora{"terfo'o", "te fonmo"},
	nora{"selfonxa", "se fonxa"},
	nora{"selfro", "se forca"},
	nora{"terfro", "te forca"},
	nora{"velfro", "ve forca"},
	nora{"selfraso", "se fraso"},
	nora{"selfra", "se frati"},
	nora{"terfra", "te frati"},
	nora{"velfra", "ve frati"},
	nora{"selfraxu", "se fraxu"},
	nora{"terfraxu", "te fraxu"},
	nora{"selfrica", "se frica"},
	nora{"terfrica", "te frica"},
	nora{"selfi'o", "se friko"},
	nora{"selfrili", "se frili"},
	nora{"terfrili", "te frili"},
	nora{"selfrinu", "se frinu"},
	nora{"terfrinu", "te frinu"},
	nora{"selfriti", "se friti"},
	nora{"terfriti", "te friti"},
	nora{"velfriti", "ve friti"},
	nora{"selfu'i", "se fukpi"},
	nora{"terfu'i", "te fukpi"},
	nora{"velfu'i", "ve fukpi"},
	nora{"selflu", "se fulta"},
	nora{"selfu'a", "se funca"},
	nora{"selfusra", "se fusra"},
	nora{"selfu'e", "se fuzme"},
	nora{"terfu'e", "te fuzme"},
	nora{"selgai", "se gacri"},
	nora{"selgadri", "se gadri"},
	nora{"tergadri", "te gadri"},
	nora{"velgadri", "ve gadri"},
	nora{"selga'i", "se galfi"},
	nora{"terga'i", "te galfi"},
	nora{"selga'u", "se galtu"},
	nora{"terga'u", "te galtu"},
	nora{"selgalxe", "se galxe"},
	nora{"selga'o", "se ganlo"},
	nora{"terga'o", "te ganlo"},
	nora{"selganra", "se ganra"},
	nora{"terganra", "te ganra"},
	nora{"selga'e", "se ganse"},
	nora{"terga'e", "te ganse"},
	nora{"velga'e", "ve ganse"},
	nora{"selganti", "se ganti"},
	nora{"terganti", "te ganti"},
	nora{"selganxo", "se ganxo"},
	nora{"selganzu", "se ganzu"},
	nora{"terganzu", "te ganzu"},
	nora{"velganzu", "ve ganzu"},
	nora{"selgapci", "se gapci"},
	nora{"tergapci", "te gapci"},
	nora{"selgapru", "se gapru"},
	nora{"tergapru", "te gapru"},
	nora{"selgarna", "se garna"},
	nora{"tergarna", "te garna"},
	nora{"selgau", "se gasnu"},
	nora{"selgasta", "se gasta"},
	nora{"selgenja", "se genja"},
	nora{"selge'o", "se gento"},
	nora{"selgenxu", "se genxu"},
	nora{"selge'u", "se gerku"},
	nora{"selge'a", "se gerna"},
	nora{"terge'a", "te gerna"},
	nora{"selgi'a", "se gidva"},
	nora{"tergi'a", "te gidva"},
	nora{"selgi'o", "se gigdo"},
	nora{"tergi'o", "te gigdo"},
	nora{"selginka", "se ginka"},
	nora{"terginka", "te ginka"},
	nora{"selgri", "se girzu"},
	nora{"tergri", "te girzu"},
	nora{"velgri", "ve girzu"},
	nora{"selgi'u", "se gismu"},
	nora{"tergi'u", "te gismu"},
	nora{"velgi'u", "ve gismu"},
	nora{"selgla", "se glare"},
	nora{"selgei", "se gleki"},
	nora{"selgle", "se gletu"},
	nora{"selgli", "se glico"},
	nora{"selglu", "se gluta"},
	nora{"selgocti", "se gocti"},
	nora{"tergocti", "te gocti"},
	nora{"selgotro", "se gotro"},
	nora{"tergotro", "te gotro"},
	nora{"selrau", "se gradu"},
	nora{"teryrau", "te gradu"},
	nora{"selgra", "se grake"},
	nora{"tergra", "te grake"},
	nora{"selga'a", "se grana"},
	nora{"selgrasu", "se grasu"},
	nora{"selgreku", "se greku"},
	nora{"selgrute", "se grute"},
	nora{"selgubni", "se gubni"},
	nora{"selgu'e", "se gugde"},
	nora{"tergu'e", "te gugde"},
	nora{"selgundi", "se gundi"},
	nora{"tergundi", "te gundi"},
	nora{"selgu'a", "se gunka"},
	nora{"tergu'a", "te gunka"},
	nora{"selgunma", "se gunma"},
	nora{"selgu'o", "se gunro"},
	nora{"tergu'o", "te gunro"},
	nora{"selgunse", "se gunse"},
	nora{"selgunta", "se gunta"},
	nora{"tergunta", "te gunta"},
	nora{"selgru", "se gurni"},
	nora{"selguska", "se guska"},
	nora{"terguska", "te guska"},
	nora{"selgu'i", "se gusni"},
	nora{"tergu'i", "te gusni"},
	nora{"selgusta", "se gusta"},
	nora{"tergusta", "te gusta"},
	nora{"selgutci", "se gutci"},
	nora{"tergutci", "te gutci"},
	nora{"velgutci", "ve gutci"},
	nora{"selgutra", "se gutra"},
	nora{"selzme", "se guzme"},
	nora{"seljabre", "se jabre"},
	nora{"terjabre", "te jabre"},
	nora{"selja'i", "se jadni"},
	nora{"seljakne", "se jakne"},
	nora{"terjakne", "te jakne"},
	nora{"selja'e", "se jalge"},
	nora{"seljalna", "se jalna"},
	nora{"terjalna", "te jalna"},
	nora{"seljalra", "se jalra"},
	nora{"seljma", "se jamfu"},
	nora{"seljamna", "se jamna"},
	nora{"terjamna", "te jamna"},
	nora{"seljanbe", "se janbe"},
	nora{"seljanco", "se janco"},
	nora{"terjanco", "te janco"},
	nora{"seljanli", "se janli"},
	nora{"seljansu", "se jansu"},
	nora{"terjansu", "te jansu"},
	nora{"veljansu", "ve jansu"},
	nora{"seljanta", "se janta"},
	nora{"terjanta", "te janta"},
	nora{"veljanta", "ve janta"},
	nora{"seljarbu", "se jarbu"},
	nora{"selja'o", "se jarco"},
	nora{"terja'o", "te jarco"},
	nora{"seljarki", "se jarki"},
	nora{"terjarki", "te jarki"},
	nora{"seljaspu", "se jaspu"},
	nora{"terjaspu", "te jaspu"},
	nora{"veljaspu", "ve jaspu"},
	nora{"selja'a", "se jatna"},
	nora{"seljva", "se javni"},
	nora{"terjva", "te javni"},
	nora{"seljbama", "se jbama"},
	nora{"seljba", "se jbari"},
	nora{"seljbe", "se jbena"},
	nora{"terjbe", "te jbena"},
	nora{"veljbe", "ve jbena"},
	nora{"seljbera", "se jbera"},
	nora{"terjbera", "te jbera"},
	nora{"veljbera", "ve jbera"},
	nora{"selbi'i", "se jbini"},
	nora{"terbi'i", "te jbini"},
	nora{"seljdari", "se jdari"},
	nora{"terjdari", "te jdari"},
	nora{"seljdi", "se jdice"},
	nora{"terjdi", "te jdice"},
	nora{"seljdika", "se jdika"},
	nora{"terjdika", "te jdika"},
	nora{"seldi'a", "se jdima"},
	nora{"terdi'a", "te jdima"},
	nora{"veldi'a", "ve jdima"},
	nora{"seldi'i", "se jdini"},
	nora{"seljdu", "se jduli"},
	nora{"selje'a", "se jecta"},
	nora{"seljeftu", "se jeftu"},
	nora{"terjeftu", "te jeftu"},
	nora{"selje'o", "se jegvo"},
	nora{"seljelca", "se jelca"},
	nora{"terjelca", "te jelca"},
	nora{"seljme", "se jemna"},
	nora{"terjme", "te jemna"},
	nora{"seljenca", "se jenca"},
	nora{"seljendu", "se jendu"},
	nora{"terjendu", "te jendu"},
	nora{"seljei", "se jenmi"},
	nora{"terjei", "te jenmi"},
	nora{"seljerna", "se jerna"},
	nora{"terjerna", "te jerna"},
	nora{"selje'i", "se jersi"},
	nora{"seljerxo", "se jerxo"},
	nora{"seljesni", "se jesni"},
	nora{"selje'e", "se jetce"},
	nora{"terje'e", "te jetce"},
	nora{"selje'u", "se jetnu"},
	nora{"selja'u", "se jgalu"},
	nora{"seljga", "se jganu"},
	nora{"terjga", "te jganu"},
	nora{"seljai", "se jgari"},
	nora{"terjai", "te jgari"},
	nora{"seljge", "se jgena"},
	nora{"seljgina", "se jgina"},
	nora{"terjgina", "te jgina"},
	nora{"seljgi", "se jgira"},
	nora{"seljgita", "se jgita"},
	nora{"seljbi", "se jibni"},
	nora{"terjbi", "te jibni"},
	nora{"seljibri", "se jibri"},
	nora{"seljicla", "se jicla"},
	nora{"selcmu", "se jicmu"},
	nora{"seljijnu", "se jijnu"},
	nora{"terjijnu", "te jijnu"},
	nora{"seljikca", "se jikca"},
	nora{"seljikru", "se jikru"},
	nora{"seljilka", "se jilka"},
	nora{"seljilra", "se jilra"},
	nora{"terjilra", "te jilra"},
	nora{"seljimca", "se jimca"},
	nora{"seljmi", "se jimpe"},
	nora{"terjmi", "te jimpe"},
	nora{"seljimte", "se jimte"},
	nora{"terjimte", "te jimte"},
	nora{"seljinci", "se jinci"},
	nora{"selji'a", "se jinga"},
	nora{"terji'a", "te jinga"},
	nora{"velji'a", "ve jinga"},
	nora{"seljinku", "se jinku"},
	nora{"terjinku", "te jinku"},
	nora{"veljinku", "ve jinku"},
	nora{"seljinme", "se jinme"},
	nora{"seljinru", "se jinru"},
	nora{"seljinsa", "se jinsa"},
	nora{"terjinsa", "te jinsa"},
	nora{"seljinto", "se jinto"},
	nora{"terjinto", "te jinto"},
	nora{"selji'i", "se jinvi"},
	nora{"terji'i", "te jinvi"},
	nora{"velji'i", "ve jinvi"},
	nora{"seljinzi", "se jinzi"},
	nora{"seljipci", "se jipci"},
	nora{"selji'o", "se jipno"},
	nora{"terji'o", "te jipno"},
	nora{"seljirna", "se jirna"},
	nora{"seljisra", "se jisra"},
	nora{"seljitfa", "se jitfa"},
	nora{"seltro", "se jitro"},
	nora{"tertro", "te jitro"},
	nora{"seljivbu", "se jivbu"},
	nora{"terjivbu", "te jivbu"},
	nora{"seljvi", "se jivna"},
	nora{"terjvi", "te jivna"},
	nora{"veljvi", "ve jivna"},
	nora{"seljmaji", "se jmaji"},
	nora{"terjmaji", "te jmaji"},
	nora{"seljmifa", "se jmifa"},
	nora{"terjmifa", "te jmifa"},
	nora{"seljmina", "se jmina"},
	nora{"terjmina", "te jmina"},
	nora{"veljmina", "ve jmina"},
	nora{"selji'e", "se jmive"},
	nora{"seljo'o", "se jordo"},
	nora{"seljo'e", "se jorne"},
	nora{"terjo'e", "te jorne"},
	nora{"seljbu", "se jubme"},
	nora{"terjbu", "te jubme"},
	nora{"seljudri", "se judri"},
	nora{"terjudri", "te judri"},
	nora{"selju'a", "se jufra"},
	nora{"terju'a", "te jufra"},
	nora{"seljukni", "se jukni"},
	nora{"seljukpa", "se jukpa"},
	nora{"terjukpa", "te jukpa"},
	nora{"selju'e", "se julne"},
	nora{"terju'e", "te julne"},
	nora{"velju'e", "ve julne"},
	nora{"selju'i", "se jundi"},
	nora{"seljungo", "se jungo"},
	nora{"seljunla", "se junla"},
	nora{"terjunla", "te junla"},
	nora{"veljunla", "ve junla"},
	nora{"seljunri", "se junri"},
	nora{"seljunta", "se junta"},
	nora{"terjunta", "te junta"},
	nora{"seljurme", "se jurme"},
	nora{"seljursa", "se jursa"},
	nora{"seljutsi", "se jutsi"},
	nora{"terjutsi", "te jutsi"},
	nora{"seljuxre", "se juxre"},
	nora{"selji'u", "se jvinu"},
	nora{"terji'u", "te jvinu"},
	nora{"selkabri", "se kabri"},
	nora{"terkabri", "te kabri"},
	nora{"selkacma", "se kacma"},
	nora{"terkacma", "te kacma"},
	nora{"selkadno", "se kadno"},
	nora{"selkafke", "se kafke"},
	nora{"terkafke", "te kafke"},
	nora{"selkagni", "se kagni"},
	nora{"terkagni", "te kagni"},
	nora{"seljde", "se kajde"},
	nora{"terjde", "te kajde"},
	nora{"selkajna", "se kajna"},
	nora{"terkajna", "te kajna"},
	nora{"selka'e", "se kakne"},
	nora{"terka'e", "te kakne"},
	nora{"selkakpa", "se kakpa"},
	nora{"terkakpa", "te kakpa"},
	nora{"velkakpa", "ve kakpa"},
	nora{"selkalci", "se kalci"},
	nora{"selkalri", "se kalri"},
	nora{"terkalri", "te kalri"},
	nora{"selkalsa", "se kalsa"},
	nora{"selkalte", "se kalte"},
	nora{"terkalte", "te kalte"},
	nora{"selkamju", "se kamju"},
	nora{"selkamni", "se kamni"},
	nora{"terkamni", "te kamni"},
	nora{"selkau", "se kampu"},
	nora{"selkanba", "se kanba"},
	nora{"selkancu", "se kancu"},
	nora{"terkancu", "te kancu"},
	nora{"velkancu", "ve kancu"},
	nora{"selkandi", "se kandi"},
	nora{"terkandi", "te kandi"},
	nora{"selkanji", "se kanji"},
	nora{"terkanji", "te kanji"},
	nora{"velkanji", "ve kanji"},
	nora{"selkanla", "se kanla"},
	nora{"selka'o", "se kanro"},
	nora{"selkansa", "se kansa"},
	nora{"terkansa", "te kansa"},
	nora{"selka'u", "se kantu"},
	nora{"selkanxe", "se kanxe"},
	nora{"terkanxe", "te kanxe"},
	nora{"selkarbi", "se karbi"},
	nora{"terkarbi", "te karbi"},
	nora{"velkarbi", "ve karbi"},
	nora{"xelkarbi", "xe karbi"},
	nora{"selkarce", "se karce"},
	nora{"terkarce", "te karce"},
	nora{"selkarda", "se karda"},
	nora{"terkarda", "te karda"},
	nora{"selkargu", "se kargu"},
	nora{"terkargu", "te kargu"},
	nora{"selkarli", "se karli"},
	nora{"terkarli", "te karli"},
	nora{"selkarni", "se karni"},
	nora{"terkarni", "te karni"},
	nora{"velkarni", "ve karni"},
	nora{"selka'a", "se katna"},
	nora{"terka'a", "te katna"},
	nora{"selkavbu", "se kavbu"},
	nora{"terkavbu", "te kavbu"},
	nora{"selke'i", "se kecti"},
	nora{"terke'i", "te kecti"},
	nora{"selkei", "se kelci"},
	nora{"selke'o", "se kelvo"},
	nora{"terke'o", "te kelvo"},
	nora{"selkenra", "se kenra"},
	nora{"selkensa", "se kensa"},
	nora{"selkre", "se kerfa"},
	nora{"terkre", "te kerfa"},
	nora{"selkerlo", "se kerlo"},
	nora{"seltco", "se ketco"},
	nora{"selke'a", "se kevna"},
	nora{"selki'e", "se kicne"},
	nora{"terki'e", "te kicne"},
	nora{"selki'o", "se kilto"},
	nora{"terki'o", "te kilto"},
	nora{"selkinli", "se kinli"},
	nora{"selkisto", "se kisto"},
	nora{"selklaji", "se klaji"},
	nora{"terklaji", "te klaji"},
	nora{"selklaku", "se klaku"},
	nora{"terklaku", "te klaku"},
	nora{"selkla", "se klama"},
	nora{"terkla", "te klama"},
	nora{"velkla", "ve klama"},
	nora{"xelkla", "xe klama"},
	nora{"selylai", "se klani"},
	nora{"terlai", "te klani"},
	nora{"selkle", "se klesi"},
	nora{"terlei", "te klesi"},
	nora{"selkli", "se klina"},
	nora{"selkliru", "se kliru"},
	nora{"selkliti", "se kliti"},
	nora{"selylu'e", "se klupe"},
	nora{"terlu'e", "te klupe"},
	nora{"velylu'e", "ve klupe"},
	nora{"selkluza", "se kluza"},
	nora{"terkluza", "te kluza"},
	nora{"selko'i", "se kobli"},
	nora{"selko'a", "se kojna"},
	nora{"terko'a", "te kojna"},
	nora{"selko'e", "se kolme"},
	nora{"selkomcu", "se komcu"},
	nora{"terkomcu", "te komcu"},
	nora{"selko'u", "se konju"},
	nora{"terko'u", "te konju"},
	nora{"selkoi", "se korbi"},
	nora{"terkoi", "te korbi"},
	nora{"selkorka", "se korka"},
	nora{"selkosta", "se kosta"},
	nora{"selkramu", "se kramu"},
	nora{"terkramu", "te kramu"},
	nora{"velkramu", "ve kramu"},
	nora{"selkra", "se krasi"},
	nora{"selka'i", "se krati"},
	nora{"terka'i", "te krati"},
	nora{"selke'u", "se krefu"},
	nora{"selkri", "se krici"},
	nora{"terkri", "te krici"},
	nora{"selkrili", "se krili"},
	nora{"terkrili", "te krili"},
	nora{"selki'u", "se krinu"},
	nora{"selki'a", "se krixa"},
	nora{"selkruca", "se kruca"},
	nora{"terkruca", "te kruca"},
	nora{"selkruji", "se kruji"},
	nora{"selkru", "se kruvi"},
	nora{"terkru", "te kruvi"},
	nora{"velkru", "ve kruvi"},
	nora{"selkubli", "se kubli"},
	nora{"terkubli", "te kubli"},
	nora{"selkucli", "se kucli"},
	nora{"selkufra", "se kufra"},
	nora{"selkukte", "se kukte"},
	nora{"selklu", "se kulnu"},
	nora{"selku'a", "se kumfa"},
	nora{"terku'a", "te kumfa"},
	nora{"selkumte", "se kumte"},
	nora{"selkunra", "se kunra"},
	nora{"terkunra", "te kunra"},
	nora{"selkunti", "se kunti"},
	nora{"selkurfa", "se kurfa"},
	nora{"terkurfa", "te kurfa"},
	nora{"selku'i", "se kurji"},
	nora{"selkurki", "se kurki"},
	nora{"selku'e", "se kuspe"},
	nora{"selkusru", "se kusru"},
	nora{"selylabno", "se labno"},
	nora{"selcpu", "se lacpu"},
	nora{"tercpu", "te lacpu"},
	nora{"selylacri", "se lacri"},
	nora{"terlacri", "te lacri"},
	nora{"selyladru", "se ladru"},
	nora{"selylafti", "se lafti"},
	nora{"terlafti", "te lafti"},
	nora{"velylafti", "ve lafti"},
	nora{"selyla'e", "se lakne"},
	nora{"selylakse", "se lakse"},
	nora{"selyla'u", "se lalxu"},
	nora{"selyla'i", "se lamji"},
	nora{"terla'i", "te lamji"},
	nora{"velyla'i", "ve lamji"},
	nora{"selylanbi", "se lanbi"},
	nora{"selylanci", "se lanci"},
	nora{"terlanci", "te lanci"},
	nora{"velylanci", "ve lanci"},
	nora{"selylanka", "se lanka"},
	nora{"terlanka", "te lanka"},
	nora{"selylanli", "se lanli"},
	nora{"terlanli", "te lanli"},
	nora{"selylanme", "se lanme"},
	nora{"terlanme", "te lanme"},
	nora{"selylante", "se lante"},
	nora{"terlante", "te lante"},
	nora{"selylanxe", "se lanxe"},
	nora{"selylanzu", "se lanzu"},
	nora{"terlanzu", "te lanzu"},
	nora{"selylarcu", "se larcu"},
	nora{"selyla'a", "se lasna"},
	nora{"terla'a", "te lasna"},
	nora{"velyla'a", "ve lasna"},
	nora{"selylastu", "se lastu"},
	nora{"selyla'o", "se latmo"},
	nora{"selylatna", "se latna"},
	nora{"terlatna", "te latna"},
	nora{"velylatna", "ve latna"},
	nora{"selylazni", "se lazni"},
	nora{"selyle'a", "se lebna"},
	nora{"terle'a", "te lebna"},
	nora{"selyle'o", "se lenjo"},
	nora{"terle'o", "te lenjo"},
	nora{"velyle'o", "ve lenjo"},
	nora{"selylenku", "se lenku"},
	nora{"selylerci", "se lerci"},
	nora{"selyle'u", "se lerfu"},
	nora{"terle'u", "te lerfu"},
	nora{"selylibjo", "se libjo"},
	nora{"selyli'e", "se lidne"},
	nora{"terli'e", "te lidne"},
	nora{"selfri", "se lifri"},
	nora{"seljda", "se lijda"},
	nora{"terjda", "te lijda"},
	nora{"selylimna", "se limna"},
	nora{"selylindi", "se lindi"},
	nora{"terlindi", "te lindi"},
	nora{"selyli'i", "se linji"},
	nora{"selylinsi", "se linsi"},
	nora{"terlinsi", "te linsi"},
	nora{"selyli'o", "se linto"},
	nora{"selylisri", "se lisri"},
	nora{"terlisri", "te lisri"},
	nora{"velylisri", "ve lisri"},
	nora{"selste", "se liste"},
	nora{"terste", "te liste"},
	nora{"velste", "ve liste"},
	nora{"selylitce", "se litce"},
	nora{"terlitce", "te litce"},
	nora{"selylitki", "se litki"},
	nora{"terlitki", "te litki"},
	nora{"selyli'u", "se litru"},
	nora{"terli'u", "te litru"},
	nora{"selylivga", "se livga"},
	nora{"selylivla", "se livla"},
	nora{"selylogji", "se logji"},
	nora{"seljbo", "se lojbo"},
	nora{"selyloi", "se loldi"},
	nora{"selylo'u", "se lorxu"},
	nora{"selylu'o", "se lubno"},
	nora{"seljvo", "se lujvo"},
	nora{"terjvo", "te lujvo"},
	nora{"veljvo", "ve lujvo"},
	nora{"selylu'i", "se lumci"},
	nora{"terlu'i", "te lumci"},
	nora{"velylu'i", "ve lumci"},
	nora{"selylunra", "se lunra"},
	nora{"selylunsa", "se lunsa"},
	nora{"terlunsa", "te lunsa"},
	nora{"velylunsa", "ve lunsa"},
	nora{"selmabla", "se mabla"},
	nora{"termabla", "te mabla"},
	nora{"selmabru", "se mabru"},
	nora{"selcnu", "se macnu"},
	nora{"tercnu", "te macnu"},
	nora{"selma'u", "se makcu"},
	nora{"selmakfa", "se makfa"},
	nora{"termakfa", "te makfa"},
	nora{"selmaksi", "se maksi"},
	nora{"selmalsi", "se malsi"},
	nora{"termalsi", "te malsi"},
	nora{"selmamta", "se mamta"},
	nora{"selmanci", "se manci"},
	nora{"selmanfo", "se manfo"},
	nora{"selmanri", "se manri"},
	nora{"termanri", "te manri"},
	nora{"selmansa", "se mansa"},
	nora{"termansa", "te mansa"},
	nora{"selmanti", "se manti"},
	nora{"selmapku", "se mapku"},
	nora{"selmapti", "se mapti"},
	nora{"termapti", "te mapti"},
	nora{"selmra", "se marbi"},
	nora{"termra", "te marbi"},
	nora{"terma'e", "te marce"},
	nora{"velma'e", "ve marce"},
	nora{"selmarde", "se marde"},
	nora{"termarde", "te marde"},
	nora{"selmai", "se marji"},
	nora{"termai", "te marji"},
	nora{"selmarna", "se marna"},
	nora{"selmarxa", "se marxa"},
	nora{"termarxa", "te marxa"},
	nora{"selsno", "se masno"},
	nora{"selma'i", "se masti"},
	nora{"terma'i", "te masti"},
	nora{"selmatci", "se matci"},
	nora{"selmatne", "se matne"},
	nora{"selmatra", "se matra"},
	nora{"selmavji", "se mavji"},
	nora{"selxri", "se maxri"},
	nora{"selmebri", "se mebri"},
	nora{"selmegdo", "se megdo"},
	nora{"termegdo", "te megdo"},
	nora{"selmei", "se mei"},
	nora{"termei", "te mei"},
	nora{"selme'o", "se mekso"},
	nora{"selmle", "se melbi"},
	nora{"termle", "te melbi"},
	nora{"velmle", "ve melbi"},
	nora{"selmeljo", "se meljo"},
	nora{"selmenli", "se menli"},
	nora{"selme'i", "se mensi"},
	nora{"terme'i", "te mensi"},
	nora{"selme'u", "se mentu"},
	nora{"terme'u", "te mentu"},
	nora{"selmerko", "se merko"},
	nora{"selmre", "se merli"},
	nora{"termre", "te merli"},
	nora{"velmre", "ve merli"},
	nora{"xelmre", "xe merli"},
	nora{"selmexno", "se mexno"},
	nora{"selmidju", "se midju"},
	nora{"selmifra", "se mifra"},
	nora{"termifra", "te mifra"},
	nora{"selmikce", "se mikce"},
	nora{"termikce", "te mikce"},
	nora{"velmikce", "ve mikce"},
	nora{"selmikri", "se mikri"},
	nora{"termikri", "te mikri"},
	nora{"selmilti", "se milti"},
	nora{"termilti", "te milti"},
	nora{"selmli", "se milxe"},
	nora{"termi'e", "te minde"},
	nora{"selmi'i", "se minji"},
	nora{"selminli", "se minli"},
	nora{"terminli", "te minli"},
	nora{"velminli", "ve minli"},
	nora{"selminra", "se minra"},
	nora{"terminra", "te minra"},
	nora{"velminra", "ve minra"},
	nora{"selmi'u", "se mintu"},
	nora{"termi'u", "te mintu"},
	nora{"selmipri", "se mipri"},
	nora{"termipri", "te mipri"},
	nora{"velmipri", "ve mipri"},
	nora{"selmirli", "se mirli"},
	nora{"selmi'o", "se misno"},
	nora{"selmisro", "se misro"},
	nora{"seltre", "se mitre"},
	nora{"tertre", "te mitre"},
	nora{"veltre", "ve mitre"},
	nora{"selxre", "se mixre"},
	nora{"selmla", "se mlana"},
	nora{"termla", "te mlana"},
	nora{"velmla", "ve mlana"},
	nora{"selmlatu", "se mlatu"},
	nora{"selme'a", "se mleca"},
	nora{"terme'a", "te mleca"},
	nora{"velme'a", "ve mleca"},
	nora{"selmledi", "se mledi"},
	nora{"termledi", "te mledi"},
	nora{"selmluni", "se mluni"},
	nora{"termluni", "te mluni"},
	nora{"velmluni", "ve mluni"},
	nora{"selmoi", "se moi"},
	nora{"termoi", "te moi"},
	nora{"selmokca", "se mokca"},
	nora{"selmo'u", "se moklu"},
	nora{"selmlo", "se molki"},
	nora{"selmo'o", "se molro"},
	nora{"termo'o", "te molro"},
	nora{"selmo'i", "se morji"},
	nora{"termo'i", "te morji"},
	nora{"selmorko", "se morko"},
	nora{"selmo'a", "se morna"},
	nora{"termo'a", "te morna"},
	nora{"selmosra", "se mosra"},
	nora{"termosra", "te mosra"},
	nora{"selmraji", "se mraji"},
	nora{"selmri", "se mrilu"},
	nora{"termri", "te mrilu"},
	nora{"velmri", "ve mrilu"},
	nora{"xelmri", "xe mrilu"},
	nora{"selmru", "se mruli"},
	nora{"termru", "te mruli"},
	nora{"velmru", "ve mruli"},
	nora{"selmudri", "se mudri"},
	nora{"selmu'i", "se mukti"},
	nora{"termu'i", "te mukti"},
	nora{"selmu'o", "se mulno"},
	nora{"termu'o", "te mulno"},
	nora{"selmu'e", "se munje"},
	nora{"termu'e", "te munje"},
	nora{"selmupli", "se mupli"},
	nora{"termupli", "te mupli"},
	nora{"selmurse", "se murse"},
	nora{"termurse", "te murse"},
	nora{"selmu'a", "se murta"},
	nora{"termu'a", "te murta"},
	nora{"selmuslo", "se muslo"},
	nora{"seltce", "se mutce"},
	nora{"tertce", "te mutce"},
	nora{"selmu'u", "se muvdu"},
	nora{"termu'u", "te muvdu"},
	nora{"velmu'u", "ve muvdu"},
	nora{"selmuzga", "se muzga"},
	nora{"termuzga", "te muzga"},
	nora{"selnabmi", "se nabmi"},
	nora{"ternabmi", "te nabmi"},
	nora{"selnakni", "se nakni"},
	nora{"ternakni", "te nakni"},
	nora{"selna'i", "se nalci"},
	nora{"selnanba", "se nanba"},
	nora{"selna'a", "se nanca"},
	nora{"terna'a", "te nanca"},
	nora{"selnandu", "se nandu"},
	nora{"ternandu", "te nandu"},
	nora{"selnanla", "se nanla"},
	nora{"ternanla", "te nanla"},
	nora{"selnanvi", "se nanvi"},
	nora{"ternanvi", "te nanvi"},
	nora{"selnarge", "se narge"},
	nora{"ternarge", "te narge"},
	nora{"velnarge", "ve narge"},
	nora{"selna'e", "se natfe"},
	nora{"terna'e", "te natfe"},
	nora{"selnai", "se natmi"},
	nora{"selnavni", "se navni"},
	nora{"selxle", "se naxle"},
	nora{"terxle", "te naxle"},
	nora{"velxle", "ve naxle"},
	nora{"selzbi", "se nazbi"},
	nora{"terzbi", "te nazbi"},
	nora{"selnejni", "se nejni"},
	nora{"ternejni", "te nejni"},
	nora{"selnei", "se nelci"},
	nora{"selne'i", "se nenri"},
	nora{"selni'i", "se nibli"},
	nora{"terni'i", "te nibli"},
	nora{"selcte", "se nicte"},
	nora{"tercte", "te nicte"},
	nora{"selni'e", "se nilce"},
	nora{"terni'e", "te nilce"},
	nora{"selnimre", "se nimre"},
	nora{"selnirna", "se nirna"},
	nora{"seltcu", "se nitcu"},
	nora{"tertcu", "te nitcu"},
	nora{"selnivji", "se nivji"},
	nora{"ternivji", "te nivji"},
	nora{"selxli", "se nixli"},
	nora{"terxli", "te nixli"},
	nora{"selno'i", "se nobli"},
	nora{"selnoi", "se notci"},
	nora{"ternoi", "te notci"},
	nora{"velnoi", "ve notci"},
	nora{"selnu'e", "se nupre"},
	nora{"ternu'e", "te nupre"},
	nora{"selnurma", "se nurma"},
	nora{"selnu'i", "se nutli"},
	nora{"selnuzba", "se nuzba"},
	nora{"ternuzba", "te nuzba"},
	nora{"velnuzba", "ve nuzba"},
	nora{"selpa'a", "se pacna"},
	nora{"terpa'a", "te pacna"},
	nora{"selpau", "se pagbu"},
	nora{"selgre", "se pagre"},
	nora{"tergre", "te pagre"},
	nora{"velgre", "ve pagre"},
	nora{"selpai", "se pajni"},
	nora{"selpalci", "se palci"},
	nora{"selpalku", "se palku"},
	nora{"selpalne", "se palne"},
	nora{"terpalne", "te palne"},
	nora{"selpalta", "se palta"},
	nora{"selpambe", "se pambe"},
	nora{"terpambe", "te pambe"},
	nora{"velpambe", "ve pambe"},
	nora{"xelpambe", "xe pambe"},
	nora{"selpanci", "se panci"},
	nora{"terpanci", "te panci"},
	nora{"selpandi", "se pandi"},
	nora{"terpandi", "te pandi"},
	nora{"velpandi", "ve pandi"},
	nora{"selpanka", "se panka"},
	nora{"terpanka", "te panka"},
	nora{"selpa'o", "se panlo"},
	nora{"selpanpi", "se panpi"},
	nora{"selpanra", "se panra"},
	nora{"terpanra", "te panra"},
	nora{"velpanra", "ve panra"},
	nora{"selpante", "se pante"},
	nora{"terpante", "te pante"},
	nora{"velpante", "ve pante"},
	nora{"selpanzi", "se panzi"},
	nora{"selpapri", "se papri"},
	nora{"selparbi", "se parbi"},
	nora{"terparbi", "te parbi"},
	nora{"selpastu", "se pastu"},
	nora{"selpa'u", "se patfu"},
	nora{"selpatlu", "se patlu"},
	nora{"selpatxu", "se patxu"},
	nora{"terpatxu", "te patxu"},
	nora{"selple", "se pelji"},
	nora{"selpemci", "se pemci"},
	nora{"terpemci", "te pemci"},
	nora{"velpemci", "ve pemci"},
	nora{"selpenbi", "se penbi"},
	nora{"terpenbi", "te penbi"},
	nora{"selpe'u", "se pencu"},
	nora{"terpe'u", "te pencu"},
	nora{"selpe'o", "se pendo"},
	nora{"selpe'i", "se penmi"},
	nora{"terpe'i", "te penmi"},
	nora{"selpei", "se pensi"},
	nora{"selperli", "se perli"},
	nora{"selpesxu", "se pesxu"},
	nora{"selpetso", "se petso"},
	nora{"terpetso", "te petso"},
	nora{"selpezli", "se pezli"},
	nora{"selpicti", "se picti"},
	nora{"terpicti", "te picti"},
	nora{"selpijne", "se pijne"},
	nora{"terpijne", "te pijne"},
	nora{"selpikci", "se pikci"},
	nora{"terpikci", "te pikci"},
	nora{"selpikta", "se pikta"},
	nora{"terpikta", "te pikta"},
	nora{"velpikta", "ve pikta"},
	nora{"selpi'i", "se pilji"},
	nora{"terpi'i", "te pilji"},
	nora{"selpi'a", "se pilka"},
	nora{"selpli", "se pilno"},
	nora{"terpli", "te pilno"},
	nora{"selpi'u", "se pimlu"},
	nora{"selpinca", "se pinca"},
	nora{"selpindi", "se pindi"},
	nora{"selpinfu", "se pinfu"},
	nora{"terpinfu", "te pinfu"},
	nora{"selpinji", "se pinji"},
	nora{"selpinka", "se pinka"},
	nora{"terpinka", "te pinka"},
	nora{"velpinka", "ve pinka"},
	nora{"selpinsi", "se pinsi"},
	nora{"terpinsi", "te pinsi"},
	nora{"selpinta", "se pinta"},
	nora{"selpinxe", "se pinxe"},
	nora{"terpinxe", "te pinxe"},
	nora{"selxra", "se pixra"},
	nora{"terxra", "te pixra"},
	nora{"velxra", "ve pixra"},
	nora{"selplana", "se plana"},
	nora{"selpla", "se platu"},
	nora{"terpla", "te platu"},
	nora{"selyle'i", "se pleji"},
	nora{"terle'i", "te pleji"},
	nora{"velyle'i", "ve pleji"},
	nora{"selplibu", "se plibu"},
	nora{"selplini", "se plini"},
	nora{"terplini", "te plini"},
	nora{"velplini", "ve plini"},
	nora{"selpi'e", "se plipe"},
	nora{"terpi'e", "te plipe"},
	nora{"velpi'e", "ve plipe"},
	nora{"xelpi'e", "xe plipe"},
	nora{"selplise", "se plise"},
	nora{"selplita", "se plita"},
	nora{"selplixa", "se plixa"},
	nora{"terplixa", "te plixa"},
	nora{"velplixa", "ve plixa"},
	nora{"selpluja", "se pluja"},
	nora{"terpluja", "te pluja"},
	nora{"selpu'a", "se pluka"},
	nora{"terpu'a", "te pluka"},
	nora{"selylu'a", "se pluta"},
	nora{"terlu'a", "te pluta"},
	nora{"velylu'a", "ve pluta"},
	nora{"selplo", "se polje"},
	nora{"terplo", "te polje"},
	nora{"selpolno", "se polno"},
	nora{"selpo'o", "se ponjo"},
	nora{"selpo'e", "se ponse"},
	nora{"terpo'e", "te ponse"},
	nora{"selpo'i", "se porpi"},
	nora{"selpoi", "se porsi"},
	nora{"terpoi", "te porsi"},
	nora{"selporto", "se porto"},
	nora{"selprali", "se prali"},
	nora{"terprali", "te prali"},
	nora{"selpa'i", "se prami"},
	nora{"selpa'e", "se prane"},
	nora{"selpe'a", "se preja"},
	nora{"terpe'a", "te preja"},
	nora{"selrei", "se preti"},
	nora{"teryrei", "te preti"},
	nora{"velrei", "ve preti"},
	nora{"selprije", "se prije"},
	nora{"terprije", "te prije"},
	nora{"selpri", "se prina"},
	nora{"terpri", "te prina"},
	nora{"selpritu", "se pritu"},
	nora{"terpritu", "te pritu"},
	nora{"selro'a", "se prosa"},
	nora{"teryro'a", "te prosa"},
	nora{"velro'a", "ve prosa"},
	nora{"selru'e", "se pruce"},
	nora{"teryru'e", "te pruce"},
	nora{"velru'e", "ve pruce"},
	nora{"selpu'e", "se pulce"},
	nora{"terpu'e", "te pulce"},
	nora{"selpulji", "se pulji"},
	nora{"selpulni", "se pulni"},
	nora{"terpulni", "te pulni"},
	nora{"selpu'i", "se punji"},
	nora{"terpu'i", "te punji"},
	nora{"selpunli", "se punli"},
	nora{"terpunli", "te punli"},
	nora{"selpru", "se purci"},
	nora{"selpurdi", "se purdi"},
	nora{"terpurdi", "te purdi"},
	nora{"selpu'o", "se purmo"},
	nora{"selracli", "se racli"},
	nora{"selractu", "se ractu"},
	nora{"selra'o", "se radno"},
	nora{"teryra'o", "te radno"},
	nora{"selrafsi", "se rafsi"},
	nora{"teryrafsi", "te rafsi"},
	nora{"velrafsi", "ve rafsi"},
	nora{"selragve", "se ragve"},
	nora{"teryragve", "te ragve"},
	nora{"selrakso", "se rakso"},
	nora{"selra'u", "se raktu"},
	nora{"teryra'u", "te raktu"},
	nora{"selralci", "se ralci"},
	nora{"selralju", "se ralju"},
	nora{"teryralju", "te ralju"},
	nora{"selra'e", "se ralte"},
	nora{"selranda", "se randa"},
	nora{"teryranda", "te randa"},
	nora{"selrango", "se rango"},
	nora{"teryrango", "te rango"},
	nora{"selra'i", "se ranji"},
	nora{"selranmi", "se ranmi"},
	nora{"teryranmi", "te ranmi"},
	nora{"velranmi", "ve ranmi"},
	nora{"selransu", "se ransu"},
	nora{"selranti", "se ranti"},
	nora{"teryranti", "te ranti"},
	nora{"selranxi", "se ranxi"},
	nora{"teryranxi", "te ranxi"},
	nora{"selrapli", "se rapli"},
	nora{"selratcu", "se ratcu"},
	nora{"selratni", "se ratni"},
	nora{"teryratni", "te ratni"},
	nora{"selrebla", "se rebla"},
	nora{"selre'u", "se rectu"},
	nora{"selre'o", "se renro"},
	nora{"teryre'o", "te renro"},
	nora{"selre'i", "se renvi"},
	nora{"teryre'i", "te renvi"},
	nora{"selrespa", "se respa"},
	nora{"selcfu", "se ricfu"},
	nora{"selrigni", "se rigni"},
	nora{"teryrigni", "te rigni"},
	nora{"selrilti", "se rilti"},
	nora{"selrimni", "se rimni"},
	nora{"teryrimni", "te rimni"},
	nora{"velrimni", "ve rimni"},
	nora{"selrinci", "se rinci"},
	nora{"teryrinci", "te rinci"},
	nora{"velrinci", "ve rinci"},
	nora{"selri'u", "se rinju"},
	nora{"teryri'u", "te rinju"},
	nora{"selri'a", "se rinka"},
	nora{"teryri'a", "te rinka"},
	nora{"selrinsa", "se rinsa"},
	nora{"teryrinsa", "te rinsa"},
	nora{"selrirci", "se rirci"},
	nora{"teryrirci", "te rirci"},
	nora{"selrirni", "se rirni"},
	nora{"selri'e", "se rirxe"},
	nora{"teryri'e", "te rirxe"},
	nora{"velri'e", "ve rirxe"},
	nora{"selrismi", "se rismi"},
	nora{"selrisna", "se risna"},
	nora{"selri'i", "se ritli"},
	nora{"teryri'i", "te ritli"},
	nora{"velri'i", "ve ritli"},
	nora{"selrivbi", "se rivbi"},
	nora{"teryrivbi", "te rivbi"},
	nora{"selro'i", "se rokci"},
	nora{"teryro'i", "te rokci"},
	nora{"selromge", "se romge"},
	nora{"selro'o", "se ropno"},
	nora{"selrorci", "se rorci"},
	nora{"teryrorci", "te rorci"},
	nora{"seltsu", "se rotsu"},
	nora{"tertsu", "te rotsu"},
	nora{"selzgu", "se rozgu"},
	nora{"selble", "se ruble"},
	nora{"terble", "te ruble"},
	nora{"selrunme", "se runme"},
	nora{"teryrunme", "te runme"},
	nora{"selrunta", "se runta"},
	nora{"teryrunta", "te runta"},
	nora{"velrunta", "ve runta"},
	nora{"selru'u", "se rupnu"},
	nora{"teryru'u", "te rupnu"},
	nora{"selru'o", "se rusko"},
	nora{"selrutni", "se rutni"},
	nora{"selsabji", "se sabji"},
	nora{"tersabji", "te sabji"},
	nora{"selsabnu", "se sabnu"},
	nora{"selsacki", "se sacki"},
	nora{"selsaclu", "se saclu"},
	nora{"tersaclu", "te saclu"},
	nora{"seldjo", "se sadjo"},
	nora{"selsakci", "se sakci"},
	nora{"tersakci", "te sakci"},
	nora{"selsakli", "se sakli"},
	nora{"selsakta", "se sakta"},
	nora{"tersakta", "te sakta"},
	nora{"selsla", "se salci"},
	nora{"tersla", "te salci"},
	nora{"selsa'o", "se salpo"},
	nora{"tersa'o", "te salpo"},
	nora{"selsalta", "se salta"},
	nora{"selsamcu", "se samcu"},
	nora{"selsampu", "se sampu"},
	nora{"selsna", "se sance"},
	nora{"selsa'a", "se sanga"},
	nora{"tersa'a", "te sanga"},
	nora{"selsanji", "se sanji"},
	nora{"selsa'i", "se sanli"},
	nora{"tersa'i", "te sanli"},
	nora{"selsai", "se sanmi"},
	nora{"selsanso", "se sanso"},
	nora{"tersanso", "te sanso"},
	nora{"selsanta", "se santa"},
	nora{"tersanta", "te santa"},
	nora{"velsanta", "ve santa"},
	nora{"xelsanta", "xe santa"},
	nora{"selsa'u", "se sarcu"},
	nora{"tersa'u", "te sarcu"},
	nora{"selsra", "se sarji"},
	nora{"tersra", "te sarji"},
	nora{"velsra", "ve sarji"},
	nora{"selsarlu", "se sarlu"},
	nora{"tersarlu", "te sarlu"},
	nora{"selsarxe", "se sarxe"},
	nora{"tersarxe", "te sarxe"},
	nora{"selske", "se saske"},
	nora{"terske", "te saske"},
	nora{"selsatci", "se satci"},
	nora{"tersatci", "te satci"},
	nora{"selsa'e", "se satre"},
	nora{"selvru", "se savru"},
	nora{"tervru", "te savru"},
	nora{"selsazri", "se sazri"},
	nora{"tersazri", "te sazri"},
	nora{"selsfe", "se sefta"},
	nora{"tersfe", "te sefta"},
	nora{"velsfe", "ve sefta"},
	nora{"selsle", "se selci"},
	nora{"selse'u", "se selfu"},
	nora{"terse'u", "te selfu"},
	nora{"selsme", "se semto"},
	nora{"selsenpi", "se senpi"},
	nora{"selsenta", "se senta"},
	nora{"tersenta", "te senta"},
	nora{"selsne", "se senva"},
	nora{"selsei", "se sepli"},
	nora{"tersei", "te sepli"},
	nora{"selserti", "se serti"},
	nora{"terserti", "te serti"},
	nora{"selse'a", "se setca"},
	nora{"terse'a", "te setca"},
	nora{"selse'i", "se sevzi"},
	nora{"selsfani", "se sfani"},
	nora{"selsfa", "se sfasa"},
	nora{"tersfa", "te sfasa"},
	nora{"velsfa", "ve sfasa"},
	nora{"selsu'u", "se sfubu"},
	nora{"tersu'u", "te sfubu"},
	nora{"selsiclu", "se siclu"},
	nora{"selsi'i", "se sicni"},
	nora{"tersi'i", "te sicni"},
	nora{"velsi'i", "ve sicni"},
	nora{"selsi'o", "se sidbo"},
	nora{"tersi'o", "te sidbo"},
	nora{"seldju", "se sidju"},
	nora{"terdju", "te sidju"},
	nora{"selsigja", "se sigja"},
	nora{"tersigja", "te sigja"},
	nora{"selsilka", "se silka"},
	nora{"selsilna", "se silna"},
	nora{"tersilna", "te silna"},
	nora{"selmlu", "se simlu"},
	nora{"termlu", "te simlu"},
	nora{"velmlu", "ve simlu"},
	nora{"selsmi", "se simsa"},
	nora{"tersmi", "te simsa"},
	nora{"selsi'u", "se simxu"},
	nora{"selsince", "se since"},
	nora{"selsi'a", "se sinma"},
	nora{"selsinso", "se sinso"},
	nora{"selsni", "se sinxa"},
	nora{"tersni", "te sinxa"},
	nora{"selsirji", "se sirji"},
	nora{"tersirji", "te sirji"},
	nora{"selsirxo", "se sirxo"},
	nora{"selsisku", "se sisku"},
	nora{"tersisku", "te sisku"},
	nora{"selsti", "se sisti"},
	nora{"selsitna", "se sitna"},
	nora{"tersitna", "te sitna"},
	nora{"selsivni", "se sivni"},
	nora{"selskaci", "se skaci"},
	nora{"selskami", "se skami"},
	nora{"selskapi", "se skapi"},
	nora{"selska", "se skari"},
	nora{"terska", "te skari"},
	nora{"velska", "ve skari"},
	nora{"selski", "se skicu"},
	nora{"terski", "te skicu"},
	nora{"velski", "ve skicu"},
	nora{"selskiji", "se skiji"},
	nora{"terskiji", "te skiji"},
	nora{"selskina", "se skina"},
	nora{"terskina", "te skina"},
	nora{"velskina", "ve skina"},
	nora{"selsko", "se skori"},
	nora{"selko'o", "se skoto"},
	nora{"selku'o", "se skuro"},
	nora{"selsau", "se slabu"},
	nora{"tersau", "te slabu"},
	nora{"velsau", "ve slabu"},
	nora{"selslaka", "se slaka"},
	nora{"selslami", "se slami"},
	nora{"selslanu", "se slanu"},
	nora{"selslari", "se slari"},
	nora{"selslasi", "se slasi"},
	nora{"selsligu", "se sligu"},
	nora{"tersligu", "te sligu"},
	nora{"selsli", "se slilu"},
	nora{"tersli", "te slilu"},
	nora{"selylo'o", "se slovo"},
	nora{"selslu", "se sluji"},
	nora{"terslu", "te sluji"},
	nora{"selsluni", "se sluni"},
	nora{"selsmacu", "se smacu"},
	nora{"selsmadi", "se smadi"},
	nora{"tersmadi", "te smadi"},
	nora{"selsma", "se smaji"},
	nora{"tersma", "te smaji"},
	nora{"selsmani", "se smani"},
	nora{"selsmo", "se smoka"},
	nora{"selsmuci", "se smuci"},
	nora{"tersmuci", "te smuci"},
	nora{"selsmu", "se smuni"},
	nora{"tersmu", "te smuni"},
	nora{"selsnada", "se snada"},
	nora{"tersnada", "te snada"},
	nora{"selsnanu", "se snanu"},
	nora{"tersnanu", "te snanu"},
	nora{"selsnidu", "se snidu"},
	nora{"tersnidu", "te snidu"},
	nora{"selsnipa", "se snipa"},
	nora{"selsnuji", "se snuji"},
	nora{"tersnuji", "te snuji"},
	nora{"selnu'a", "se snura"},
	nora{"selsnuti", "se snuti"},
	nora{"selso'e", "se sobde"},
	nora{"selsodna", "se sodna"},
	nora{"selsodva", "se sodva"},
	nora{"selsofto", "se softo"},
	nora{"selsolri", "se solri"},
	nora{"tersolri", "te solri"},
	nora{"selso'o", "se sombo"},
	nora{"terso'o", "te sombo"},
	nora{"selsoi", "se sonci"},
	nora{"selsro", "se sorcu"},
	nora{"tersro", "te sorcu"},
	nora{"selsorgu", "se sorgu"},
	nora{"selso'a", "se sovda"},
	nora{"selspaji", "se spaji"},
	nora{"selspali", "se spali"},
	nora{"terspali", "te spali"},
	nora{"velspali", "ve spali"},
	nora{"selspano", "se spano"},
	nora{"selspa", "se spati"},
	nora{"selspe", "se speni"},
	nora{"terspe", "te speni"},
	nora{"selspi", "se spisa"},
	nora{"selspita", "se spita"},
	nora{"terspita", "te spita"},
	nora{"selpo'u", "se spofu"},
	nora{"selpo'a", "se spoja"},
	nora{"selspu", "se spuda"},
	nora{"terspu", "te spuda"},
	nora{"selpu'u", "se sputu"},
	nora{"terpu'u", "te sputu"},
	nora{"velpu'u", "ve sputu"},
	nora{"selsraji", "se sraji"},
	nora{"selsraku", "se sraku"},
	nora{"selsralo", "se sralo"},
	nora{"selra'a", "se srana"},
	nora{"selsrasu", "se srasu"},
	nora{"selsre", "se srera"},
	nora{"tersre", "te srera"},
	nora{"velsre", "ve srera"},
	nora{"selsrito", "se srito"},
	nora{"selru'a", "se sruma"},
	nora{"teryru'a", "te sruma"},
	nora{"selsru", "se sruri"},
	nora{"tersru", "te sruri"},
	nora{"selstace", "se stace"},
	nora{"terstace", "te stace"},
	nora{"selstagi", "se stagi"},
	nora{"terstagi", "te stagi"},
	nora{"selstaku", "se staku"},
	nora{"terstaku", "te staku"},
	nora{"velstaku", "ve staku"},
	nora{"selsta", "se stali"},
	nora{"selstani", "se stani"},
	nora{"selstapa", "se stapa"},
	nora{"terstapa", "te stapa"},
	nora{"selstasu", "se stasu"},
	nora{"selstati", "se stati"},
	nora{"selsteba", "se steba"},
	nora{"selte'i", "se steci"},
	nora{"terte'i", "te steci"},
	nora{"selstedu", "se stedu"},
	nora{"selstela", "se stela"},
	nora{"terstela", "te stela"},
	nora{"selte'o", "se stero"},
	nora{"terte'o", "te stero"},
	nora{"selstici", "se stici"},
	nora{"terstici", "te stici"},
	nora{"selti'i", "se stidi"},
	nora{"terti'i", "te stidi"},
	nora{"selstika", "se stika"},
	nora{"terstika", "te stika"},
	nora{"selsto", "se stodi"},
	nora{"tersto", "te stodi"},
	nora{"selstuna", "se stuna"},
	nora{"terstuna", "te stuna"},
	nora{"selsu'a", "se stura"},
	nora{"selstu", "se stuzi"},
	nora{"selsucta", "se sucta"},
	nora{"tersucta", "te sucta"},
	nora{"selsudga", "se sudga"},
	nora{"selsfu", "se sufti"},
	nora{"selsuksa", "se suksa"},
	nora{"tersuksa", "te suksa"},
	nora{"selsumji", "se sumji"},
	nora{"tersumji", "te sumji"},
	nora{"selsumne", "se sumne"},
	nora{"selsu'i", "se sumti"},
	nora{"tersu'i", "te sumti"},
	nora{"selsunga", "se sunga"},
	nora{"selsunla", "se sunla"},
	nora{"selsurla", "se surla"},
	nora{"selsutra", "se sutra"},
	nora{"seltadji", "se tadji"},
	nora{"tertadji", "te tadji"},
	nora{"seltadni", "se tadni"},
	nora{"seltagji", "se tagji"},
	nora{"tertagji", "te tagji"},
	nora{"veltagji", "ve tagji"},
	nora{"seltalsa", "se talsa"},
	nora{"tertalsa", "te talsa"},
	nora{"seltamca", "se tamca"},
	nora{"seltamji", "se tamji"},
	nora{"tertamji", "te tamji"},
	nora{"seltamne", "se tamne"},
	nora{"tertamne", "te tamne"},
	nora{"selta'o", "se tanbo"},
	nora{"seltance", "se tance"},
	nora{"seltanjo", "se tanjo"},
	nora{"seltanko", "se tanko"},
	nora{"seltau", "se tanru"},
	nora{"tertau", "te tanru"},
	nora{"veltau", "ve tanru"},
	nora{"xeltau", "xe tanru"},
	nora{"seltansi", "se tansi"},
	nora{"tertansi", "te tansi"},
	nora{"selta'e", "se tanxe"},
	nora{"terta'e", "te tanxe"},
	nora{"seltapla", "se tapla"},
	nora{"tertapla", "te tapla"},
	nora{"veltapla", "ve tapla"},
	nora{"seltarbi", "se tarbi"},
	nora{"tertarbi", "te tarbi"},
	nora{"seltarci", "se tarci"},
	nora{"seltarla", "se tarla"},
	nora{"seltai", "se tarmi"},
	nora{"seltra", "se tarti"},
	nora{"tertra", "te tarti"},
	nora{"seltaske", "se taske"},
	nora{"selta'i", "se tatpi"},
	nora{"seltatru", "se tatru"},
	nora{"selta'a", "se tavla"},
	nora{"terta'a", "te tavla"},
	nora{"velta'a", "ve tavla"},
	nora{"selta'u", "se taxfu"},
	nora{"terta'u", "te taxfu"},
	nora{"seltcaci", "se tcaci"},
	nora{"tertcaci", "te tcaci"},
	nora{"seltca", "se tcadu"},
	nora{"tertca", "te tcadu"},
	nora{"veltca", "ve tcadu"},
	nora{"seltcana", "se tcana"},
	nora{"seltcati", "se tcati"},
	nora{"seltcena", "se tcena"},
	nora{"tertcena", "te tcena"},
	nora{"veltcena", "ve tcena"},
	nora{"seltcica", "se tcica"},
	nora{"tertcica", "te tcica"},
	nora{"seltcidu", "se tcidu"},
	nora{"tertcidu", "te tcidu"},
	nora{"seltcika", "se tcika"},
	nora{"tertcika", "te tcika"},
	nora{"veltcika", "ve tcika"},
	nora{"seltcila", "se tcila"},
	nora{"selti'a", "se tcima"},
	nora{"seltcini", "se tcini"},
	nora{"seltcita", "se tcita"},
	nora{"tertcita", "te tcita"},
	nora{"seltei", "se temci"},
	nora{"tertei", "te temci"},
	nora{"seltenfa", "se tenfa"},
	nora{"tertenfa", "te tenfa"},
	nora{"selte'u", "se tengu"},
	nora{"selterdi", "se terdi"},
	nora{"selte'a", "se terpa"},
	nora{"selterto", "se terto"},
	nora{"terterto", "te terto"},
	nora{"seltigni", "se tigni"},
	nora{"tertigni", "te tigni"},
	nora{"seltikpa", "se tikpa"},
	nora{"tertikpa", "te tikpa"},
	nora{"veltikpa", "ve tikpa"},
	nora{"seltilju", "se tilju"},
	nora{"seltinbe", "se tinbe"},
	nora{"tertinbe", "te tinbe"},
	nora{"seltinsa", "se tinsa"},
	nora{"tertinsa", "te tinsa"},
	nora{"veltinsa", "ve tinsa"},
	nora{"seltirna", "se tirna"},
	nora{"tertirna", "te tirna"},
	nora{"seltirxu", "se tirxu"},
	nora{"tertirxu", "te tirxu"},
	nora{"seltisna", "se tisna"},
	nora{"seltitla", "se titla"},
	nora{"seltivni", "se tivni"},
	nora{"tertivni", "te tivni"},
	nora{"veltivni", "ve tivni"},
	nora{"seltoknu", "se toknu"},
	nora{"seltoldi", "se toldi"},
	nora{"selto'a", "se tonga"},
	nora{"terto'a", "te tonga"},
	nora{"selto'u", "se tordu"},
	nora{"terto'u", "te tordu"},
	nora{"selto'i", "se torni"},
	nora{"selrai", "se traji"},
	nora{"teryrai", "te traji"},
	nora{"velrai", "ve traji"},
	nora{"seltrati", "se trati"},
	nora{"selre'e", "se trene"},
	nora{"teryre'e", "te trene"},
	nora{"velre'e", "ve trene"},
	nora{"seltricu", "se tricu"},
	nora{"seltri", "se trina"},
	nora{"tertri", "te trina"},
	nora{"selti'e", "se trixe"},
	nora{"terti'e", "te trixe"},
	nora{"seltoi", "se troci"},
	nora{"tertoi", "te troci"},
	nora{"seltsa", "se tsali"},
	nora{"tertsa", "te tsali"},
	nora{"seltsani", "se tsani"},
	nora{"seltsapi", "se tsapi"},
	nora{"seltsi", "se tsiju"},
	nora{"tertsi", "te tsiju"},
	nora{"seltsina", "se tsina"},
	nora{"tertsina", "te tsina"},
	nora{"veltsina", "ve tsina"},
	nora{"seltu'u", "se tubnu"},
	nora{"tertu'u", "te tubnu"},
	nora{"seltu'i", "se tugni"},
	nora{"tertu'i", "te tugni"},
	nora{"veltu'i", "ve tugni"},
	nora{"seltujli", "se tujli"},
	nora{"seltu'a", "se tumla"},
	nora{"seltunba", "se tunba"},
	nora{"tertunba", "te tunba"},
	nora{"seltunta", "se tunta"},
	nora{"seltu'e", "se tuple"},
	nora{"seltru", "se turni"},
	nora{"seltci", "se tutci"},
	nora{"seltutra", "se tutra"},
	nora{"selvacri", "se vacri"},
	nora{"tervacri", "te vacri"},
	nora{"selvai", "se vajni"},
	nora{"tervai", "te vajni"},
	nora{"selvla", "se valsi"},
	nora{"tervla", "te valsi"},
	nora{"selva'i", "se vamji"},
	nora{"terva'i", "te vamji"},
	nora{"velva'i", "ve vamji"},
	nora{"selvamtu", "se vamtu"},
	nora{"selvanbi", "se vanbi"},
	nora{"selvanci", "se vanci"},
	nora{"tervanci", "te vanci"},
	nora{"selvanju", "se vanju"},
	nora{"selvau", "se vasru"},
	nora{"selva'u", "se vasxu"},
	nora{"selve'u", "se vecnu"},
	nora{"terve'u", "te vecnu"},
	nora{"velve'u", "ve vecnu"},
	nora{"selvenfu", "se venfu"},
	nora{"tervenfu", "te venfu"},
	nora{"velvenfu", "ve venfu"},
	nora{"selvensa", "se vensa"},
	nora{"tervensa", "te vensa"},
	nora{"selve'a", "se verba"},
	nora{"terve'a", "te verba"},
	nora{"selvibna", "se vibna"},
	nora{"selvidni", "se vidni"},
	nora{"selvidru", "se vidru"},
	nora{"tervidru", "te vidru"},
	nora{"selvi'i", "se vikmi"},
	nora{"tervi'i", "te vikmi"},
	nora{"velvi'i", "ve vikmi"},
	nora{"selviknu", "se viknu"},
	nora{"selvi'u", "se vimcu"},
	nora{"tervi'u", "te vimcu"},
	nora{"velvi'u", "ve vimcu"},
	nora{"selvindu", "se vindu"},
	nora{"selvinji", "se vinji"},
	nora{"tervinji", "te vinji"},
	nora{"selvipsi", "se vipsi"},
	nora{"tervipsi", "te vipsi"},
	nora{"selvri", "se virnu"},
	nora{"tervri", "te virnu"},
	nora{"selvi'a", "se viska"},
	nora{"tervi'a", "te viska"},
	nora{"selvitci", "se vitci"},
	nora{"selvi'e", "se vitke"},
	nora{"tervi'e", "te vitke"},
	nora{"selvi'o", "se vitno"},
	nora{"tervi'o", "te vitno"},
	nora{"selvlagi", "se vlagi"},
	nora{"selvlina", "se vlina"},
	nora{"tervlina", "te vlina"},
	nora{"selvli", "se vlipa"},
	nora{"tervli", "te vlipa"},
	nora{"selvoi", "se vofli"},
	nora{"selvo'a", "se voksa"},
	nora{"selvro", "se vorme"},
	nora{"tervro", "te vorme"},
	nora{"velvro", "ve vorme"},
	nora{"selvra", "se vraga"},
	nora{"tervra", "te vraga"},
	nora{"velvra", "ve vraga"},
	nora{"selvei", "se vreji"},
	nora{"tervei", "te vreji"},
	nora{"velvei", "ve vreji"},
	nora{"selvre", "se vreta"},
	nora{"selvrici", "se vrici"},
	nora{"selvu'e", "se vrude"},
	nora{"selvu'i", "se vrusi"},
	nora{"selvu'o", "se vukro"},
	nora{"selxa'u", "se xabju"},
	nora{"selxadba", "se xadba"},
	nora{"terxadba", "te xadba"},
	nora{"selxadni", "se xadni"},
	nora{"selxagji", "se xagji"},
	nora{"selxagri", "se xagri"},
	nora{"selxajmi", "se xajmi"},
	nora{"terxajmi", "te xajmi"},
	nora{"selxaksu", "se xaksu"},
	nora{"selxalbo", "se xalbo"},
	nora{"selxalka", "se xalka"},
	nora{"terxalka", "te xalka"},
	nora{"selxalni", "se xalni"},
	nora{"selxau", "se xamgu"},
	nora{"terxau", "te xamgu"},
	nora{"selxa'o", "se xampo"},
	nora{"terxa'o", "te xampo"},
	nora{"selxamsi", "se xamsi"},
	nora{"terxamsi", "te xamsi"},
	nora{"selxa'e", "se xance"},
	nora{"selxanka", "se xanka"},
	nora{"terxanka", "te xanka"},
	nora{"selxanri", "se xanri"},
	nora{"selxanto", "se xanto"},
	nora{"selxa'i", "se xarci"},
	nora{"terxa'i", "te xarci"},
	nora{"selxarju", "se xarju"},
	nora{"selxarnu", "se xarnu"},
	nora{"terxarnu", "te xarnu"},
	nora{"selxasli", "se xasli"},
	nora{"selxasne", "se xasne"},
	nora{"terxasne", "te xasne"},
	nora{"selxa'a", "se xatra"},
	nora{"terxa'a", "te xatra"},
	nora{"velxa'a", "ve xatra"},
	nora{"selxatsi", "se xatsi"},
	nora{"terxatsi", "te xatsi"},
	nora{"selzdo", "se xazdo"},
	nora{"selxei", "se xebni"},
	nora{"selbro", "se xebro"},
	nora{"selcto", "se xecto"},
	nora{"tercto", "te xecto"},
	nora{"selxe'a", "se xedja"},
	nora{"selxelso", "se xelso"},
	nora{"selxe'o", "se xendo"},
	nora{"terxe'o", "te xendo"},
	nora{"selxe'u", "se xenru"},
	nora{"selxexso", "se xexso"},
	nora{"terxexso", "te xexso"},
	nora{"selxindo", "se xindo"},
	nora{"selxinmo", "se xinmo"},
	nora{"terxinmo", "te xinmo"},
	nora{"selxi'a", "se xirma"},
	nora{"selxi'u", "se xislu"},
	nora{"terxi'u", "te xislu"},
	nora{"selxispo", "se xispo"},
	nora{"selxla", "se xlali"},
	nora{"terxla", "te xlali"},
	nora{"selxlu", "se xlura"},
	nora{"terxlu", "te xlura"},
	nora{"velxlu", "ve xlura"},
	nora{"selxoi", "se xotli"},
	nora{"terxoi", "te xotli"},
	nora{"selxrabo", "se xrabo"},
	nora{"selxai", "se xrani"},
	nora{"terxai", "te xrani"},
	nora{"velxai", "ve xrani"},
	nora{"selxi'o", "se xriso"},
	nora{"selxruba", "se xruba"},
	nora{"selxruki", "se xruki"},
	nora{"selxrula", "se xrula"},
	nora{"selxru", "se xruti"},
	nora{"terxru", "te xruti"},
	nora{"velxru", "ve xruti"},
	nora{"selxu'i", "se xukmi"},
	nora{"terxu'i", "te xukmi"},
	nora{"selxu'o", "se xurdo"},
	nora{"selxu'a", "se xusra"},
	nora{"selza'a", "se zabna"},
	nora{"terza'a", "te zabna"},
	nora{"selzajba", "se zajba"},
	nora{"selzalvi", "se zalvi"},
	nora{"terzalvi", "te zalvi"},
	nora{"selzau", "se zanru"},
	nora{"selzai", "se zarci"},
	nora{"terzai", "te zarci"},
	nora{"selza'u", "se zargu"},
	nora{"selzasni", "se zasni"},
	nora{"terzasni", "te zasni"},
	nora{"selza'i", "se zasti"},
	nora{"terza'i", "te zasti"},
	nora{"selzbabu", "se zbabu"},
	nora{"terzbabu", "te zbabu"},
	nora{"selzbani", "se zbani"},
	nora{"selzba", "se zbasu"},
	nora{"terzba", "te zbasu"},
	nora{"selzbe", "se zbepi"},
	nora{"terzbe", "te zbepi"},
	nora{"selzda", "se zdani"},
	nora{"selzdi", "se zdile"},
	nora{"terzdi", "te zdile"},
	nora{"selzei", "se zekri"},
	nora{"selze'a", "se zenba"},
	nora{"terze'a", "te zenba"},
	nora{"selzepti", "se zepti"},
	nora{"terzepti", "te zepti"},
	nora{"selzetro", "se zetro"},
	nora{"terzetro", "te zetro"},
	nora{"selzga", "se zgana"},
	nora{"terzga", "te zgana"},
	nora{"velzga", "ve zgana"},
	nora{"selzgi", "se zgike"},
	nora{"selzi'e", "se zifre"},
	nora{"terzi'e", "te zifre"},
	nora{"selvle", "se zivle"},
	nora{"tervle", "te zivle"},
	nora{"velvle", "ve zivle"},
	nora{"selmau", "se zmadu"},
	nora{"termau", "te zmadu"},
	nora{"velmau", "ve zmadu"},
	nora{"selzmi", "se zmiku"},
	nora{"terzmi", "te zmiku"},
	nora{"selzu'e", "se zukte"},
	nora{"terzu'e", "te zukte"},
	nora{"selzmu", "se zumri"},
	nora{"selzungi", "se zungi"},
	nora{"selzunle", "se zunle"},
	nora{"terzunle", "te zunle"},
	nora{"selzu'i", "se zunti"},
	nora{"terzu'i", "te zunti"},
	nora{"seltse", "se zutse"},
	nora{"selzva", "se zvati"},
}
